#
# spec file for package pacemaker
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

# Globals and defines to control package behavior (configure these as desired)

## User and group to use for nonprivileged services
%global uname hacluster
%global gname haclient

## Where to install Pacemaker documentation
%global pcmk_docdir %{_docdir}/%{name}

## Path to Python interpreter (leave commented to auto-detect,
## or uncomment and edit to use a specific version)
%global python_path /usr/bin/python%{python3_version}

## Corosync version
%define cs_version 2

%define with_nagios             1
%define with_cibsecrets         1
%define enable_lib_cluster_pkg  0
%define enable_fatal_warnings   0
%define with_regression_tests   0

# Define conditionals so that "rpmbuild --with <feature>" and
# "rpmbuild --without <feature>" can enable and disable specific features

## Add option to enable support for stonith/external fencing agents
%bcond_without stonithd

## Add option to create binaries suitable for use with profiling tools
%bcond_with profiling

## Add option to create binaries with coverage analysis
%bcond_with coverage

## Add option to skip generating documentation
## (the build tools aren't available everywhere)
%bcond_with doc

## Add option to turn off hardening of libraries and daemon executables
%bcond_with hardening

# Keep sane profiling data if requested
%if %{with profiling}

## Disable -debuginfo package and stripping binaries/libraries
%define debug_package %{nil}

%endif

Name:           pacemaker
Version:        1.1.18+20180430.b12c320f5
Release:        lp150.2.16.1
Summary:        Scalable High-Availability cluster resource manager
# AGPL-3.0 licensed extra/clustermon.sh is not present in the binary
License:        GPL-2.0 and GPL-2.0+ and LGPL-2.1+
Group:          Productivity/Clustering/HA
Url:            http://www.clusterlabs.org
# Hint: use "spectool -s 0 pacemaker.spec" (rpmdevtools) to check the final URL:
# https://github.com/ClusterLabs/pacemaker/archive/e91769e5a39f5cb2f7b097d3c612368f0530535e/pacemaker-e91769e.tar.gz
Source0:        %{name}-%{version}.tar.xz
Source1:        crm_report.in
Source100:      pacemaker.rpmlintrc
Patch1:         bug-806256_pacemaker-log-level-notice.patch
Patch2:         bug-728579_pacemaker-stonith-dev-id.patch
Patch3:         pacemaker-nagios-plugin-dir.patch
Patch4:         bug-812269_pacemaker-fencing-device-register-messages.patch
Patch5:         pacemaker-Wno-format-signedness.patch
Patch6:         bug-943295_pacemaker-lrmd-log-notice.patch
Patch7:         bug-977201_pacemaker-controld-self-fencing.patch
Patch8:         bug-995365_pacemaker-cts-restart-systemd-journald.patch
Patch9:         pacemaker-cts-StartCmd.patch
Patch10:        pacemaker-libcrmcommon-check-filedirectory-writability-better.patch
Patch11:        pacemaker-pacemaker_remote-correct-documentation-URL-in-systemd-unit-file.patch
Patch12:        pacemaker-libcrmcommon-improve-connection-loss-message.patch
Patch13:        pacemaker-daemons-improve-connection-loss-messages.patch
Patch14:        pacemaker-libcrmcommon-avoid-memory-leak-on-failed-IPC-send.patch
Patch15:        pacemaker-io.c-restore--Werror-buildability--put-conversion-specifier-last.patch
Patch16:        pacemaker-libcrmcommon-pacemakerd-kernel-task-name-is-at-most-15-characters.patch
Patch17:        pacemaker-controller-dont-abort-after-delay-if-were-no-longer-DC.patch
Patch18:        pacemaker-contoller-scheduler-guard-hash-table-deletes.patch
Patch19:        pacemaker-execd-handle-systemd-actions-correctly-when-used-with-service.patch
Patch20:        pacemaker-libcrmservice-separate-LSB-specific-code-into-own-source-files.patch
Patch21:        pacemaker-libcrmservice-find-absolute-paths-when-used-with-service.patch
Patch22:        pacemaker-scheduler-improve-failed-op-message.patch
Patch23:        bsc#1102915-pacemaker-tools-cibsecret---help--version-doesnt-require-cluster-to-be-running.patch
Patch24:        pacemaker-libcrmservice-dont-consider-a-cancelled-recurring-operation-as-failed.patch
Patch25:        pacemaker-tools-bash-portability-issue-in-crm_failcount.patch
Patch26:        pacemaker-tools-handle-multiple-values-properly-in-crm_attribute.patch
Patch27:        pacemaker-tools-use-output-redirection-correctly-in-crm_standby.patch
Patch28:        pacemaker-tools-improve-error-messages-from-crm_resource---move.patch
Patch29:        pacemaker-XML-regression.sh-modularize-XSLT-processor-allow-substitutes.patch
Patch30:        pacemaker-XML-upgrade-2.10.xsl-simplify-1-2-resource-instance_attributes.patch
Patch31:        pacemaker-XML-upgrade-2.10.xsl-simplify-2-2-HelperIdentity-no-INNER-RECURSION.patch
Patch32:        pacemaker-XML-upgrade-2.10.xsl-remaining-marking-space-with-op-meta_attributes.patch
Patch33:        pacemaker-XML-upgrade-2.10.xsl-make-diagnostics-more-direct-wrt-context.patch
Patch34:        pacemaker-XML-upgrade-2.10.xsl-resource-meta_attributes-isolation-items.patch
Patch35:        pacemaker-controld-avoid-memory-leak-when-synthesizing-failure.patch
Patch36:        pacemaker-cts-scheduler-avoid-unsupported-usage-of-requires.patch
Patch37:        pacemaker-execd-avoid-memory-leak-when-testing-remote-key.patch
Patch38:        pacemaker-XML-upgrade-2.10.xsl-resource-meta_attributes-validity-conformance.patch
Patch39:        pacemaker-XML-upgrade-2.10.xsl-re-apply-on-scheduler-CTS-test-cases.patch
Patch40:        pacemaker-XML-upgrade-2.10.xsl-resource-meta_attributes-tweak-diagnostic-msg.patch
Patch41:        bsc#1094208-0001-Fix-controld-able-to-manually-confirm-unseen-nodes-a.patch
Patch42:        bsc#1094208-0002-Refactor-fenced-Handle-fencing-requested-with-nodeid.patch
Patch43:        0001-Test-cts-set-default-number-of-iterations-to-1.patch
Patch44:        bsc#1114840-0001-Test-CTS-don-t-require-nodes-to-be-specified-if-only.patch
Patch45:        bsc#1121272-0001-Test-cts-simulate-failure-of-pacemaker_remoted-by-fr.patch
Patch46:        bsc#1121272-0002-Test-cts-resume-any-possibly-frozen-pacemaker_remote.patch
Patch47:        bsc#1121272-0003-Test-cts-clear-constraints-on-cluster-nodes.patch
Patch48:        0001-Test-cts-use-bash-in-the-pacemaker-cts-dummyd.patch
Patch49:        0001-Test-CTS-lower-remote-connection-failure-detection-t.patch
Patch50:        0002-Test-CTS-ignore-monitor-failures-when-testing-remote.patch
Patch51:        bsc#1121808-0001-Test-cts-exec-still-run-the-tests-for-the-other-reso.patch
Patch52:        0001-Test-cts-service-counts-as-enabled-only-if-it-s-expl.patch
Patch53:        0002-Test-cts-temporarily-disable-any-enabled-cluster-ser.patch
Patch54:        bsc#1114840-0001-Test-CTS-really-don-t-require-nodes-to-be-specified-.patch
Patch55:        bsc#1117934-0001-Fix-scheduler-cl-5301-respect-order-constraints-when.patch
Patch56:        bsc#1117934-0002-Test-scheduler-cl-5301-respect-order-constraints-whe.patch
Patch57:        bsc#1117934-0003-Test-scheduler-cl-5301-respect-order-constraints-whe.patch
Patch58:        bsc#1128772-0001-Fix-libcrmcluster-avoid-use-of-NULL-when-searching-f.patch
Patch59:        0001-Shutdown-corosync-after-a-fatal-error.patch
Patch60:        0001-Low-pacemakerd-only-one-active-process-check-needed.patch
Patch61:        bsc#1131357-0001-High-libservices-fix-use-after-free-wrt.-alert-handl.patch
Patch62:        bsc#1131353-bsc#1131356-0002-High-pacemakerd-vs.-IPC-procfs-confused-deputy-authe.patch
Patch63:        bsc#1131353-bsc#1131356-0003-High-pacemakerd-vs.-IPC-procfs-confused-deputy-authe.patch
Patch64:        bsc#1131353-bsc#1131356-0004-High-pacemakerd-vs.-IPC-procfs-confused-deputy-authe-1.1.patch
Patch65:        bsc#1131353-bsc#1131356-0005-High-pacemakerd-vs.-IPC-procfs-confused-deputy-authe.patch
Patch66:        bsc#1131353-bsc#1131356-0006-High-pacemakerd-vs.-IPC-procfs-confused-deputy-authe-1.1.patch
Patch67:        bsc#1131353-bsc#1131356-0007-Med-controld-fix-possible-NULL-pointer-dereference-1.1.patch
Patch68:        bsc#1140519-0001-Fix-tools-crm_resource-C-should-wait-for-all-replies.patch
Patch69:        bsc#1131353-bsc#1131356-0008-Fix-libcrmcommon-avoid-use-of-NULL-when-checking-whe.patch
Patch70:        bsc#1131353-bsc#1131356-0009-Low-libcrmcommon-return-proper-code-if-testing-pid-i.patch
Patch71:        0001-Low-controller-avoid-memory-leak-when-duplicate-moni.patch
Patch72:        bsc#1127716-0001-Fix-libcrmcommon-correctly-apply-XML-diffs-with-mult.patch
Patch73:        bsc#1127716-0002-Fix-libcrmcommon-avoid-possible-use-of-NULL-when-app.patch
Patch74:        bsc#1127716-0003-Fix-libcrmcommon-return-error-when-applying-XML-diff.patch
Patch75:        bsc#1133866-0001-Refactor-libcrmcommon-improve-parse_op_key-efficienc.patch
Patch76:        bsc#1133866-0002-Log-controller-improve-failed-recurring-action-messa.patch
Patch77:        bsc#1133866-0003-Fix-controller-confirm-cancel-of-failed-monitors.patch
Patch78:        bsc#1130122-0001-Fix-scheduler-wait-for-probe-actions-to-complete-to-.patch
Patch79:        bsc#1130122-0002-Test-scheduler-wait-for-probe-actions-to-complete-to.patch
# Required for core functionality
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  coreutils
BuildRequires:  fdupes
BuildRequires:  findutils
BuildRequires:  gcc
BuildRequires:  grep
BuildRequires:  help2man
BuildRequires:  libtool
BuildRequires:  ncurses-devel
BuildRequires:  pam-devel
BuildRequires:  pkgconfig
# Required for agent_config.h which specifies the correct scratch directory
BuildRequires:  resource-agents
BuildRequires:  sed
%if %{with_cibsecrets}
BuildRequires:  openssh
BuildRequires:  procps
%endif
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(corosync) >= 2.0.0
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(glib-2.0) >= 2.16
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(libexslt)
# Pacemaker requires a minimum libqb functionality
BuildRequires:  pkgconfig(libqb) > 0.13.0
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libxslt)
# Pacemaker requires a minimum Python functionality
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(uuid)
Requires:       %{name}-cli = %{version}-%{release}
Requires:       corosync >= 2.0.0
Requires:       libpacemaker3 = %{version}-%{release}
Requires:       libqb > 0.13.0
Requires:       psmisc
Requires:       python3
Requires:       resource-agents
Recommends:     crmsh
Recommends:     fence-agents
Recommends:     libdlm
Recommends:     sbd
Suggests:       graphviz
Conflicts:      heartbeat < 3.0
Conflicts:      libheartbeat2 < 3.0.0
Provides:       pacemaker-ticket-support = 2.0
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%{?systemd_requires}
%if %{enable_lib_cluster_pkg}
Requires:       libpacemaker3-cluster = %{version}-%{release}
%endif
# Enables optional functionality
%if 0%{?suse_version} > 1100
BuildRequires:  docbook-xsl-stylesheets
%else
BuildRequires:  docbook-style-xsl
%endif
%if %{with stonithd}
%if 0%{?suse_version}
BuildRequires:  libglue-devel
%else
BuildRequires:  cluster-glue-libs-devel
%endif
%endif
%if %{with doc}
BuildRequires:  asciidoc
BuildRequires:  inkscape
BuildRequires:  publican
%endif
%if %{with_regression_tests}
BuildRequires:  procps
BuildRequires:  python3-curses
BuildRequires:  python3-xml
%endif

%description
Pacemaker is an advanced, scalable High-Availability cluster resource
manager.

It supports more than 16 node clusters with significant capabilities
for managing resources and dependencies.

It will run scripts at initialization, when machines go up or down,
when related resources fail and can be configured to periodically check
resource health.

%package cli
Summary:        Command line tools for controlling Pacemaker clusters
Group:          Productivity/Clustering/HA
Requires:       libpacemaker3 = %{version}-%{release}
Requires:       logrotate
Requires:       perl-TimeDate
Requires(post): coreutils

%description cli
Pacemaker is an advanced, scalable High-Availability cluster resource
manager.

The %{name}-cli package contains command line tools that can be used
to query and control the cluster from machines that may, or may not,
be part of the cluster.

%package -n libpacemaker3
Summary:        Core Pacemaker libraries
Group:          Productivity/Clustering/HA
Requires(pre):  shadow

%description -n libpacemaker3
Pacemaker is an advanced, scalable High-Availability cluster resource
manager.

The libpacemaker3 package contains shared libraries needed for cluster
nodes and those just running the CLI tools.

%if %{enable_lib_cluster_pkg}
%package -n libpacemaker3-cluster
Summary:        Cluster Libraries used by Pacemaker
Group:          Productivity/Clustering/HA
Requires:       libpacemaker3 = %{version}-%{release}

%description -n libpacemaker3-cluster
Pacemaker is an advanced, scalable High-Availability cluster resource
manager.

The libpacemaker3-cluster package contains cluster-aware shared
libraries needed for nodes that will form part of the cluster nodes.
%endif

%package remote
Summary:        Pacemaker remote daemon for non-cluster nodes
Group:          Productivity/Clustering/HA
Requires:       %{name}-cli = %{version}-%{release}
Requires:       libpacemaker3 = %{version}-%{release}
Requires:       resource-agents
%{?systemd_requires}

%description remote
Pacemaker is an advanced, scalable High-Availability cluster resource
manager.

The %{name}-remote package contains the Pacemaker Remote daemon
which is capable of extending pacemaker functionality to remote
nodes not running the full corosync/cluster stack.

%package -n libpacemaker-devel
Summary:        Pacemaker development package
Group:          Development/Libraries/C and C++
Requires:       %{name}-cts = %{version}-%{release}
Requires:       libpacemaker3 = %{version}-%{release}
Requires:       libtool-ltdl-devel
Requires:       pkgconfig
Requires:       pkgconfig(bzip2)
Requires:       pkgconfig(corosync) >= 2.0.0
Requires:       pkgconfig(glib-2.0)
Requires:       pkgconfig(libqb)
Requires:       pkgconfig(libxml-2.0)
Requires:       pkgconfig(libxslt)
Requires:       pkgconfig(uuid)
%if %{enable_lib_cluster_pkg}
Requires:       libpacemaker3-cluster = %{version}-%{release}
%endif
%if %{with_regression_tests}
# For the regression tests, we can run them only if all pacemaker
# packages are installed, so we pull that in here for the regression
# builds; this is supposed to be disabled for shipping code.
Requires:       pacemaker
%endif

%description -n libpacemaker-devel
Pacemaker is an advanced, scalable High-Availability cluster resource
manager.

The libpacemaker-devel package contains headers and shared libraries
for developing tools for Pacemaker.

%package       cts
Summary:        Test framework for cluster-related technologies
Group:          Productivity/Clustering/HA
Requires:       libpacemaker3 = %{version}-%{release}
Requires:       python3
BuildArch:      noarch
#Requires:       python3-systemd
Recommends:     python3-systemd

%description   cts
Test framework for cluster-related technologies like Pacemaker

%if %{with doc}
%package       doc
Summary:        Documentation for Pacemaker
Group:          Productivity/Clustering/HA
BuildArch:      noarch

%description   doc
Documentation for Pacemaker.

Pacemaker is an advanced, scalable High-Availability cluster resource
manager.
%endif

%prep
%setup -q -n %{name}-%{version}
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1
%patch14 -p1
%patch15 -p1
%patch16 -p1
%patch17 -p1
%patch18 -p1
%patch19 -p1
%patch20 -p1
%patch21 -p1
%patch22 -p1
%patch23 -p1
%patch24 -p1
%patch25 -p1
%patch26 -p1
%patch27 -p1
%patch28 -p1
%patch29 -p1
%patch30 -p1
%patch31 -p1
%patch32 -p1
%patch33 -p1
%patch34 -p1
%patch35 -p1
%patch36 -p1
%patch37 -p1
%patch38 -p1
%patch39 -p1
%patch40 -p1
%patch41 -p1
%patch42 -p1
%patch43 -p1
%patch44 -p1
%patch45 -p1
%patch46 -p1
%patch47 -p1
%patch48 -p1
%patch49 -p1
%patch50 -p1
%patch51 -p1
%patch52 -p1
%patch53 -p1
%patch54 -p1
%patch55 -p1
%patch56 -p1
%patch57 -p1
%patch58 -p1
%patch59 -p1
%patch60 -p1
%patch61 -p1
%patch62 -p1
%patch63 -p1
%patch64 -p1
%patch65 -p1
%patch66 -p1
%patch67 -p1
%patch68 -p1
%patch69 -p1
%patch70 -p1
%patch71 -p1
%patch72 -p1
%patch73 -p1
%patch74 -p1
%patch75 -p1
%patch76 -p1
%patch77 -p1
%patch78 -p1
%patch79 -p1

%build

export systemdunitdir=%{?_unitdir}%{!?_unitdir:no}

%if %{with hardening}
# prefer distro-provided hardening flags in case they are defined
# through _hardening_{c,ld}flags macros, configure script will
# use its own defaults otherwise; if such hardenings are completely
# undesired, rpmbuild using "--without hardening"
# (or "--define '_without_hardening 1'")
export CFLAGS_HARDENED_EXE="%{?_hardening_cflags}"
export CFLAGS_HARDENED_LIB="%{?_hardening_cflags}"
export LDFLAGS_HARDENED_EXE="%{?_hardening_ldflags}"
export LDFLAGS_HARDENED_LIB="%{?_hardening_ldflags}"
%endif

autoreconf -fvi

%configure \
        --docdir=%{_docdir}/%{name}                \
        --disable-static                           \
        --disable-silent-rules                     \
        --with-acl=true                            \
%if %{with_nagios}
        --with-nagios=true                         \
%endif
%if %{with_cibsecrets}
        --with-cibsecrets=true                     \
%endif
%if !%{enable_fatal_warnings}
        --enable-fatal-warnings=no                 \
%endif
        %{?python_path:      PYTHON=%{python_path}} \
        %{!?with_hardening:  --disable-hardening}   \
        %{?with_profiling:   --with-profiling}      \
        %{?with_coverage:    --with-coverage}       \
        %{!?with_doc:        --with-brand=}         \
        --with-initdir=%{_initddir}                 \
        --localstatedir=%{_var}                     \
        --with-version=%{version}-%{release}

make %{?_smp_mflags} all

%install
%make_install

install -d -m755 %{buildroot}%{_fillupdir}
install -m 644 daemons/pacemakerd/pacemaker.sysconfig %{buildroot}%{_fillupdir}/sysconfig.pacemaker
install -m 644 tools/crm_mon.sysconfig %{buildroot}%{_fillupdir}/sysconfig.crm_mon

# Don't package static libs
find %{buildroot} -type f -name "*.a" -delete -print
find %{buildroot} -type f -name "*.la" -delete -print

# Don't ship init scripts for systemd based platforms
rm -f %{buildroot}/%{_initddir}/pacemaker
rm -f %{buildroot}/%{_initddir}/pacemaker_remote

%if %{with coverage}
GCOV_BASE=%{buildroot}/%{_var}/lib/pacemaker/gcov
mkdir -p $GCOV_BASE
find . -name '*.gcno' -type f | while read F ; do
        D=`dirname $F`
        mkdir -p ${GCOV_BASE}/$D
        cp $F ${GCOV_BASE}/$D
done
%endif

ln -s service %{buildroot}%{_sbindir}/rcpacemaker
ln -s service %{buildroot}%{_sbindir}/rcpacemaker_remote
ln -s service %{buildroot}%{_sbindir}/rccrm_mon

mv %{buildroot}%{_sbindir}/crm_report %{buildroot}%{_sbindir}/crm_report.pacemaker
install -m 755 %{SOURCE1} %{buildroot}%{_sbindir}/crm_report

ln -s ../heartbeat/NodeUtilization %{buildroot}%{_libexecdir}/ocf/resource.d/pacemaker/

%fdupes -s %{buildroot}

%check
# Prevent false positives in rpmlint
./cts/cts-regression -V pengine cli 2>&1

%pre
%service_add_pre pacemaker.service

%post
%service_add_post pacemaker.service

%preun
%service_del_preun pacemaker.service

%postun
%service_del_postun pacemaker.service

%pre remote
%service_add_pre pacemaker_remote.service

%post remote
%service_add_post pacemaker_remote.service

%preun remote
%service_del_preun pacemaker_remote.service

%postun remote
%service_del_postun pacemaker_remote.service

%pre cli
%service_add_pre crm_mon.service

%post cli
if [ ! -e %{_sysconfdir}/sysconfig/pacemaker ]; then
    %fillup_only -n pacemaker
fi

%service_add_post crm_mon.service

if [ ! -e %{_sysconfdir}/sysconfig/crm_mon ]; then
    %fillup_only -n crm_mon
fi

if [ "$1" -eq "2" ]; then
    # Package upgrade, not initial install:
    # Move any pre-2.0 logs to new location to ensure they get rotated
    { mv -fbS.rpmsave %{_var}/log/pacemaker.log* %{_var}/log/pacemaker \
      || mv -f %{_var}/log/pacemaker.log* %{_var}/log/pacemaker
    } >/dev/null 2>/dev/null || :
fi

%preun cli
%service_del_preun crm_mon.service

%postun cli
%service_del_postun crm_mon.service

%pre cts
%service_add_pre pacemaker-cts-dummyd@.service

%post cts
%service_add_post pacemaker-cts-dummyd@.service

%preun cts
%service_del_preun pacemaker-cts-dummyd@.service

%postun cts
%service_del_postun pacemaker-cts-dummyd@.service

%pre -n libpacemaker3
getent group %{gname} >/dev/null || groupadd -r %{gname} -g 189
getent passwd %{uname} >/dev/null || useradd -r -g %{gname} -u 189 -s /sbin/nologin -c "cluster user" %{uname}
exit 0

%post -n libpacemaker3 -p /sbin/ldconfig
%postun -n libpacemaker3 -p /sbin/ldconfig

%if %{enable_lib_cluster_pkg}
%post -n libpacemaker3-cluster -p /sbin/ldconfig
%postun -n libpacemaker3-cluster -p /sbin/ldconfig
%endif

%if %{with_regression_tests}
%post -n libpacemaker-devel
if [ ! -e /tmp/.pcmk_regression_tests_ran ]; then
	touch /tmp/.pcmk_regression_tests_ran
	# Needed so that the shell doesn't get stuck on escape
	# sequences
	export TERM=dumb
	%{_datadir}/pacemaker/tests/cts-cli || true
	%{_datadir}/pacemaker/tests/cts-pengine -V || true
fi
%endif

%files
%defattr(-,root,root)
%{_defaultdocdir}/%{name}/
%{_sbindir}/pacemakerd

%{_unitdir}/pacemaker.service
%{_sbindir}/rcpacemaker

%exclude %{_libexecdir}/pacemaker/lrmd_test
%exclude %{_sbindir}/pacemaker_remoted
%dir %{_libexecdir}/pacemaker
%{_libexecdir}/pacemaker/*

%{_sbindir}/cibsecret
%{_sbindir}/crm_node
%{_sbindir}/fence_legacy
%{_sbindir}/stonith_admin

%{_mandir}/man7/crmd.7%{ext_man}
%{_mandir}/man7/pengine.7%{ext_man}
%{_mandir}/man7/stonithd.7%{ext_man}
%{_mandir}/man7/ocf_pacemaker_controld.7%{ext_man}
%{_mandir}/man7/ocf_pacemaker_o2cb.7%{ext_man}
%{_mandir}/man7/ocf_pacemaker_remote.7%{ext_man}
%{_mandir}/man8/cibsecret.8%{ext_man}
%{_mandir}/man8/crm_node.8%{ext_man}
%{_mandir}/man8/fence_legacy.8%{ext_man}
%{_mandir}/man8/pacemakerd.8%{ext_man}
%{_mandir}/man8/stonith_admin.8%{ext_man}

%doc %{_datadir}/pacemaker/alerts

#%license licenses/GPLv2
%doc COPYING ChangeLog

%dir %attr (750, %{uname}, %{gname}) %{_var}/lib/pacemaker/cib
%dir %attr (750, %{uname}, %{gname}) %{_var}/lib/pacemaker/pengine
%{_libexecdir}/ocf/resource.d/pacemaker/controld
%{_libexecdir}/ocf/resource.d/pacemaker/o2cb
%{_libexecdir}/ocf/resource.d/pacemaker/remote

%if "%{?cs_version}" != "UNKNOWN"
%if 0%{?cs_version} < 2
%{_libexecdir}/lcrso/pacemaker.lcrso
%endif
%endif

%files cli
%defattr(-,root,root)
%dir %attr (750, root, %{gname}) %{_sysconfdir}/pacemaker
%config(noreplace) %{_sysconfdir}/logrotate.d/pacemaker
%{_unitdir}/crm_mon.service
%{_sbindir}/rccrm_mon
%{_sbindir}/attrd_updater
%{_sbindir}/cibadmin
%{_sbindir}/crm_attribute
%{_sbindir}/crm_diff
%{_sbindir}/crm_error
%{_sbindir}/crm_failcount
%{_sbindir}/crm_master
%{_sbindir}/crm_mon
%{_sbindir}/crm_resource
%{_sbindir}/crm_standby
%{_sbindir}/crm_verify
%{_sbindir}/crmadmin
%{_sbindir}/iso8601
%{_sbindir}/crm_shadow
%{_sbindir}/crm_simulate
%{_sbindir}/crm_report
%{_sbindir}/crm_report.pacemaker
%{_sbindir}/crm_ticket
%exclude %{_datadir}/pacemaker/alerts
%exclude %{_datadir}/pacemaker/tests
%{_datadir}/pacemaker
%{_datadir}/snmp/mibs/PCMK-MIB.txt
%{_libexecdir}/pacemaker/lrmd_test

%exclude %{_libexecdir}/ocf/resource.d/pacemaker/controld
%exclude %{_libexecdir}/ocf/resource.d/pacemaker/o2cb
%exclude %{_libexecdir}/ocf/resource.d/pacemaker/remote

%dir %{_libexecdir}/ocf
%dir %{_libexecdir}/ocf/resource.d
%{_libexecdir}/ocf/resource.d/pacemaker

%config(noreplace) %{_fillupdir}/sysconfig.pacemaker
%config(noreplace) %{_fillupdir}/sysconfig.crm_mon
%{_mandir}/man7/*
%exclude %{_mandir}/man7/crmd.*
%exclude %{_mandir}/man7/pengine.*
%exclude %{_mandir}/man7/stonithd.*
%exclude %{_mandir}/man7/ocf_pacemaker_controld.*
%exclude %{_mandir}/man7/ocf_pacemaker_o2cb.*
%exclude %{_mandir}/man7/ocf_pacemaker_remote.*
%{_mandir}/man8/*
%exclude %{_mandir}/man8/cibsecret.*
%exclude %{_mandir}/man8/crm_node.*
%exclude %{_mandir}/man8/fence_legacy.*
%exclude %{_mandir}/man8/pacemakerd.*
%exclude %{_mandir}/man8/pacemaker_remoted.*
%exclude %{_mandir}/man8/stonith_admin.*

#%license licenses/GPLv2
%doc COPYING ChangeLog

%dir %attr (750, %{uname}, %{gname}) %{_var}/lib/pacemaker
%dir %attr (750, %{uname}, %{gname}) %{_var}/lib/pacemaker/blackbox
%dir %attr (750, %{uname}, %{gname}) %{_var}/lib/pacemaker/cores
%dir %attr (770, %{uname}, %{gname}) %{_var}/log/pacemaker
%dir %attr (770, %{uname}, %{gname}) %{_var}/log/pacemaker/bundles

%files -n libpacemaker3
%defattr(-,root,root)

%{_libdir}/libcib.so.*
%{_libdir}/liblrmd.so.*
%{_libdir}/libcrmservice.so.*
%{_libdir}/libcrmcommon.so.*
%{_libdir}/libpe_status.so.*
%{_libdir}/libpe_rules.so.*
%{_libdir}/libpengine.so.*
%{_libdir}/libstonithd.so.*
%{_libdir}/libtransitioner.so.*
#%license licenses/LGPLv2.1
%doc COPYING ChangeLog
%{_libdir}/libcrmcluster.so.*

%if %{enable_lib_cluster_pkg}
%files -n libpacemaker3-cluster
%defattr(-,root,root)
%{_libdir}/libcrmcluster.so.*
#%license licenses/LGPLv2.1
%doc COPYING ChangeLog
%endif

%files remote
%defattr(-,root,root)
%{_unitdir}/pacemaker_remote.service
%{_sbindir}/rcpacemaker_remote
%{_sbindir}/pacemaker_remoted
%{_mandir}/man8/pacemaker_remoted.8%{ext_man}
#%license licenses/GPLv2
%doc COPYING ChangeLog

%if %{with doc}
%files doc
%defattr(-,root,root)
%doc %{pcmk_docdir}
#%license licenses/CC-BY-SA-4.0
%endif

%files cts
%defattr(-,root,root)
%{python3_sitelib}/cts
%{_datadir}/pacemaker/tests
%{_unitdir}/pacemaker-cts-dummyd@.service
#%license licenses/GPLv2
%doc COPYING ChangeLog

%files -n libpacemaker-devel
%defattr(-,root,root)
%{_includedir}/pacemaker
%{_libdir}/*.so
%if %{with coverage}
%{_var}/lib/pacemaker/gcov
%endif
%{_libdir}/pkgconfig/*.pc
#%license licenses/LGPLv2.1
%doc COPYING ChangeLog

%changelog
* Mon Jul 15 2019 Yan Gao <ygao@suse.com>
- scheduler: wait for probe actions to complete to prevent unnecessary restart/re-promote of dependent resources (bsc#1130122, bsc#1032511)
  * bsc#1130122-0001-Fix-scheduler-wait-for-probe-actions-to-complete-to-.patch
  * bsc#1130122-0002-Test-scheduler-wait-for-probe-actions-to-complete-to.patch
* Fri Jun  7 2019 Yan Gao <ygao@suse.com>
- controller: confirm cancel of failed monitors (bsc#1133866)
  * bsc#1133866-0003-Fix-controller-confirm-cancel-of-failed-monitors.patch
- controller: improve failed recurring action messages (bsc#1133866)
  * bsc#1133866-0002-Log-controller-improve-failed-recurring-action-messa.patch
- libcrmcommon: improve parse_op_key() efficiency (bsc#1133866)
  * bsc#1133866-0001-Refactor-libcrmcommon-improve-parse_op_key-efficienc.patch
- libcrmcommon: return error when applying XML diffs containing unknown operations (bsc#1127716)
  * bsc#1127716-0003-Fix-libcrmcommon-return-error-when-applying-XML-diff.patch
- libcrmcommon: avoid possible use-of-NULL when applying XML diffs (bsc#1127716)
  * bsc#1127716-0002-Fix-libcrmcommon-avoid-possible-use-of-NULL-when-app.patch
- libcrmcommon: correctly apply XML diffs with multiple move/create changes (bsc#1127716)
  * bsc#1127716-0001-Fix-libcrmcommon-correctly-apply-XML-diffs-with-mult.patch
* Wed May  1 2019 Yan Gao <ygao@suse.com>
- controller: avoid memory leak when duplicate monitor is scheduled
  * 0001-Low-controller-avoid-memory-leak-when-duplicate-moni.patch
- libcrmcommon: return proper code if testing pid is denied (bsc#1131353, bsc#1131356)
  * bsc#1131353-bsc#1131356-0009-Low-libcrmcommon-return-proper-code-if-testing-pid-i.patch
* Tue Apr 30 2019 Yan Gao <ygao@suse.com>
- libcrmcommon: avoid use-of-NULL when checking whether process is active (bsc#1131353, bsc#1131356)
  * bsc#1131353-bsc#1131356-0008-Fix-libcrmcommon-avoid-use-of-NULL-when-checking-whe.patch
- tools: run main loop for crm_resource clean-up with resource (bsc#1140519)
  * bsc#1140519-0001-Fix-tools-crm_resource-C-should-wait-for-all-replies.patch
* Thu Apr 18 2019 Yan Gao <ygao@suse.com>
- controld: fix possible NULL pointer dereference (bsc#1131353, bsc#1131356)
  * bsc#1131353-bsc#1131356-0007-Med-controld-fix-possible-NULL-pointer-dereference-1.1.patch
- pacemakerd vs. IPC/procfs confused deputy authenticity issue (CVE-2018-16877, bsc#1131356) (CVE-2018-16878, bsc#1131353)
  * bsc#1131353-bsc#1131356-0002-High-pacemakerd-vs.-IPC-procfs-confused-deputy-authe.patch
  * bsc#1131353-bsc#1131356-0003-High-pacemakerd-vs.-IPC-procfs-confused-deputy-authe.patch
  * bsc#1131353-bsc#1131356-0004-High-pacemakerd-vs.-IPC-procfs-confused-deputy-authe-1.1.patch
  * bsc#1131353-bsc#1131356-0005-High-pacemakerd-vs.-IPC-procfs-confused-deputy-authe.patch
  * bsc#1131353-bsc#1131356-0006-High-pacemakerd-vs.-IPC-procfs-confused-deputy-authe-1.1.patch
- libservices: fix use-after-free wrt. alert handling (CVE-2019-3885, bsc#1131357)
  * bsc#1131357-0001-High-libservices-fix-use-after-free-wrt.-alert-handl.patch
- pacemakerd: only one active process check needed
  * 0001-Low-pacemakerd-only-one-active-process-check-needed.patch
- Shutdown corosync after a fatal error
  * 0001-Shutdown-corosync-after-a-fatal-error.patch
* Fri Mar 29 2019 Yan Gao <ygao@suse.com>
- libcrmcluster: avoid use-of-NULL when searching for remote node (bsc#1128772)
  * bsc#1128772-0001-Fix-libcrmcluster-avoid-use-of-NULL-when-searching-f.patch
* Tue Mar 12 2019 Yan Gao <ygao@suse.com>
- scheduler: cl#5301 - respect order constraints when relevant resources are being probed (bsc#1117934, bsc#1128374)
  * bsc#1117934-0001-Fix-scheduler-cl-5301-respect-order-constraints-when.patch
  * bsc#1117934-0002-Test-scheduler-cl-5301-respect-order-constraints-whe.patch
  * bsc#1117934-0003-Test-scheduler-cl-5301-respect-order-constraints-whe.patch
* Thu Jan 31 2019 ygao@suse.com
- CTS: really don't require nodes to be specified if listing tests (bsc#1114840)
  * bsc#1114840-0001-Test-CTS-really-don-t-require-nodes-to-be-specified-.patch
* Thu Jan 24 2019 ygao@suse.com
- cts: temporarily disable any enabled cluster serivces when running remote tests
  * 0002-Test-cts-temporarily-disable-any-enabled-cluster-ser.patch
- cts: service counts as enabled only if it's explicitly enabled
  * 0001-Test-cts-service-counts-as-enabled-only-if-it-s-expl.patch
* Mon Jan 14 2019 ygao@suse.com
- cts-exec: still run the tests for the other resource classes even without python systemd bindings (bsc#1121808)
  * bsc#1121808-0001-Test-cts-exec-still-run-the-tests-for-the-other-reso.patch
* Tue Jan  8 2019 ygao@suse.com
- CTS: ignore monitor failures when testing remote node fencing
  * 0002-Test-CTS-ignore-monitor-failures-when-testing-remote.patch
- CTS: lower remote connection failure detection time
  * 0001-Test-CTS-lower-remote-connection-failure-detection-t.patch
- cts: use bash in the pacemaker-cts-dummyd
  * 0001-Test-cts-use-bash-in-the-pacemaker-cts-dummyd.patch
- cts: clear constraints on cluster nodes (bsc#1121272)
  * bsc#1121272-0003-Test-cts-clear-constraints-on-cluster-nodes.patch
- cts: resume any possibly frozen pacemaker_remoted when cleaning up the test (bsc#1121272)
  * bsc#1121272-0002-Test-cts-resume-any-possibly-frozen-pacemaker_remote.patch
- cts: simulate failure of pacemaker_remoted by freezing it with SIGSTOP (bsc#1121272)
  * bsc#1121272-0001-Test-cts-simulate-failure-of-pacemaker_remoted-by-fr.patch
- CTS: don't require nodes to be specified if only listing tests (bsc#1114840)
  * bsc#1114840-0001-Test-CTS-don-t-require-nodes-to-be-specified-if-only.patch
- cts: set default number of iterations to 1
  * 0001-Test-cts-set-default-number-of-iterations-to-1.patch
* Tue Oct 16 2018 ygao@suse.com
- fenced: Handle fencing requested with nodeid by utilizing the membership cache of known nodes (bsc#1094208, bsc#1107270, bsc#974108)
  * bsc#1094208-0002-Refactor-fenced-Handle-fencing-requested-with-nodeid.patch
- controld: able to manually confirm unseen nodes are down (bsc#1094208, bsc#1107270)
  * bsc#1094208-0001-Fix-controld-able-to-manually-confirm-unseen-nodes-a.patch
* Wed Jun  6 2018 jengelh@inai.de
- Add missing %%pre section for cts
* Fri May 18 2018 ygao@suse.com
- spec: Install /etc/pacemaker directory for storing authkey file (bsc#1082883)
- spec: unify quoting in {pre,post}* scriptlets' action soliciting
- spec: add a simple retention of pre-existing log move targets
- XML: upgrade-2.10.xsl: resource meta_attributes: tweak diagnostic msg
  * pacemaker-XML-upgrade-2.10.xsl-resource-meta_attributes-tweak-diagnostic-msg.patch
- XML: upgrade-2.10.xsl: re-apply on scheduler CTS test cases
  * pacemaker-XML-upgrade-2.10.xsl-re-apply-on-scheduler-CTS-test-cases.patch
- XML: upgrade-2.10.xsl: resource meta_attributes: validity conformance
  * pacemaker-XML-upgrade-2.10.xsl-resource-meta_attributes-validity-conformance.patch
* Mon May 14 2018 ygao@suse.com
- execd: avoid memory leak when testing remote key
  * pacemaker-execd-avoid-memory-leak-when-testing-remote-key.patch
- cts-scheduler: avoid unsupported usage of requires
  * pacemaker-cts-scheduler-avoid-unsupported-usage-of-requires.patch
- controld: avoid memory leak when synthesizing failure
  * pacemaker-controld-avoid-memory-leak-when-synthesizing-failure.patch
- XML: upgrade-2.10.xsl: resource meta_attributes: isolation* items
  * pacemaker-XML-upgrade-2.10.xsl-resource-meta_attributes-isolation-items.patch
- XML: upgrade-2.10.xsl: make diagnostics more direct wrt. context
  * pacemaker-XML-upgrade-2.10.xsl-make-diagnostics-more-direct-wrt-context.patch
- XML: upgrade-2.10.xsl: remaining "marking" space with op meta_attributes
  * pacemaker-XML-upgrade-2.10.xsl-remaining-marking-space-with-op-meta_attributes.patch
- XML: upgrade-2.10.xsl: simplify 2/2: HelperIdentity, no INNER-RECURSION
  * pacemaker-XML-upgrade-2.10.xsl-simplify-2-2-HelperIdentity-no-INNER-RECURSION.patch
- XML: upgrade-2.10.xsl: simplify 1/2: resource instance_attributes
  * pacemaker-XML-upgrade-2.10.xsl-simplify-1-2-resource-instance_attributes.patch
- XML: regression.sh: modularize "XSLT processor", allow substitutes
  * pacemaker-XML-regression.sh-modularize-XSLT-processor-allow-substitutes.patch
- tools: improve error messages from crm_resource --move
  * pacemaker-tools-improve-error-messages-from-crm_resource---move.patch
- tools: use output redirection correctly in crm_standby
  * pacemaker-tools-use-output-redirection-correctly-in-crm_standby.patch
- tools: handle multiple values properly in crm_attribute
  * pacemaker-tools-handle-multiple-values-properly-in-crm_attribute.patch
- tools: bash portability issue in crm_failcount
  * pacemaker-tools-bash-portability-issue-in-crm_failcount.patch
- libcrmservice: don't consider a cancelled recurring operation as failed
  * pacemaker-libcrmservice-dont-consider-a-cancelled-recurring-operation-as-failed.patch
- tools: cibsecret --help/--version doesn't require cluster to be running (bsc#1102915)
  * bsc#1102915-pacemaker-tools-cibsecret---help--version-doesnt-require-cluster-to-be-running.patch
- spec: package cts-exec-helper with main package instead of -cli
- spec: move old logs after upgrade
- scheduler: improve failed op message
  * pacemaker-scheduler-improve-failed-op-message.patch
- libcrmservice: find absolute paths when used with "service:"
  * pacemaker-libcrmservice-find-absolute-paths-when-used-with-service.patch
- libcrmservice: separate LSB-specific code into own source files
  * pacemaker-libcrmservice-separate-LSB-specific-code-into-own-source-files.patch
- execd: handle systemd actions correctly when used with "service:"
  * pacemaker-execd-handle-systemd-actions-correctly-when-used-with-service.patch
* Wed May  9 2018 ygao@suse.com
- contoller,scheduler: guard hash table deletes (bsc#1136712)
  * pacemaker-contoller-scheduler-guard-hash-table-deletes.patch
- controller: don't abort after delay if we're no longer DC
  * pacemaker-controller-dont-abort-after-delay-if-were-no-longer-DC.patch
- libcrmcommon,pacemakerd: kernel task name is at most 15 characters
  * pacemaker-libcrmcommon-pacemakerd-kernel-task-name-is-at-most-15-characters.patch
- io.c: restore -Werror buildability, put conversion specifier last
  * pacemaker-io.c-restore--Werror-buildability--put-conversion-specifier-last.patch
* Tue May  8 2018 ygao@suse.com
- libcrmcommon: avoid memory leak on failed IPC send
  * pacemaker-libcrmcommon-avoid-memory-leak-on-failed-IPC-send.patch
- daemons: improve connection loss messages
  * pacemaker-daemons-improve-connection-loss-messages.patch
- libcrmcommon: improve connection loss message
  * pacemaker-libcrmcommon-improve-connection-loss-message.patch
- pacemaker_remote: correct documentation URL in systemd unit file
  * pacemaker-pacemaker_remote-correct-documentation-URL-in-systemd-unit-file.patch
- libcrmcommon: check file/directory writability better
  * pacemaker-libcrmcommon-check-filedirectory-writability-better.patch
- spec: no more buildroot XML to modify
* Wed May  2 2018 ygao@suse.com
- Update to version 1.1.18+20180430.b12c320f5:
  * XML: upgrade-2.10.xsl: fix "mark space" issue (bsc#1091661)
* Sat Apr 28 2018 ygao@suse.com
- Update to version 1.1.18+20180427.a34ccd926:
- crmd: avoid double free after ACL rejection of resource delete
- lib: Changed to lowercase comparison.
- all: correct misspellings
- controld: remove deprecated configdir parameter
- controld: deprecate and ignore configdir parameter
- controld: consistently indent with spaces instead of tabs
- libcrmcommon: don't record pending notify actions as completed
- crmd: improve messages when a node is unexpectedly lost
- cib: improve shutdown messages
- cts-regression: allow specifying to run multiple tests again (bsc#1091360)
* Wed Apr 18 2018 ygao@suse.com
- Update to version 1.1.18+20180417.24df451b5:
- alerts: Delete redundant code.
- liblrmd: cast time_t to long long when printing
- cts: separate dummy systemd service into separate files
  * Drop obsolete fate-323526_pacemaker-tests-shebang-python3.patch
- crm_diff: rhbz#1561617 - Ignore attribute placement when comparing in 'cib' mode
- spec: remove reference to long-gone file
- spec: mark -cts & -doc packages as noarch
- spec: fix malformed conditional macros for systemd-less cases
- alerts: Change timestamp of Alert of snmp.
* Thu Apr 12 2018 ygao@suse.com
- Update to version 1.1.18+20180411.2f77f4922:
- libcrmcommon: free signal triggers when cleaning up mainloop
- libcrmcommon: fix memory leak in schema workaround
- fencing: avoid memory leaks when freeing remote operation
- fencing: free dynamic memory at stonithd shutdown
- crmd: delete resource from lrmd when appropriate (bsc#1117381)
- Test: rhbz#1565187 - Ensure failures that cause fencing are not removed until after fencing completes
- rhbz#1565187 - Ensure failures that cause fencing are not removed until after fencing completes
* Mon Apr  9 2018 ygao@suse.com
- Update to version 1.1.18+20180406.633845120:
- libcrmcommon: add a byte to pid file holder
- attrd,cib,libcrmcommon: avoid %%z
- crmd: avoid memory leak when synthesizing operation result
- tools: avoid memory leak on invalid resource
- crmd: log rc code as extended information
- cib: avoid file descriptor leak on temporary file creation
- pengine: avoid redundant test
- libcrmcommon: handle compression failures properly
- libcrmcommon: improve empty string check
- various: improve NULL checks
- libcrmcommon: improve patch xpath searches
- libcrmcommon,tools: use format strings appropriate to variables
- libcrmcommon: use correct argument type for duration
- libcrmcluster: avoid potential use-of-NULL
- libcrmcommon,libstonithd: avoid resource leaks
- tools: get sensor lun in ipmiservicelogd before using it
- schema upgrade: temporary fix to avoid crash on newly present text
* Fri Apr  6 2018 ygao@suse.com
- Update to version 1.1.18+20180406.ce623681e:
- fencing: convert fence_legacy to python
- fencing: fix typos in messages
* Fri Apr  6 2018 ygao@suse.com
- Update to version 1.1.18+20180406.18fe1cc2b:
- XML: upgrade-2.10.xsl: add transform for automatic upgrades to latest schema
- Log: establish correct character string literals also with qb_logt sink
- pengine: fix swapped warning message arguments leading to segfault (bsc#1090538)
- cts-pengine: add regression test for notifications for unrunnable actions
- cts-pengine: update regression tests for notification changes
- rhbz#1545449 - Do not perform notifications for events we know wont be executed
- bundle: Added add-host option.
- liblrmd: add API function for new lrmd op
- lrmd: add new lrmd op to list recurring ops
- spec: require corosync >= 2.0.0
- crmd,libcrmcommon,libpe_status: guint can't be negative
- xml: Allow local "kind" in resource_set within rsc_order (bsc#1085515)
- Pacemaker Explained: "symmetrical" defaults to "false" for serialize orders (bsc#1085515)
- pengine: "symmetrical" defaults to "false" for serialize orders (bsc#1085515)
- pengine: Avoid potential use-of-NULL in unpack_simple_rsc_order() (bsc#1085515)
- cts-pengine: add new regression test for interval handling
- libpe_status: handle ISO8601 intervals when checking for blocking failures
- pengine: properly cancel recurring monitors
- pengine: improve recurring operation messages
- pengine: check for duplicate intervals properly
- libcrmcommon: avoid misuse of crm_get_msec()
- pengine: treat reconnect_interval more consistently with action intervals
- libpe_status: use default timeout rather than 0 if timeout spec is bad
- libpe_status: use correct default timeout for monitors
* Fri Mar 23 2018 ygao@suse.com
- Update to version 1.1.18+20180322.d37067b2a:
- spec: Make sure shadow package is installed before adding user and group
* Tue Mar 13 2018 ygao@suse.com
- Update to version 1.1.18+20180313.2c83c6872:
- cts-pengine: add regression test for changing bundle replica count
- libpe_status: handle unique bundle children correctly
* Tue Mar 13 2018 ygao@suse.com
- Update to version 1.1.18+20180312.31c732adc:
- spec: make shadow dependency explicit
- spec: drop requirements for bison and flex
* Sat Mar 10 2018 ygao@suse.com
- Update to version 1.1.18+20180309.e51687162:
- crmd,liblrmd,libcrmcommon: improve remote node disconnection logs
- libcrmcommon: add function to get text equivalent of client type
- crmd: always write faked failures to CIB whenever possible
- liblrmd: add function to create resource info structure
- crmd: functionize setting fake operation status
- crmd: always assert when operation can't be created
- crmd: avoid core dump if remote connection doesn't exist
- crmd: improve lrmd failure handling
- crmd: return rich error codes from get_lrm_resource()
- crmd: match only executed down events
- crmd: functionize pieces of do_lrm_invoke()
- crmd: don't abort for v2 diff LRM refresh if actions pending
- crmd: validate CIB diffs better
* Wed Mar  7 2018 ygao@suse.com
- Update to version 1.1.18+20180305.9cd0f6cb8:
- libcrmcommon: avoid memory leak when schema transform not found
- tools: warn if crm_resource --wait called in mixed-version cluster
- Install /etc/pacemaker directory for storing authkey file (bsc#1082883)
* Wed Feb 28 2018 ygao@suse.com
- Update to version 1.1.18+20180226.f788652cf:
- crmd: log transition ID when aborting
- crmd: always log unmatched down events at least at debug level
- pengine: deprecate require-all in rsc_order (fate#324508)
- libpe_status: deprecate stonith-action=poweroff (fate#324508)
- tools: already latest schema is not failure for cibadmin --upgrade
- libcrmcluster: prefer corosync name over ring0_addr (fate#324508)
- spec: add gcc to BuildRequires
- attrd: Synchronize attributes held only on own node.
* Fri Feb 23 2018 ygao@suse.com
- Build: Ship cibsecret by pacemaker instead of cluster-glue (bsc#1082456)
  * Drop obsolete pacemaker-cibsecret-tool-temp-disabled.patch
* Tue Feb 20 2018 ygao@suse.com
- Update to version 1.1.18+20180216.ae50b7f5d:
- various: improve string allocation
- XML: upgrade-2.10.xsl: re(drop) rsc_colocation/@score-attribute{,-mangle}
- XML: upgrade-*.xsl: bump the validate-with field from within stylesheet
- XML: upgrade-*.xsl: omit XML declaration
- upgrade-*.xsl: don't be picky about comments, PIs, etc.
* Wed Feb 14 2018 ygao@suse.com
- Update to version 1.1.18+20180213.965befd59:
- libcrmcommon: use /tmp when creating temporary XML file
- tools: crm_master should always work on node attribute
- tools: crm_resource --cleanup couldn't match clone instances
- tools: crm_resource --refresh should ignore --operation and --interval
- crmd: quorum gain should always cause new transition
- rhbz#1527072 - Correctly observe colocation constraints with bundles in the Master role
- Bug rhbz#1519812 - Prevent notify actions from causing --wait to hang
- libpe_status: recover after failed demote when appropriate
- lrmd: always use most recent remote proxy
- libpe_status: limit resource type check to primitives
- PE: correct mispelled constant
- PE: Ensure stop operations occur after stopped remote connections have been brought up
- PE: Remote connection resources are safe to to require only quorum
- PE: Only allowed nodes need to be considered when ordering resource startup after _all_ recovery
- PE: Ordering bundle child stops/demotes after container fencing causes graph loops
- PE: Passing boolean instead of a pointer
* Sat Feb 10 2018 ygao@suse.com
- Update to version 1.1.18+20180209.7acb22379:
- use proper way to make output files executable
- spec: move lrmd_test to cli package
- spec: make log directories owned by cli package
- spec: move all test data into cts package
- pengine: move regression test to cts as cts-pengine
- lrmd: move regression test to cts as cts-lrmd
- fencing: move regression test to cts as cts-stonithd
- tools: move CLI regression test to cts as cts-cli
- rename top-level testing files and move to cts directory
- tools: drop crmadmin -i and -d options (fate#324508)
* Fri Feb  9 2018 ygao@suse.com
- Update to version 1.1.18+20180208.f6a261987:
- Feature: crmd: modify feature set handling
* Wed Feb  7 2018 ygao@suse.com
- Update to version 1.1.18+20180205.b44c57e35:
- pengine,doc,tools: rename "master score" to "promotion score" (fate#324508)
- libpe_status: rename bundle 'masters' to 'promoted-max' (fate#323415)
- pengine,libpe_status: rename master-{max,node-max} to promoted-* (fate#324508)
- various: merge clone resource type and master/slave resource type (fate#324508)
- attrd,pacemakerd,libcrmcommon: make "Exiting" last message
- don't use corosync logging settings (fate#324508)
- crmd,libpe_rules: drop support for notification-agent/recipient
- tools: improve crm_failcount exit code usage
* Tue Jan 30 2018 ygao@suse.com
- Update to version 1.1.18+20180129.c801ab11e:
- allow configuring specific python intepreter version (fate#323526)
  * Drop obsolete fate-323526_pacemaker-pacemaker-configure-AM_PATH_PYTHON-python3.patch
- use auto-configured python executable in python shebangs (fate#323526)
  * Update fate-323526_pacemaker-tests-shebang-python3.patch
- xml: drop score-attribute and score-attribute-mangle
- pengine: avoid misuse of function parameter
- libcrmservice,pacemakerd: improve privilege dropping
* Sat Jan 20 2018 ygao@suse.com
- Update to version 1.1.18+20180119.9146c3c20:
- crmd: Avoid double-removal of glib event source on stopping
* Fri Jan 19 2018 ygao@suse.com
- Update to version 1.1.18+20180118.9c3f7a49c:
- libcrmcommon: put exit/return handling in own source/header files
- Build: bump build dependencies
- Rebase:
  * pacemaker-Wno-format-signedness.patch
* Thu Jan 18 2018 ygao@suse.com
- configure: Check for python3 with AM_PATH_PYTHON (fate#323526)
  * fate-323526_pacemaker-pacemaker-configure-AM_PATH_PYTHON-python3.patch
* Sat Jan 13 2018 ygao@suse.com
- Update to version 1.1.18+20180112.bd7115b8c:
- tools: improve help text
- libpe_status: deprecate restart-type and role_after_failure
* Wed Jan 10 2018 ygao@suse.com
- Update to version 1.1.18+20180109.57d48a1b1:
- libcluster,libcrmcommon: improve BZ2 error messages
- all: use consistent exit status codes
- libcrmcommon,tools: improve XML write error handling
- stonithd,libcrmcommon: auto-calculate stonith-watchdog-timeout when requested (fate#324508)
- logrotate: switch user when rotating logs
* Tue Jan  9 2018 ygao@suse.com
- cts: Operate pacemaker service on startup to prevent triggering StopWhenUnneeded of corosync service
  * pacemaker-cts-StartCmd.patch
* Fri Jan  5 2018 ygao@suse.com
- Update to version 1.1.18+20180104.7ba28d854:
- tools: improve crm_standby option handling
- tools: improve crm_standby help and error messages
- tools: improve crm_master option handling
- tools: improve crm_master help and error messages
- tools: remove deprecated stonith_admin option (fate#324508)
- tools: remove deprecated crm_verify option (fate#324508)
- tools: remove deprecated crm_attribute --node-uuid option (fate#324508)
- tools: avoid using deprecated options
- tools: remove deprecated crm_resource options (fate#324508)
- libpe_status: use consistent monitor for implicit remotes
- all: overhaul log locations (fate#324508)
* Wed Jan  3 2018 ygao@suse.com
- spec: Switch dependencies from python to python3 (fate#323526)
- tests: Switch shebang from /usr/bin/python to /usr/bin/python3 (fate#323526)
  * fate-323526_pacemaker-tests-shebang-python3.patch
* Tue Jan  2 2018 bliu@suse.com
- Update to version 1.1.18+20180101.494eacba4:
- migrate cts to python3 (fate#323526)
* Sat Dec 23 2017 ygao@suse.com
- Update to version 1.1.18+20171221.c91a650ec:
- libcrmcommon: drop special handling of pre-1.1.7 failed recurring op history
- libcrmcommon: drop special handling of pre-1.1.4 migration history entries
- crmd: drop support for DCs that don't support throttling
- cib,libcrmcommon: drop support for PCMK_legacy variable
* Fri Dec 22 2017 ygao@suse.com
- libcrmcluster: use crm_strdup_printf() instead of calloc()
- attrd: avoid small memory leak at start-up
- systemd unit files: restore DBus dependency
- libcrmservice: avoid memory leak on DBus error
- pengine: validate more function arguments
- Upstream version cs: 098d557cc495944e1b6ebd9d05b819d6da74825e
* Mon Dec 18 2017 ygao@suse.com
- libpe_status: drop support for "requires" operation meta-attribute (fate#324508)
- tools: crm_resource --cleanup with no resource specified (bsc#1071503)
- tools: crm_resource --cleanup (bsc#1071503)
- crmd,libpe_status: drop support for legacy option aliases (fate#324508)
- libstonithd,libpe_status: drop support for pcmk_poweroff_action (fate#324508)
- libstonithd,libpe_status: drop support for pcmk_arg_map (fate#324508)
- libstonithd,libpe_status: drop support for pcmk_*_cmd (fate#324508)
- libpe_status,libpe_rules: drop support for default-action-timeout (fate#324508)
- libpe_status: use correct default timeout for probes
- libpe_status: drop support for operation meta-attributes in instance_attributes (fate#324508)
- libpe_status: fix precedence of operation meta-attributes
- libpe_status,libpe_rules: remove support for is-managed-default (fate#324508)
- libpe_status,libpe_rules: drop support for default-resource-stickiness (fate#324508)
- crmd: drop support for LRMD_MAX_CHILDREN environment variable (fate#324508)
- tools: remove crm_mon SMTP support (fate#324508)
- tools: remove crm_mon SNMP support (fate#324508)
- lrmd: remove deprecated -r/--dummy command-line option (fate#324508)
- tools: crm_resource --cleanup for non-primitive resources (bsc#1071503)
- pengine: unfence before probing or starting fence devices
- Upstream version cs: 4528eb3b726197ab077243ab923ed291473f0ed7
* Thu Nov 30 2017 ygao@suse.com
- attrd: ensure node name is broadcast at start-up (CLBZ#5330)
- Upstream version cs: 407ded8de381543e71c5b94b3ade296fcfd2c828
* Thu Nov 30 2017 ygao@suse.com
- libpe_status: remove support for default-resource-failure-stickiness (fate#324508)
- libpe_status: remove support for resource-failure-stickiness (fate#324508)
- various: remove support for pre-Pacemaker-1.0 CIB XML (fate#324508)
- libpe_status,tools: remove support for legacy ticket state entries (fate#324508)
- various: remove isolation wrapper support (fate#324508)
- systemd unit files: enable TasksMax=infinity (bsc#1028138, bsc#1066710)
  * Drop obsolete bug-1028138_pacemaker-pacemaker.service-TasksMax.patch
- Upstream version cs: 53a3fe14b15b087bbde9ccb524d11d0a413cc6e9
* Wed Nov 29 2017 ygao@suse.com
- RA: NodeUtilization RA is now shipped by resource-agents package (bsc#1070347)
  * Drop bug-1015842_pacemaker-NodeUtilization-RA.patch
* Wed Nov 29 2017 ygao@suse.com
- crmd: default record-pending to TRUE (fate#324508)
- tools: enable new crm_resource --cleanup/--refresh behavior (fate#324508)
- Upstream version cs: f36ad364748880815bf00151c516a1f2deae2fed
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Mon Nov 20 2017 ygao@suse.com
- Update to version 1.1.18
- libpe_status: always use default key location with bundles
- attrd,stonithd: more efficient regular expression parsing
- libpe_status: avoid potential NULL dereference
- tools: use proper variable in message from crm_resource -g
- tools: use uber-parent for crm_resource -a/-A
- tools: use g_main_loop_is_running() properly
- libpe_status: monitors are rescheduled, not reloaded
- crmd: determine restart/private digests correctly
- systemd: add TasksMax comment to pacemaker_remote unit (bsc#1028138, bsc#1066710)
- tools: make regression test insensitive to line number changes
- pengine,tools,libpe_status: avoid unnecessary use of pe_find_current
- pacemaker.service: Recommend not to limit tasks (bsc#1028138, bsc#1066710)
  * Update bug-1028138_pacemaker-pacemaker.service-TasksMax.patch
- tools: set the correct OCF_RESOURCE_INSTANCE env when crm_resource --force-* executes RA
- typo: overriden -> overridden
- portability: the difference of time_t values is given by difftime()
- pengine: avoid not-really-possible use-of-NULL
- PE: Have bundles log to stderr so that 'journalctl -M' works (rkt)
- tools: don't expect reply to failed send
- pengine: use newer Pacemaker Remote terminology
- pengine: memory leak when writing graph to file
- tools: don't reinvent the glib wheel
- tools: implement clean-up dry-run correctly
- pengine: avoid potential use-of-NULL
- Update regression test outputs
- PE: Improved logging of reasons for stop/restart actions
- PE: Allow all resources to stop prior to probes completing
- PE: Correctly defer processing of resources inside containers
- crm_resource: Ensure we wait for all messages before exiting
- crm_resource: Have cleanup operate only on failures
- PE: Have bundles log to stderr so that 'docker logs' works
- PE: Resources are allowed to stop before their state is known everywhere
- PE: Use the node we already have and know isnt NULL
- PE: Flag resources that are acting as remote nodes
- crmd: Scale all cib operation timeouts
- PE: Bare metal remotes _can_ run resources now and must be probed
- PE: Bundles only need to wait for other containers on the same node to be probed
- crmd: Scale timeouts with the number of remotes too
- PE: There is no need for port mapping directives when net=host is specified
- PE: Do not always expire failed operations of nested remotes
- PE: Consolidate REMOTE_CONTAINER_HACK logic
- PE: Exclude resources and nodes from the symmetric_default constraint in some circumstances
- crm_resource: Don't cleanup on nodes not meeting the discovery conditions
- PE: Restore the ability to send the transition graph via the disk if it gets too big
- crm_resource: Prevent disconnection from crmd during cleanup
- PE: Do not probe connection resources until the container is active
- PE: Detailed resource information should include connection resource state
- Tools: Allow crm_resource to operate on anonymous clones in unknown states
- tools: Clean up everywhere if we don't know anything about the resource
- crm_resource: See what cleanup would have done for a saved configuration
- PE: Only pass requests for promote/demote flags onto the bundle's child
- Upstream version cs: 2b07d5c5a908998891c3317faa30328c108d3a91 (Pacemaker-1.1.18)
* Thu Nov  2 2017 ygao@suse.com
- pengine: if ignoring failure, also ignore migration-threshold
- libcrmcommon,liblrmd,lrmd: improve messages for failed remote sends
- libcrmcommon,lrmd: meaningful error codes when sending remote messages
- libcrmcommon: lower watchdog messages when default
- tools: set meta_timeout env when crm_resource --force-* executes RA
- fencing: don't print event twice with stonith_admin --verbose
- fencing: memory leak in stonith_admin --env
- fencing: improve stonith_admin help
- crmd: hard error if remote start fails due to missing key
- libcrmcommon,liblrmd: report meaningful async connection errors
- libcrmcommon: return meaningful error codes to connection callbacks
- libcrmcommon: async connection callback must get negative error codes
- libcrmcommon,liblrmd: improve remote connection messages
- pacemaker_remote: warn if TLS key can't be read at start-up
- lrmd: tweak TLS listener messages
- pengine: don't probe offline or unclean guest nodes (fate#324441)
- agents: ifspeed - Try to detect interface name from ip address.
- pengine: don't keep unique instances on same node
- pengine: improve messages when assigning resources to nodes
- Upstream version cs: 23be51236edc34477a99d6979bc0e2cc1e1a7684
* Tue Oct 24 2017 ygao@suse.com
- libpe_status: avoid use-after-free (again)
- lrmd: don't reject protocol 1.0 clients (bsc#1009076)
- tools: print descriptive messages for OCF exit code
- tools: differentiate trace log level for RAs
- tools: show RAs debug logs only when verbose mode for crm_resource --force-*
- tools: suppress an invalid error message for crm_resource --force-* options
- pengine: don't schedule reload and restart in same transition
- libcrmservice: list systemd agents alphabetically
- libcrmcommon: add function to sort list alphabetically
- pengine: new regression test for unrecoverable remote connection
- libcrmservice: avoid infinite loop on bad DBus reply
- libcrmservice: list systemd unit files, not only active units
- libpe_status: print container type in lowercase when outputting XML
- tools: re-enable crm_resource --lifetime option (CLBZ#5251, bsc#950128)
- libcrmcluster: improve error checking when updating node name
- tools: fix crm_resource --why output when resource and node are specified
- libcrmservice: parse LSB long description correctly
- libcrmservice: follow LSB standard for header block more strictly
- libcommon: Erase old exit_reason
- Upstream version cs: 36d2962a8613322fc43d727d95720d61a47d0138
* Fri Oct 13 2017 ygao@suse.com
- crm_mon: error-exit child if execl should return
- crmd: avoid memory leak when caching meta-data
- tools: ensure crm_resource data set is initialized
- libcib: ensure xpath result isn't empty
- tools: missing break statement in attrd_updater
- libcrmcommon: check sscanf() result when parsing schema version
- tools: check sscanf return value when parsing failed op list
- tools: treat bundles with replicas like clones when restarting
- tools: allow crm_resource to be called without arguments
- tools: update regression test for recent message changes
- tools: improve crm_resource --show-metadata error messages (CLBZ#5287)
- libcrmcommon: add functions for using agent specifications
- tools: improve crm_resource help (CLBZ#5251, bsc#950128)
- libcrmcommon: improve cluster option parsing
- Upstream version cs: 27b631162104d90e944cbc107c2d46e983f94ca7
* Fri Oct  6 2017 ygao@suse.com
- spec: Disable deprecated crm_mon SNMP/ESMTP support (configure alerts instead)
* Fri Oct  6 2017 ygao@suse.com
- pengine: add tests for no-quorum-policy=suicide
- libpe_status: properly detect when nodes should suicide
- libpe_status: always log startup-fencing value
- libpe_status: generalize ability to log warning only once
- pengine: reset loss-policy from fence to stop if no fencing
- pengine: avoid use-of-NULL when unpacking tickets
- tools: ensure crm_resource works if no command is specified
- libpe_status: validate no-quorum-policy=suicide correctly
- tools: use-after-free in crm_diff
- RA: ClusterMon - Correctly handle "update" parameter
- attrd: "peer peer loss" -> "peer loss"
- Tools:Refactored Crm_resource to have proper assignments for require_*
- Upstream version cs: c4a09cfec99570a2509831f4b8974457dcdb1af6
* Fri Sep 29 2017 ygao@suse.com
- Log: Reduce verbosity of developer logging
- PE: We most definitely need to probe connection resources
- PE: Ensure the bundle nodes get set with the correct discovery mode
- PE: Implement probing of container remote nodes (fate#324441)
- attrd: Tweak log messages for clarity
- crm_resource: Do not send history erasure commands for nodes where this is none
- PE: Resources in bundles should also respect failcounts
- PE: Do not send notifications to unclean bundles
- PE: Prevent graph loops when fencing the host out from underneath a bundle
- Tools: Allow bundle resources to read/write master scores based on the same logic as attrd (cf34f4c)
- PE: bundle: Send an additional host list when container-attribute-target=host
- PE: Correctly interpret colocation with bundles
- PE/attrd: Allow bundle resources to read/write attributes based on the physical host rather than the container name
- Upstream version cs: 4328c6a65424d1caf9785107664ec1b7fc824664
* Thu Sep 28 2017 ygao@suse.com
- Rebase:
  * bug-728579_pacemaker-stonith-dev-id.patch
- Fix: -Wformat-truncation=2: prevent format truncation
- snprintf: use correct signedness in print format specifiers
- snprintf: use sizeof(X) as size + prevent off-by-ones
- crmd,libcrmcommon,libcluster,tools: handle PID as string properly
- tools: use right size for string buffer in fake_transition.c
- crm_resource: fix a memleak
- pengine: sprintf -> snprintf
- libcrmcommon: fix possible infloop in buffer_print
- crm_snprintf_offset like parts: fix off-by-ones
- attrd: improve update messages
- stonithd,lrmd,pengine: spelling/formatting corrections
- build: install ifspeed resource agent
- libcrmservices: avoid assert for HB resource with no parameters
- crmd: re-enable local collection of meta-data for remote nodes
- crmd,pengine,libpe_status,libpe_rules: remove support for versioned attributes
- crmd: avoid memory leak when node state is unknown
- crmd: avoid assert if LRM query fails
- libpe_status: more error checking when unpacking bundles
- libpe_status: bundles now respect PCMK_authkey_location
- libcrmcommon,liblrmd,lrmd: validate PCMK_remote_port
- PE: Bundles: add support for rkt bundle type
- libcrmcommon,libpe_rules: unpack new alert filter syntax
- xml: allow specifying alertable events
- Fix: a proper calculation of a speed in case of hfi1 for ifspeed RA.
- pengine: detect proper clone name at startup
- pengine: don't ignore permanent master scores at startup
- pengine: handle resource migrating behind a migrating remote connection
- stonith-ng: advertise pcmk_on_action via metadata
- liblrmd: Make sure the operation of a remote resource returns if setup of the key fails (bsc#1053463)
- libcrmcommon,pengine: improve log messages
- PE: only print to stdout if run from command line
- crmd: eliminate size restriction on node state xpath
- pengine: add regression test for remote connect interval wait
- pengine: re-enable unrecoverable remote fencing
- pengine: Make sure calculated resource scores are consistent on different architectures (bsc#1054389)
- PE: Allow resources inside bundles to receive notifications
- PE: Update unfencing device change test output
- attrd,crmd: erase attributes at attrd start-up, not first join
- attrd: accept connections only after CIB connection is active
- attrd: make CIB connection function self-contained
- attrd: improve messages
- stonith-ng: make fencing-device reappear properly after reenabling
- crmd: don't need meta-data after resource is deleted
- crmd: only get meta-data for OCF and stonith agents
- libcrmcommon: generate agent key without :: if no provider
- pengine: avoid fence loop for remote nodes
- attrd: don't log error if CIB doesn't have an alerts section
- PE: Only retrigger unfencing on nodes that ran operations with the old parameters
- PE: Output resource changes in a friendlier format
- PE: Attempt to indicate why resources are changing state
- Mechanism for recording why an action is required
- Support unfencing of remote nodes
- PE: Ignore optional unfencing events and report the fencing type
- Upstream version cs: 20cffae1e9c64217339173c197edac8612ad02b9
* Mon Jul 31 2017 ygao@suse.com
- logging: ensure blackbox gets generated on arithmetic error
- crm_mon: overcome crm_system_name no longer influenced with argv
- crm_mon: make CGI bail out on suspicious arguments
- crm_mon: make CGI bail out properly and w/o help screen
- crm_mon: canonical casing of Content-Type CGI header field
- libcrmcommon: handle schema versions properly
- attrd: don't reconnect to lrmd if already connected
- PE: Ensure nested container connections run on the same host
- crmd: send alerts via lrmd
- lrmd: execute alerts as cluster daemon user
- libservices: add ability to specify user to run an action
- libcrmcommon: improve user lookup messages
- extra: correct ClusterMon metadata
- attrd: avoid memory leak when disconnecting from lrmd
- attrd,tools: avoid memory leaks from use of crm_itoa()
- attrd: be consistent about attr/host logging
- attrd: delay lrmd connect until needed
- attrd: add timestamp to alert just when needed
- attrd: improve log messages
- libcrmcommon,libpe_rules: avoid crash when alerts section has comments
- libcrmcommon: add API call for next named XML child
- liblrmd: only set environment variables with a value
- attrd,liblrmd: handle adding env var at head of list
- lrmd: drain alerts at shutdown
- attrd,lrmd: generate alert sequence number in lrmd
- liblrmd: better trace message when creating command
- stonith-ng: avoid double-free of pending-ops in free_device
- crmd: log correct feature set revision
- PE: update start-failure-is-fatal help
- cib: avoid unnecessary memory allocation
- stonith-ng: add pcmk_delay_base as static base-delay (fate#324488)
- XML: upgrade-1.3.xsl: be explicit about non 1:1 wrt. ACL @attributes
- enable upgrade XSLTs to use <xsl:message> meaningfully
- Tools: Added option of --why/Y to crm_resource to inform the status of resources if running or not
- various: fix spelling in messages and comments
- cib: reword trace message
- PE: Prevent use-after-free when creating bundle constraints
- add versioned operations support
- TE: don't bump counters when action or synapse is invalid
- obtain metadata in CRMd via async call
- tools: add version options for cibsecret
- alerts: Support of meta attributes(kind, attribute_name).
- attrd,lrmd,lib: Addition of the transmission function of the attribute alert to attrd.
- extra: Change alert_xxx.sh.sample for attribute alerts.
- extra: Change PCMK-MIB.txt for attribute alerts.
- XML: upgrade-1.3.xsl: simplify branching
- XML: upgrade-1.3.xsl: drop superfluous branching
- XML: upgrade-1.3.xsl: simplify "weak identity" transform rules
- XML: upgrade-1.3.xsl: easy simplifications + redundant declarations drop
- re-enable versioned attributes
- Upstream version cs: d134f83b4f0188f6d7cd381c8cdda1a2a7c38bd5
* Wed Jul 19 2017 ygao@suse.com
- Update to version 1.1.17
- PE: Ensure unrecoverable remote nodes are fenced even if no resources can run on them
- iso8601: strftime needs fully populated struct tm (bsc#1058844)
- crmd: abort transition whenever we lose quorum
- PE: Ensure bundle nodes and child resources are correctly cleaned up
- PE: Generic ordering for anything with bundles
- PE: Default to non-interleaved bundle ordering for safety
- PE: Functional inter-bundle ordering when either side has no child
- PE: Basic inter-bundle ordering when both sides have children
- PE: Implement bundle ordering
- libpe_status: properly disallow other resources from bundle nodes
- libcib: get remoteness correctly from node status
- libpe_status: avoid memory leaks when creating bundle remote resource
- libpe_status: disallow resources on bundle nodes
- pengine: make checks a little safer
- PE: Clones within bundles may also have notifications enabled
- PE: Correctly implement pe_order_implies_first_printed
- PE: Do not re-add a node's default score for each location constraint
- PE: Bundle location constraints should only apply to the IP and docker resources
- PE: Bundles: Allow clones to be colocated with bundles
- PE: Bundles: Implement colocation of primitives and groups with bundles
- cib,libcib: support option for IPC eviction threshold
- libcib: correctly search for v2 patchset changes
- libcib: always use current values when unpacking config
- libcrmcluster: fix spelling error in error message
- crmd: DC should update stonith fail count before aborting transition
- cib: Broadcasts of cib changes should always pass ACLs check (bsc#1042054)
- Upstream version cs: b36b869ca8fe74caa077c286304f653f0be117ef (Pacemaker-1.1.17)
* Fri Jun  2 2017 ygao@suse.com
- pengine,libpe_status: revisit fencing messages
- PE: Improve logging of node fencing and shutdown
- PE: Fence unrecoverable remote nodes with no resources
- libpe_status: propagate multiple-active=block for bundles
- libpe_status: set parent for bundle components
- attrd: broadcast local overrides of sync'ed attributes
- crmd: attribute write-out not needed with atomic attrd
- PE: Prevent use-after-free when creating bundle constraints
- PE: Ensure remote nodes are fenced when the connection cannot be recovered
- PE: Improved fencing logging
- PE: Assume resources on remote nodes do not need to be restarted until absolutely necessary
- PE: Correctly compare a point with NULL instead of FALSE
- libpe_status: correctly flag remote connection resources
- pengine: improve internal bundle constraints
- pengine: re-phrase trace log for internal constraints
- libpe_status: set #kind to "container" for bundle nodes
- pengine,libpengine: avoid potential use-of-NULL
- pengine: avoid use-of-NULL in bundle without primitive
- libpengine: don't double score when adding first allowed node
- pengine: improve detection of invalid constraints
- PE: Prevent use-of-NULL when expanding containers
- PE: Partially restore 62ed004 to ensure remote connections are available before attempting resource recovery
- stonith-ng: Trigger on constraints added to cib (bsc#1042374)
- Upstream version cs: e47bd5bc77a3d1b38589b3716f5112ed39329e7b
* Mon May 15 2017 ygao@suse.com
- RA: NodeUtilization - Use xl if available (bsc#1015842)
  * Drop obsolete:
  * * bug-1015842_pacemaker-NodeUtilization-RA-1.patch
  * * bug-1015842_pacemaker-NodeUtilization-RA-2.patch
  * * bug-1015842_pacemaker-NodeUtilization-RA-3.patch
  * Add bug-1015842_pacemaker-NodeUtilization-RA.patch
- Drop obsolete pacemaker-lrmd.h-include-libxml.patch
- lrmd,pengine: remove versioned parameters from documentation and tests
- lrmd,pengine: don't support versioned attributes by default
- Containers: Relax docker/remote colocation constraint when appropriate
- Containers: Ensure remote resources are only allocated to full cluster nodes
- lrmd: Ensure verbosity options are handled after crm_log_init()
- pengine: unmanage guest-container puts guest in maintenance
- pengine: unique ids for meta-attributes of guest-connection
- pengine: update regression tests for probes of guest-connections
- pengine: have guest-node connection-resources probed
- crmd: clean up throttle memory on exit
- libcib: avoid use-after-free when deleting CIB connection
- systemd unit files: add dependency on resource-agents-deps
- pengine: Allow use of resource params and meta-params in location rules
- libcrmcommon: avoid evicting IPC client if messages spike briefly
- libcrmcommon: don't delay next flush by more than 5 seconds
- libcib: downgrade ACL status message to trace
- crmd: don't destroy election structure twice
- crmd: avoid use-after-free when disconnecting from CIB
- libcib: functionize destroying op callback table
- crmd,libcrmcommon: update throttle when CPUs are hot-plugged
- crmd: remove I/O load checks
- libcrmcommon: add function to get number of CPU cores
- crmd: functionize checking throttle thresholds
- crmd: functionize setting throttle load target
- CTS: update corosync fail patterns
- crmd: check correct timer for being started
- crmd: improve fencing result message
- lrmd: Have pacemaker-remote reap zombies if it is running as pid 1
- pengine: add test for per-op fail count
- libcrmcommon: filter attributes with '#' from XML fields
- extra: Dummy stop shouldn't fail if monitor is in progress
- extra: use whitespace consistently in Dummy
- crmd: don't fence old DC if it's shutting down as soon-to-be DC joins
- crmd: avoid DC sending offer to itself twice
- crmd: don't restart transition if no fence devices
- crmd: skip restart at (not above) stonith-max-attempts
- crmd: allow clearing all stonith fail counts
- crmd: track stonith fail counts on all nodes
- crmd: forget stonith failures when forgetting node
- crmd: consider target when checking stonith failures
- crmd: check for too many stonith failures only when aborting for that reason
- PE: Remote: Allow remote nodes that start containers with pacemaker remote inside
- fencing: ignore empty 'action' parameter in fence devices
- crmd: fix remove attr_id from update_attr_delegate()
- Fix log showing the node status so that it is easily distinguishable from other logs
- crmd: don't abandon fencing after one "no devices" failure
- libcrmcommon: more useful message if can't open dump file
- libcib: use new convenience function for sanitizing ID
- libpe_status: implement active check for bundles
- tools: update crm_mon RNG schema for bundles
- crmd: add set_join_state()
- crmd: fix line wrapping
- crmd: update_attr_delegate() instead of set_standby()
- PE: Containers: Allow custom docker run commands
- logrotate: rotate pacemaker logs inside bundled containers
- libpe_status: improve bundle docker defaults
- tools: crm_resource should free result if re-running function returns one
- libpe_status: avoid memory leak when counting failures
- crmd: remove functions from crmd_utils.c
- PE: Containers: Ensure replicas_per_host=1 is respected during rediscovery and startup
- libcib: change the format of the state id in set_standby()
- PE: Containers: Allow the internal and external ports to optionally differ
- PE: Containers: Allow custom control ports when using the machine's local address
- crmd: set_standby in first_join
- PE: Bundles: Better support for net=host, allow the pacemaker-remote port to change
- Remote: Allow the port to listen on to be specified on the commandline
- libpe_status: allow more than 254 containers in a bundle
- crmd,liblrmd: handle crmd-local proxy requests properly
- common: Prevention of the double definition.
- pacemaker_remoted: Allow compilation with glib older 2.36
- PE: Containers: Default 'replicas' to the same number of 'masters'
- PE: Containers: Correctly find the right anonymous child resource running in a container
- PE: Clone: Simplified allocation function
- PE: Contaienrs: Better checks when assuming a container will start
- PE: Preferred nodes are only accepted if their scores are equal to the otherwise best candidate
- PE: Containers: Remove containers on termination by default
- PE: Container: Add support for non-default docker networks and supplying external IPs to container resources
- PE: Containers: Allow specifiying the maximum number of peers per host
- PE: Containers: Force a sane hostname
- PE: Containers: Add support for nic and netmask parameters
- PE: container: Parse network and mount options
- PE: Allow the graph to assume container nodes will come up and schedule actions for it
- PE: Force node scores for containerized resources
- PE: Basic allocation of containers
- Core: Track the line number of callers of crm_(set|clear)_bit
- xml: Correctly find the first child element
- PE: Basic container parsing and expansion (fate#323415)
- PE: Correctly test for clone functionality
- Improve recovery when demote fails with OCF_NOT_RUNNING
- Upstream version cs: ce86684f5d0672791e9fd3043a84f0931cdd97ea
* Thu Mar 23 2017 ygao@suse.com
- libcrmcluster,crmd: log join phase as text rather than integer
- pacemaker-remote: pacemaker_remoted shutdown while unmanaged
- tools: disable agent stdout/stderr for crm_resource --validate
- tools: Add "--validate" command to crm_resource
- tools: crm_resource should set OCF_RESKEY_crm_feature_set
- tools: make crm_failcount compatible with per-operation failcounts
- tools: support clearing failure of a single operation with crm_resource -C
- crmd: support clearing failure of a single operation
- crmd: make clearing last failure more efficient
- attrd,libcrmcommon: support clearing failure of a single operation
- attrd,crmd,libraries,tools: track resource failures per-operation
- tools: support crm_failcount -q as advertised
- Upstream version cs: 77ea74d01bcb6b7100e1c7acab0e66e79aceaf8b
* Fri Mar 17 2017 ygao@suse.com
- NodeUtilization: Never set hv_memory to a negative value (bsc#1015842)
  * bug-1015842_pacemaker-NodeUtilization-RA-3.patch
- NodeUtilization: Fix mixed indentation, set executable bit (bsc#1015842)
  * bug-1015842_pacemaker-NodeUtilization-RA-2.patch
- RA: NodeUtilization - Use xl if available (bsc#1015842)
  * Drop obsolete bug-1015842_pacemaker-NodeUtilization-RA.patch
  * Add bug-1015842_pacemaker-NodeUtilization-RA-1.patch
* Fri Mar 17 2017 ygao@suse.com
- spec: Merge the SLE and Factory versions
  * enable_fatal_warnings=0
* Thu Mar 16 2017 ygao@suse.com
- crmd: new cluster option stonith-max-attempts with default value 10 (fate#323417)
- crmd: Change of the log level and addition of uuid.
- crmd: use new attrd op to clear fail counts
- tools: crm_resource -C should clear last-failure
- libcrmcommon: add API for new attrd clear-failure operation
- attrd: add more detail to legacy attrd messages
- attrd: add API for clearing failures
- Upstream version cs: e55d506cc390f0a0335b4ec6e365ea89da30b6b1
* Mon Mar 13 2017 ygao@suse.com
- pacemaker.service: Add presetting TasksMax=4915 (bsc#1028138)
  * bug-1028138_pacemaker-pacemaker.service-TasksMax.patch
* Tue Mar  7 2017 ygao@suse.com
- Build: lrmd: Include libxml/tree.h in lrmd.h
  * pacemaker-lrmd.h-include-libxml.patch
* Mon Mar  6 2017 ygao@suse.com
- libfencing,fencing: properly remap "action" in configuration
- libservices: ensure recurring actions table is created before using
- libservices: improve error messages when creating operation
- libservices: properly detect in-flight systemd/upstart ops when kicking
- libservices: properly cancel in-flight systemd/upstart op
- libservices: handle in-flight case first when cancelling an operation
- libservices: prevent use-after-free when freeing an operation
- libservices: ensure completed ops aren't on blocked ops list
- libcrmcommon: assert if can't generate operation key
- libcrmcommon: improve remote connection polling messages
- crmd: clear failure only for requested node
- crmd: improve message when clearing failures
- pengine,libpe_status: make failcount clearing messages more helpful
- pengine,libpe_status: don't clear same fail-count twice
- cib: properly mark variable as volatile
- libcib: avoid memory leak in query_node_uuid()
- tools: avoid NULL dereference in crm_resource debug message
- cib,libcrmcommon,lrmd: handle IP addresses better in messages
- tools: crm_attribute should prefer node name from environment
- libcrmcommon: Correctly delete XML comments according to their positions (bsc#1024037)
- libcrmcommon: Correctly compare XML comments to prevent crmd from getting into infinite election loop (bsc#1024037)
- crmd,libcrmcluster: minor log message improvements
- tools: avoid deprecated function in notifyServicelogEvent
- libcrmcommon,pengine,tools: pass local node name to resource agents
- use callback instead of sync call
- libcib: make querying node uuid more efficient
- tools: allow regular expression with crm_attribute
- attrd: support regular expressions in legacy attrd
- attrd: support Pacemaker Remote node attributes in legacy attrd
- use status scope to start node in standby mode
- attrd: ignore unsupported requests in legacy attrd
- attrd,crmd: implement peer remove requests in legacy attrd
- crmd: don't clear remote node transient attributes unnecessarily
- crm_mon: protect against non-standard or failing asctime
- libservices(sync): partially prevent killing foreign process
- libservices (sync): ensure no zombie is left behind
- cib: improve re-sync handling
- tools: implement crm_failcount command-line options correctly
- tools: use correct regular expression for fail counts in crm_resource
- cib: never disable legacy mode with corosync 1 stacks
- cib: improve warning when legacy diff fails
- libcrmcommon: ensure filename is not NULL before opening
- crmd: be more resilient when checking an LRM command's "from"
- crmd: improve crmd's LRM-related log messages
- tools: properly ignore version with crm_diff --no-version (bsc#888726)
- Ability to start node in standby (fate#323416)
- Upstream version cs: a7825f4f0a8db272d1ce0b1f93e8044cbcaa5144
* Mon Mar  6 2017 ygao@suse.com
- libservices: properly watch writable DBus handles
- tools: don't reference hidden parameter in crm_resource help text
- Alert: Set SNMP_PERSISTENT_DIR directory for the snmp-trap tool.
- dbus: Prevent lrmd from hanging on dbus calls (bsc#1015264)
- spec: add %%check to run a subset of tests on rpmbuild
- crmd: update cache status for guest node whose host is fenced
- pengine: consider guest node unclean if its host is unclean
- pengine: create a pseudo-fence for guest node recovery
- pengine: guest node fencing doesn't require stonith enabled
- pengine: remove unnecessary assert
- mcp: Correction of the difference in access permission setting.
- stonith_admin: Addition of the list-targets option.
- stonith: Check for missing params in new device and dup
- libservices: treat systemd service reloading as OK (bsc#1059187)
- crmd: increase severity when fencing didn't happen (bsc#1011240)
- rng: Create resources-2.7.rng to update template class validation
- libcrmcommon: Don't report error if the output file isn't syncable
- crmd: bump feature set
- pengine: disable migration for versioned resources
- add versioned parameters support
- Upstream version cs: 2817a2081e9e70e7412f0d0a253495611afab55e
* Mon Mar  6 2017 ygao@suse.com
- wd: Fix to not compare NULL when environment variable is not set
- mcp,pacemaker_remote: order after time-sync
- configure: fix fouled parameter expansion
  * Drop obsolete pacemaker-configure-systemd-detection.patch
- xml: rng: Keep score-attribute{,-mangle} in the existing RelaxNG schema files for graceful upgrades
- Upstream version cs: 94ff4df51a55cc30d01843ea11b3292bac755432 (Pacemaker-1.1.16)
* Mon Mar  6 2017 ygao@suse.com
- RA: NodeUtilization - Use xl if available (bsc#1015842)
  * bug-1015842_pacemaker-NodeUtilization-RA.patch
* Mon Mar  6 2017 ygao@suse.com
- spec: Prevent overwriting existing sysconfig files by conditionally running %%fillup_only (bsc#1022807, bsc#980341)
* Mon Mar  6 2017 ygao@suse.com
- spec: cts brings an RA that needs python-systemd
* Wed Feb 22 2017 dimstar@opensuse.org
- Explicitly own %%{_defaultdocdir}/%%{name}.
* Tue Nov  8 2016 ygao@suse.com
- Revert "Build: configure: make systemd detection akin to + before Upstart one"
  * pacemaker-configure-systemd-detection.patch
- libcrmcommon: fix CVE-2016-7035 (improper IPC guarding) (bsc#1007433)
- sysconfig: minor tweaks (typo, wording)
- various: issues discovered via valgrind and coverity
- attrd_updater: fix usage of HAVE_ATOMIC_ATTRD
- Upstream version cs: b6f251a13fadca0cb74702b0c007a55275c8ea09
* Fri Oct 21 2016 ygao@suse.com
- Rebase:
  * pacemaker-NodeUtilization-RA.patch
- extra: add resource agent for managing a node attribute
- crmd: cl#5185 - Record pending operations in the CIB before they are performed (bsc#1003565)
- ClusterMon: fix to avoid matching other process with the same PID
- mcp: improve comments for sysconfig options
- spec: require libqb >= 0.13.0
- tools: crm_standby --version/--help should work without cluster
- spec: reorganize so %%pre etc. blocks are self-contained
- spec: require python >= 2.6
- spec: comment better
- libpengine: ensure child is not null before looking up value
- libpengine: only log startup-fencing warning once
- Upstream version cs: 722276c442bf023931842313bfe0dfb7d90a7c15
* Mon Sep 26 2016 ygao@suse.com
- pacemaker.service: do not mistakenly suggest killing fenced
- pacemaker.spec: consume "systemdunitdir" via %%_unitdir
- libcrmcommon: report errors consistently when waiting for data on connection (bsc#986644)
- libservices: use DBusError API properly
- remote: Correctly calculate the remaining timeouts when receiving messages (bsc#986644)
- libfencing: report added node ID correctly
- crm_mon: Do not call setenv with null value
- pacemaker_remote: allow remote clients to timeout/reconnect
- pengine: Do not fence a maintenance node if it shuts down cleanly (bsc#1000743)
- install README in doc instead of now-removed AUTHORS file
- ping: Avoid temporary files for fping check (bsc#987348)
- all: clarify licensing and copyrights
- schemas.c: treat CIB with unrecognized validate-with better
- schemas.c: avoid downgrade validate-with in a corner case
- xml.c: better info in cli_config_update on no validation success
- fix infloop when no schema validates on update_validation
- xml.c: internal self-or-less reference inflicted infloop guard
- crmd: Resend the shutdown request if the DC forgets
- ping: Avoid temp files in fping_check  (bsc#987348)
- crmd: Ensure the R_SHUTDOWN is set whenever we ask the DC to shut us down
- crmd: clear remote node operation history only when it comes up
- libcib,libfencing,libtransition: handle memory allocation errors without CRM_CHECK()
- tools: make crm_mon XML schema handle resources with multiple active
- tools: make crm_mon resources section more consistent
- crmd: bump feature set
- pengine: set OCF_RESKEY_CRM_meta_notify_active_* for multistate resources
- LSB init: try to be a little more compliant
- pengine: avoid null dereference in new same-node ordering option
- lrmd,libcluster: ensure g_hash_table_foreach() is never passed a null table
- crmd: don't log warning if abort_unless_down() can't find down event
- lib: Correction of the deletion of the notice registration.
- stonithd: Correction of the wrong connection process name.
- crmd: Keep a state of LRMD in the DC node latest.
- pengine: avoid transition loop for start-then-stop + unfencing
- libpengine: allow pe_order_same_node option for constraints
- pengine: avoid sisyphean score-attribute-mangled parsing
- xml: score-attribute{,-mangle} has no meaning for rsc_colocation
- Upstream version cs: 4cce2b26f6f468c342adb24bf74234a12a0070c2
* Fri Aug 26 2016 ygao@suse.com
- cts: Restart systemd-journald with "systemctl restart systemd-journald.socket" (bsc#995365)
  * bug-995365_pacemaker-cts-restart-systemd-journald.patch
* Fri Jul  8 2016 ygao@suse.com
- libcrmcommon: properly handle XML comments when comparing v2 patchset diffs
- crmd: don't abort transitions for CIB comment changes
- libcrmcommon: log XML comments correctly
- libcrmcommon: remove extraneous format specifier from log message
- crm_mon: Avoid logging errors for any CIB changes that we don't care about (bsc#986931)
- crmd: When node load was reduced, crmd carries out a feasible action.
- Upstream version cs: 58fef06198fef17873d0d2e2d0cc5c7db73c5724
* Fri Jul  1 2016 ygao@suse.com
- ping: Log sensible error when /tmp is full (bsc#987348)
- crm_mon: Do not log errors for the known CIB changes that should be ignored (bsc#986931)
- logging: Enable synchronous logging when blackboxes are enabled
- libpengine: print target role and blocked status in XML output
- tools: add maintenance mode and disabled/blocked resources to crm_mon XML/HTML output
- tools: break up long lines in crm_mon console output
- libservices: include socket units when listing all systemd agents
- fencing: fence_legacy - Search capable devices by querying them through "list" action for cluster-glue stonith agents (bsc#986265)
- extra: correct quoting of timestamp-format in alert-snmp-example
- pengine,tools: Display pending resource state by default when it's available (bsc#986201)
- rng: Allow rsc-pattern in locations for version 2.6
- pengine: Expand regexp references in location constraints
- pengine: Allow to set base score for progressive node health strategy
- systemd: Allow unit names ending in .socket.
- watchdog: Correction to do to change action of the system reboot by fail_fast
- Upstream version cs: 630d0d112092042b6f79c2a02bb442e82fee93ec
* Thu Jun 30 2016 tchvatal@suse.com
- Remove conditionals that are not really needed as they always kept
  the values
- Remove the cman conditional as we do not even have the dependencies
  to build with it in OBS
- Convert deps to pkgconfig style ones and remove deps that are
  not mentioned by the testsuite or the configure.ac
* Wed Jun 22 2016 ygao@suse.com
- Update to version 1.1.15
- crmd: mention that graceful remote shutdowns may cause connection failures (bsc#981489)
- alerts - drop 5min timeout to 30s since it is configurable now
- Bug bz#5292 - crmd: wait for alerts to finish
- libais,libcluster,libcrmcommon,liblrmd: don't use %%z specifier
- alerts: ensure sample alert agents handle undefined recipient
- tools: crm_resource -T option should not be hidden anymore
- PE: Correctly update the dependant actions of un-runnable clones
- alerts: make timestamp-format-string work properly if strftime-escape is the last character
- extra: make alert-file-example cope with spaces in timeformat-string
- attrd,ipc: Prevent possible segfault on exit (bsc#986056)
- alerts: fix SMTP recipient defaulting
- tools: properly handle crm_resource --restart with a resource in a group
- tools: don't assume all resources restart on same node with crm_resource --restart
- tools: avoid memory leaks in crm_resource --restart
- tools: remember any existing target-role when doing crm_resource --restart
- tools: correctly count starting resources when doing crm_resource --restart
- Upstream version cs: e174ec84857e087210b9dacee3318f8203176129 (Pacemaker-1.1.15)
* Tue Jun 14 2016 tchvatal@suse.com
- Clean-up with spec-cleaner
- Drop heartbeat conditions, no heartbeat around
- Sort CMAN conditionals to be actually logical
- Run fdupes to not waste so much space
- Add logrotate to reqs of pacemaker-cli
- Cleanup rpmlintrc to contain only bare needed minimum
- Run basic sanity check in %%check phase
* Tue Jun 14 2016 tchvatal@suse.com
- Drop sysvinit support we now run on sle12+ only
- Cleanup the define conditionals that are never used
- Drop profiling and coverage options it is not enabled by default
  and better to run separately
* Mon Jun 13 2016 ygao@suse.com
- libcrmcommon: really ensure crm_time_t structure is fully initialized by API calls
- extra: correct syntax error in sample alert script
- crmd: avoid timeout on older peers when cancelling a resource operation
- crmd: use proper resource agent name when caching metadata
- crmd: avoid memory leak when sending fencing alert
- liblrmd: avoid memory leak when closing or deleting lrmd connections
- extra: improve determination of successful monitors in SNMP alert script
- tools: avoid memory leak when crm_mon unpacks constraints
- pengine: avoid use-after-free with location constraint + sets + templates
- pengine: better error handling when unpacking sets in location constraints
- pengine: avoid memory leak when invalid constraint involves set
- Build: rename sample alert scripts and install them in datadir
- pengine : Correction of the record judgment of the failed information.
- Upstream version cs: dd46368eead0d756735216a4bc765466b99274fc
* Tue Jun  7 2016 ygao@suse.com
- alert-helpers: some fixes in pcmk_smtp_helper.sh
- libpengine: log message when stonith disabled, not enabled
- pengine: only set unfencing constraints once
- tools: don't require node to be known to crm_resource when deleting attribute
- libcrmcommon: ensure crm_time_t structure is fully initialized by API calls
- attrd: don't leak memory when returning due to malformed update request
- crmd: always free result of crm_itoa()
- xml: adapt crm_mon.rng per recent reorder of the summary elements
- Upstream version cs: 1a05449500f015414b6df68b6d4feb64b713f533
* Fri Jun  3 2016 ygao@suse.com
- Rebase:
  * bug-977201_pacemaker-controld-self-fencing.patch
- pengine: properly order stop actions relative to stonith
- crm_resource: don't pretend that target-role:started would prevent promotion
- crm_mon: consistently print ms resource state
- controld: use "stonith_admin -H '*' -V" (bsc#977201)
- stonith_admin: allow -H '*' to show history for all nodes (bsc#977201)
- controld: fix "[: -eq: unary operator expected" issue from PR 1022 (bsc#977201)
- extra: Support of the task designation of a resource and the fencing.
- extra: Change pcmk_snmp_helper.sh (2).
- Upstream version cs: 6a8c1e9d35c65cbfd4019cfe797cb7bb9dfd4322
* Sun May 29 2016 ygao@suse.com
- controld: Prevent unwanted self-fencing if "stateful_merge_wait" state of dlm is not available (bsc#977201)
  * bug-977201_pacemaker-controld-self-fencing.patch
* Sun May 29 2016 ygao@suse.com
- libservices: clean up non-signalfd code paths
- spec: fence_pcmk only eligible for Pacemaker+CMAN
- crmd: Acknowledge cancellation operations for remote connection resources (bsc#976865)
- controld: improve DLM check with stateful_merge_wait (bsc#977201)
- attrd, libcrmcommon: validate attrd requests better
- crmd: clear remote node transient attributes on disconnect (bsc#981489)
- Revert "Fix: attrd: Correctly implement mass removal of a node's attributes" (bsc#981489)
- crm_mon: Fix time formatting on x32
- resources: use OCF version tagging correctly
- libcommon: crm_procfs_pid_of() would always return last /proc entry checked
- crmd: correctly dig into cib-query-answer if alerts section is present timestamp-format defaults to "%%H:%%M:%%S.%%06N"
- crmd: Take start-delay into account for the timeout of the action timer (bsc#977258)
- libservices: make systemd override file world-readable to avoid log warning
- libcrmcommon: correct directory name in log message
- Log: make crmd messages more user-friendly
- Log: make messages in common quorum/fencing situations more user-friendly
- Log: make shutdown messages more user-friendly
- pengine: lf#2560/lf#2588 - Correctly set the environment variable "OCF_RESKEY_CRM_meta_timeout" when "start-delay" is configured (bsc#977258)
- Log: make operation messages more user-friendly
- Log: make startup messages more user-friendly
- services: Correctly clean up service actions for non-dbus case
- uninitialized use of nano_digits
- attrd: Update also dampens when synchronizing attributes (bsc#977846)
- Upstream version cs: 389294fd1ebefddad67fff51306f585b758ca860
* Wed May  4 2016 ygao@suse.com
- Rebase:
  * pacemaker-Wno-format-signedness.patch
- RA: SysInfo - Reset the node attribute "#health_disk" to "green" when there's sufficient free disk (bsc#975079)
- pengine: Organize order of actions for slave resources in anti-colocations (bsc#977800)
- attrd: Fix the synchronization of attributes (bsc#977846)
- pengine: Organize order of actions for master resources in anti-colocations (bsc#977800)
- pengine: Respect asymmetrical ordering when trying to move resources (bsc#977675)
- fencing: Record the last known names of nodes to make sure fencing requested with nodeid works (bsc#974108)
- crmd: first implementation of integrated multi-agent, multi-target alerting mechanism (fate#320855)
- ping resource: Use fping6 for IPv6 hosts (bsc#976271)
- pengine: Consider resource failed if any of the configured monitor operations failed (bsc#972187)
- ping resource: avoid undefined func w/ OCF_FUNCTIONS=/dev/null
- spec: make Publican docs not depend on pre-existing packages
- cib/fencing: Set status callback before connecting to cluster (bsc#974108)
- xml: use spaces instead of tabs in schema files
- extra: Support of the dampen change by RA.
- Upstream version cs: 9e382568ac3cd54c222496501088ab3fc158b2e2
* Thu Mar 24 2016 ygao@suse.com
- crmd: update cluster state in CIB after fencing an unseen node
- crmd: don't abort transition for expected remote node shutdown
- libtransition: potential memory leak if unpacking action fails
- Upstream version cs: 5a6cdd11b4f93b4d55e1b2654078018c339931d4
* Thu Mar 17 2016 ygao@suse.com
- attrd: crash on exit if initialization fails
- build: fix scalability regression
- pengine: Suppress assert if a stateful clone is not being demoted/stopped (bsc#971129)
- attrd: Support of the dampen change by attrd.
- PE: Correctly handle the ordering of demote actions for failed and moving containers
- Upstream version cs: d076e9dbf9827f7801c89c6d635df370aeca5e90
* Mon Mar  7 2016 ygao@suse.com
- crmd,tools: Set attributes for remote nodes directly into cib if it's legacy attrd (bsc#967775)
- libcib: Correctly determine the node type (bsc#967775)
- resources: match agents' default for globally_unique to pacemaker's
- crm_mon: Help admins identify why resources are not being started or responding to commands
- PE: Memory leak
- crm_resource: Prevent segfault when --resource is not correctly supplied for --restart command
- Build: Create CRM_CORE_DIR during installation
- Upstream version cs: eb89393a82eb41ff50d041b91765ccac52e873e0
* Mon Feb 29 2016 ygao@suse.com
- cpg: Ensure group name is never unset
- remote: Simplify calls to accept() and inet_ntop() by using "struct sockaddr_storage" (bsc#964183)
- remote: cl#5269 - Notify other clients of a new connection only if the handshake has completed (bsc#967388, bsc#1002767, CVE-2016-7797)
- remote: Correctly display the IP address of the remote client (bsc#964183)
- spec: declare also BSD license as suitable
- libservices: Add error handling for pipe() failed.
- libservices: Check resource agent is executable or not before pipe open.
- crmd: Prevent use-after-free when an unexpected remote client takes over (bsc#964183)
- pacemakerd: Correction of the stonithd process judgment of pacemakerd.
- crmd: Do not turn on stonith-watchdog-timeout automatically if SBD is detected
- remote: Correctly check for SBD configuration consistency
- resources: Fix state file metadata in Dummy, Stateful and HealthCPU resource agents
- systemd: Modified so that the cluster to stop before the rsyslog
- common: Correctly locate sbd via its pidfile
- common: Assume processes are active if we get EACCESS
- Fencing: Simplify watchdog integration
- crmd: Only poopulate stonith-watchdog-timeout if SBD is active
- remote: Ensure SBD is consistently configured on remote nodes
- remote: Allow cluster and remote LRM API versions to diverge (bsc#1009076)
- cib: Do not send notifications when the dryrun flag is present
- Upstream version cs: cf67796823c4429714857411e614cfacfbc59d89
* Mon Feb 15 2016 ygao@suse.com
- crm_shadow: fix broken --display command
- ipc: Respect the parameter of pick_ipc_buffer() but don't let it affect the global value
- libcluster: crm_peer_uname() should return NULL if uuid is invalid
- remote: recover from remote node fencing more quickly
- crmd: update node state for migrated pacemaker_remote nodes
- crmd: update node state for stopped pacemaker_remote nodes
- crmd: update node state for started pacemaker_remote nodes
- crmd: add new message type for updating pacemaker_remote node state
- libcluster: set remote peer cache state based on CIB node state
- libcluster: send notifications when pacemaker_remote nodes are started
- crmd: report pacemaker_remote node state in CIB status section
- Upstream version cs: c851a117bc77bdefe15181a7d753f1aed867cde6
* Thu Feb 11 2016 ygao@suse.com
- spec: Move the common directories under /var/lib/pacemaker into pacemaker-cli package
- liblrmd: Prevent potential use-after-free (bsc#964183)
- crmd: Disconnect the relevant remote proxies as well when disconnecting a remote node (bsc#964183)
- crmd: Prevent potential use-after-free (bsc#964183)
- liblrmd: Prevent potential use-after-free issues (bsc#964183)
- PE: Fix conditions for internal sanity check (bsc#971129)
- attrd: ensure remote nodes are in correct peer cache (bsc#981489)
- crmd: set remote flag when gracefully shutting down remote nodes (bsc#981489)
- fencing: Correctly track active stonith actions (bsc#938545)
- fencing: Functionize adding and removing active pids of device (bsc#938545)
- crm_shadow: Do not invoke shells with --noprofile option other than bash (bsc#961392)
- lib/common: check return value of dlsym() and not dlerror()
- lib/ipc: allow PCMK_ipc_buffer to be smaller than default max sizes
- lib/services: use self-pipe sigchld handling when signalfd isn't available
- spec: associate subpackage with correct licenses
- spec: rely on system-wide RPM macros if available
- spec: C++ compiler is not something currently needed
- RHBZ#1286316: Do an ordered shutdown of systemd resources
- header == NULL when parsing compressed message
- attrd: Correctly implement mass removal of a node's attributes (bsc#981489)
- attrd: Hook up the client name so we can track requests
- crmd: Set the shutdown transient attribute in response to LRMD_IPC_OP_SHUTDOWN_REQ from remote nodes (bsc#981489)
- PE: Honor the shutdown transient attributes for remote nodes (bsc#981489)
- pacemaker_remote: support graceful stops (bsc#981489)
- crmd: support graceful pacemaker_remote stops (bsc#981489)
- lrmd,liblrmd: add lrmd IPC operations for requesting and acknowledging shutdown (bsc#981489)
- fencing: Support concurrent fencing actions on each device (bsc#938545)
- pengine: Support concurrent fencing (bsc#938545)
- Upstream version cs: c54f10440a7bba5a1491ea8506925c7d6d9ca2a3
* Thu Jan 21 2016 ygao@suse.com
- Update to version 1.1.14
- fencing: free only after last usage   makes coverity happy
- crmd: 0 is a valid fd   makes coverity happy
- tools: crm_resource compile issue
- crm_resource --list-agents: don't print uninitialized memory
- extra: update SNMP MIB with new pacemakerTrap OID containing pacemakerNotificationTrap
- fencing, libfencing: remap fence agent error codes before async callback (bsc#962309)
- libfencing: topology is not used
- fencing: topology is not used
- libcrmcommon: when caching attrd connection, cache connection flags as well
- cts: Plugin-based cluster has its own PacemakerUp pattern
- Upstream version cs: 70404b0e5ecbe5e51d07c6c2233eea640cbd720a (Pacemaker-1.1.14)
* Fri Dec 18 2015 ygao@suse.com
- Rebase:
  * bug-806256_pacemaker-log-level-notice.patch
  * bug-728579_pacemaker-stonith-dev-id.patch
- core: Mistake of the parameter order.
- RHBZ#1287315: stonithd: Trigger cib_devices_update in case of deletion of just an attribute
- CLBZ#5253: stonithd: Do not intermingle stdout & stderr coming from stonith-RAs (bsc#962309)
- resources: allow for top output with or without percent sign in HealthCPU
- controld: Return error when DLM status is wait fencing (RHBZ#1268313)
- crmd: Don't update cluster/peer CIB fields when processing stonith results
- Upstream version cs: e16447de89d25db3b3578c7e080c1a4c2f85806f
* Wed Dec  2 2015 ygao@suse.com
- ping: Clarify the description of host_list parameter in ping metadata (bsc#956459)
- systemd: Prevent segfaul when logging failed operations
- systemd: The underlying systemd calls default to 90s for their timeouts
- cib: Do not terminate due to badly behaving clients
- Correctly check for recycled PIDs in crm_pid_active
- crmd: Consider only fence and shutdown transition events to be "down" events
- pengine: Support of multiple-active=block for resource groups (bsc#942491)
- crmd: use 300s timeout with notification scripts, not 300ms
- stonith_admin: add ability to target topology by pattern or attribute
- fencing,libfencing: add API support for targeting topology by pattern or attribute
- Upstream version cs: a7d6e6b56fd2779a07970df7de4e0fb0b22742d3
* Mon Nov 16 2015 ygao@suse.com
- crm_report: Call "crm report" if available (bsc#950483)
* Thu Nov 12 2015 ygao@suse.com
- fencing: crm_resource --show-metadata drops documentation strings for fencing agents (bsc#950375)
- Upstream version cs: 6f22ad7312b703289da5d24e918a78117a0825e1
* Thu Nov  5 2015 ygao@suse.com
- CTS: add "try except" to deal with errors that raw_input gets EOFError and add "--yes" to skip interaction (bsc#953192)
- Upstream version cs: 577898dc4ac1efdb5989a996cb5f9ac60ed2eb7a
* Wed Nov  4 2015 ygao@suse.com
- crm_resource: Correctly clean up all children for anonymous cloned groups (bsc#950128)
- services: Directly add operations into in-flight list in the execution functions (bsc#952874)
- systemd: Return PCMK_OCF_UNKNOWN_ERROR instead of PCMK_OCF_NOT_INSTALLED for uncertain errors on LoadUnit (bsc#952884)
- systemd: Return FALSE for systemd_mask_error() if it only maps an error instead of masking one (bsc#952884)
- dbus: Correctly return the result for pcmk_dbus_find_error() no matter if there's a DBusError passed in (bsc#952884)
- services: Prevent potential use-after-free when trying to add an operation into in-flight list (bsc#952874)
- systemd: Directly return an error if the connection to System DBus is closed (bsc#952874)
- services: Correctly determine if operations are in-flight (bsc#952874)
- systemd: Reconnect to System DBus if the connection is closed (bsc#931271)
- lrmd: Finalize all pending and recurring operations when cleaning up a resource (bsc#950450)
- fencing: don't poke peers when remote node status changes
- attrd: don't try to communicate with attrd on a remote node
- libcluster,crmd: never update join info or processes for remote nodes
- cib: Increased paranoia when peer updates fail to apply in compatability mode
- crmd: do not accept remote peer data as enough for startup
- crmd: remote nodes can't be DC so never add them to stonith cleanup list
- libcluster: never autoreap from remote peer cache
- crmd: improve generation of node state
- CTS: get Reattach test working again and up-to-date (bsc#953192)
- libcommon: Ignore CDATA of metadata of the resource.
- cib: Downgrade the log message on forwarding CRM_OP_NOOP requests from INFO to DEBUG (bsc#949267)
- fencing: Return a provider for the internal fencing agent "#watchdog" instead of logging an error (bsc#949441)
  * Drop bug-949441_pacemaker-fencing-provider-internal.patch which has been merged upstream
- Upstream version cs: 7bd00f3f3010bc10d13b87e2ff501b597ea6ca03
* Thu Oct  8 2015 ygao@suse.com
- fencing: Return a provider for the internal fencing agent "#watchdog" instead of logging an error (bsc#949441)
  * bug-949441_pacemaker-fencing-provider-internal.patch
- spec: Move the normal resource agents into pacemaker-cli package (bsc#947197)
- spec: Move logrotate configuration file into pacemaker-cli package (bsc#947197)
- spec: Move attrd_updater, crm_attribute and crm_master into pacemaker-cli package (bsc#947197)
- spec: Move xml schema files and PCMK-MIB.txt into pacemaker-cli package (bsc#947197)
* Thu Oct  8 2015 ygao@suse.com
- crm_resource: Correctly observe --force when deleting and updating attributes (bsc#948197)
- crm_resource: Correctly delete existing meta attributes regardless of their position in the heirarchy (bsc#948197)
- fencing,libfencing: use level tag consistently in internal XML
- crm_resource: Correctly update existing meta attributes regardless of their position in the heirarchy (bsc#948197)
- crmd: properly detect CIB update failures for remote nodes
- cibadmin: Prevent potential use-of-NULL in print_xml_output() (bsc#947180)
- Fencing: The device list is expected to be comma separated
- Tools: Do not send command lines to syslog (bsc#986676)
- Tools: Repair the logging of 'interesting' command-lines
- PE: resolve memory leak
- libfencing: make topology level removal compatible with latest stonithd API
- fencing: parse from correct XML location when registering/unregistering topology
- tools: improve error handling when modifying configuration
- crmd,libcrmcommon,libservices,tools: potential memory leaks (bsc#948197)
- crmd,fencing: avoid potential null dereference in string searches
- typo: OPSTIONS -> OPTIONS in crm_mon.sysconfig
- cib: Check if the configuration changes with cib_config_changed() only for v1 diffs (bsc#946224)
- liblrmd: don't print error if remote key environment variable unset
- libcib: properly handle temporary file
- libcrmcommon: better validation of environment variable value
- crmd: avoid potential null dereference
- libcib: potential user input overflow
- controld: replace bashism
- PE: drop probe_complete actions
- PE: Allow resources to start and stop as soon as their state is known on all nodes
- Fencing: Correctly construct simple topologies with stonith_admin
- Fencing: Correctly remove topologies and detect invalid entries
- remote: Revise a misleading message in the ocf:pacemaker:remote resource agent (bsc#946332, bsc#967383)
  * Drop bug-946332_pacemaker-resource-agent-remote-message.patch which has been merged upstream
- remote: Correctly display the usage of the ocf:pacemaker:remote resource agent (bsc#946332, bsc#967383)
  * Drop bug-946332_pacemaker-resource-agent-remote-usage.patch which has been merged upstream
- libcib: find_nvpair_attr_delegate: check buffer overflow
- libcib: find_nvpair_attr_delegate: check alloc failure
- Upstream version cs: 7906df92a713052db1edae851579ea229d8a5393
* Fri Sep 18 2015 ygao@suse.com
- remote: Revise a misleading message in the ocf:pacemaker:remote resource agent (bsc#946332, bsc#967383)
  * bug-946332_pacemaker-resource-agent-remote-message.patch
- remote: Correctly display the usage of the ocf:pacemaker:remote resource agent (bsc#946332, bsc#967383)
  * bug-946332_pacemaker-resource-agent-remote-usage.patch
* Thu Sep 17 2015 ygao@suse.com
- crm_resource: Allow the resource configuration to be modified for --force-{check,start,..} calls
- Fencing: Correctly parse 'by-attribute' fencing levels
- Fencing: Use dedicated fields for fencing level patterns and attribute matching
- pacemaker_remote: memory leak in ipc_proxy_dispatch()
- crmd: don't add node ID to proxied remote node requests for attrd
- membership: Safely autoreap nodes without code duplication
- PE: Resolve memory leak
- pacemakerd: Do not forget about nodes that leave the cluster
- corosync: Display node state and quorum data if available
- crmd: Implement reliable event notifications
- extra: Added snmp trap of type "NOTIFICATION-TYPE" to MIB and snmp helper script
- Date: Correctly set time from seconds-since-epoch
- PE: Bug cl#5247 - Imply resources running on a container are stopped when the container is stopped
- Upstream version cs: 20c2178f076ff32fdf9ba9a467c193b8dac2f9e5
* Wed Sep  9 2015 ygao@suse.com
- lrmd: Upgrade start/finish log tags from INFO to NOTICE (bsc#943295)
  * bug-943295_pacemaker-lrmd-log-notice.patch
* Fri Aug 28 2015 ygao@suse.com
- services: Reduce severity of noisy log messages (bsc#943319)
- xml: Mark xml nodes as dirty if any children move (bsc#942382)
- pengine: The failed action of the resource that occurred in shutdown is not displayed.
- tools: memory leak in crm_resource
- crm_resource: Correctly check if a resource is unmanaged or has a target-role
- fencing: add ability to target by attribute
- crmd: Resolve memory leak in remote_proxy_cb()
- ipc: Do not constantly increase suggested size for PCMK_ipc_buffer every time we find it's insufficient (bsc#940992)
- Upstream version cs: e8888b98cd7dbdfb986c1a46bdb4b113b96e914f
* Thu Aug 13 2015 ygao@suse.com
- crm_resource: Indicate common reasons why a resource may not start after a cleanup
- pengine: Ensure fencing of the DC precedes the STONITH_DONE operation
- crm_resource: Compensate for -C and -p being called with the child resource for clones
- ipc: Fix output formats (bsc#940992)
- fencing: ensure "required"/"automatic" only apply to "on" actions
- fencing: Remove unnecessary casts (bsc#940711)
- crm_simulate: Prevent segfault on arches with 64bit time_t (bsc#940711)
- ipc: Correctly compare values for the size of ipc buffer and prevent suggesting a negative value when it's insufficient (bsc#940992)
- xml: Reduce severity of noisy log message (bsc#950551)
- crm_resource: Correctly clean up failcounts for inactive anonymous clones
- crmd: Avoid cancelling transitions when we tell nodes to shutdown
- systemd: drop legacy SysVStartPriority from service units
- crm: Set the attribute from remote node.
- Upstream version cs: 4ad07f5f464c84b80c739922bd9fd708e8d36e5a
* Thu Jul 30 2015 ygao@suse.com
- dbus: Remove redundant ref/unref of pending call records
- stonithd: potential device list corruption
- cib: don't destroy peer cache in peer status callback
- systemd: Ensure pending structs are correctly unreferenced
- systemd: Track pending operations so they can be safely cancelled
- crmd: memory leak in CIB callbacks
- attrd: memory leak in legacy attrd's CIB callback
- attrd: memory leak in CIB callback
- libcib: allow free function for user data supplied to CIB callbacks
- xml: Prevent use-of-NULL in crm_xml_dump()
- crm_mon: Memory leaks
- Upstream version cs: 3fb7f71bf9ca2a3d6e1187fa3b74c7841d6af5a7
* Wed Jul 22 2015 ygao@suse.com
- pengine: properly handle blocked clone actions
- pengine: Correctly bypass fencing for resources that do not require it
- libservices: potential memory leaks when executing systemd actions
- libservices: memory leak in DBus-related log messages
- crmd: memory leaks in recurring operation history
- pengine: Addtion of the clone resource clone-min metadata option
- Upstream version cs: 3d781d3fe61504c841e3c89b2e8ccff8195d4af6
* Mon Jul 20 2015 ygao@suse.com
- Rebase bug-806256_pacemaker-log-level-notice.patch
- Build: Update version numbers to 1.1.13 in version.m4 and sample spec file
- fencing: Broadcast uname as soon as a peer's state has changed (bsc#938410)
- fencing: remap sequential topology reboots to all-off-then-all-on
- fencing: remap sequential topology reboots to off
- fencing: support remapping reboots when processing fencing query results
- fencing: treat remapped reboots as reboots when appropriate
- fencing: support remapping reboots in fencing query results
- crmd: check for errors when searching for CIB daemon's load file
- libcib,libfencing,tools: memory leaks from xmlGetNodePath()
- attrd: use-after-free in attrd_client_update()
- fencing: memory leak when searching for a target's fencing topology
- lrmd: memory leak when freeing command structure
- libcluster: work around peer cache destruction in client status callbacks
- fencing: add support for operation phases to device properties
- fencing: add support for operation phases
- crmd: Do not enforce restart for resources that support reload and don't support any unique parameters
- crmd: Do not enforce restart for changes of non-unique parameters
- cts: change the stack from openais (white-tank) to corosync (plugin v0) in set_stack of environment.py (bsc#936149)
- Upstream version cs: bd8c4b5a30c9cacd0257fe50ab50d3a6436db42a
* Fri Jul 10 2015 ygao@suse.com
- crmd: Make resource_supports_action() really general
- crmd: Remove a duplicate invocation of snprintf()
- pengine: clear failures after reconnect_interval expires
- RA: Prevent an error message on stopping "Dummy" resource
- PE: Ignore comment blocks when unpacking the cib
- fencing: use "off" timeout when remapping "reboot" to "off"
- fencing: do not set call options twice in query
- crmd: don't synthesize op failures during shutdown
- lrmd: prevent double free after unregistering stonith device for monitoring (bsc#1035822)
- libcommon: crm_ipc_get_fd() must set errno on error
- PE: Record the execution date in PE files so we can re-use it in crm_simulate
- pengine: allow guest remote nodes using containers/vms to be nested in a group resource
- pengine: Resolve memory leak in expand_notification_data()
- cib: Prevent use-after-free and return -EINVAL when attempting to delete the whole "/cib" (bsc#934609)
- cib: Prevent use-after-free when invoking "cibadmin --delete-all --xpath" (bsc#934609)
- crmd: Prevent segfault when erasing resources from disconnected remote nodes
- pengine: do not timeout remote node recurring monitor op failure until after fencing
- crmd: No need to re-process actions we've already marked as failed
- crmd: All pseduo ops must be allowed to complete
- crm_simulate: Optionally include action IDs in the dot graph
- fencing: properly decide whether a topology fencing device has been found
- fencing: properly sort peers by number of fencing devices found
- crmd: Record actions in the CIB as failed if we cannot execute them
- pengine: do not stop notify a fenced node that the rscs on the fenced node stopped
- pengine: fixes segfault in pengine when fencing remote node
- remote: do not fail operations because of a migration
- remote: handle merging duplicate recurring monitors for connection rsc
- pengine: cl#5235 - Prevent graph loops that can be introduced by "load_stopped -> migrate_to" ordering
- PE: Exclude nodes which don't match any exclusive discovery rules
- Log: improve IPC connection error messages
- Log: make syslog less noisy
- lrmd: cancel currently pending STONITH op if stonithd connection is lost
- fencing: Correct the all_topology_devices_found() implementation
- crmd: Pre-emptively fail in-flight actions when lrmd connections fail
- PE: Include a list of all and available nodes with notifications
- lrmd: set recv timeout upper bound for tls connections
- services: prevent recurring monitors from colliding with other operations
- crmd: handle resources named the same as cluster nodes
- crmd: make actions incompletable after remote-node fails
- crm_simulate: Correctly invoke the policy engine library
- libcluster: overhaul peer cache management
- crmd: Prevent use-of-NULL
- crm_report: Enable password sanitizing by default
- PE: Keep the size of the secure list small in the cib
- PE: Reduce noise when sanitized policy engine files are replayed
- attrd: handle removals of cluster peers and remote peers consistently
- libcluster: avoid possibility of invalidating a hash table iterator
- membership: Ensure peer cache management supports all stacks
- libcluster: do not re-add peer entries for exiting nodes
- PE: Skip unrunnable actions when one-or-more is in effect
- PE: Ensure recurring monitor operations are cancelled when clone instances are de-allocated
- systemd: No need to trigger assert if cannot obtain an unit (bsc#931271)
- dbus: Use operation timeout for dbus reply timeout (bsc#931271)
- fencing: correct choice of fencing topology level
- crm_shadow: Fix "crm_shadow --diff" (bsc#931166)
- cib: Calculate and add digest for a patchset after accepting changes for the target xml (bsc#931114)
- remote: enable reloads for select remote connection options
- crmd: fence remote node after connection failure only once
- remote: reconnect_delay option for remote nodes to delay reconnect after fence
- tools: ignore stderr from crm_mon when running via systemd
- xml: update RelaxNG schema for crm_mon XML output
- Fencing: Correctly handle changes to the fencing topology
- fencing: Allow complex configurations to apply to multiple hosts
- tools: Update regression tests for ACL fixes
- tools: improve failed actions display in crm_mon
- tools: implement printing tickets in crm_mon HTML/XML output
- tools: implement printing negative location constraints in crm_mon HTML/XML output
- tools: implement printing operations and failcounts in crm_mon HTML/XML output
- tools: implement printing node attributes in crm_mon HTML/XML output
- tools: improve cluster summary display in crm_mon
- tools: improve guest node output in crm_mon
- tools: prettify plaintext output
- tools: prettify crm_mon HTML output
- tools: prettify crm_mon --simple-status output
- crm_report: Allow log file discovery to be disabled
- crm_resource: Support debugging promote and demote operations
- fencing: Allow semi-colon delimiter for pcmk_host_list
- Upstream version cs: ef86b494a411ce920eb18b9b6541a3a0425a41e0
* Fri Jul 10 2015 ygao@suse.com
- Update to version 1.1.13
- Build: Update library versions
- Build: Move new struct members to the end for backwards compatibility
- Fencing: Gracefully handle invalid metadata from agents
- Upstream version cs: 6052cd16c2f455809f8088af76ce86483bf98353 (Pacemaker-1.1.13)
* Wed Jun  3 2015 ygao@suse.com
- pengine: cl#5130 - Only check the capacities of the nodes that are allowed to run the resource (FATE#313105)
- cib: Correctly add "update-origin", "update-client" and "update-user" attributes for cib (bsc#931177)
- fencing : Correction of the log output of the practice node of stonith.
- Upstream version cs: a0449d443fa5c834207def5fe36a117a53c334d6
* Mon May 18 2015 ygao@suse.com
- xml: Correctly create v1 patchsets when deleting attributes (bsc#931170)
- xml: Prevent potential use-of-NULL (bsc#929960)
- Upstream version cs: 677f53216662d121a47b4c7683ec3749c614437e
* Fri May 15 2015 ygao@suse.com
- cib: No need to enforce cib digests for v2 diffs in legacy mode (bsc#929960)
- cib: Ability to upgrade cib validation schema in legacy mode (bsc#929960)
- xml: Do not dump deleted attributes (bsc#929960)
- cib: Revert d153b86 to instantly get cib synchronized in legacy mode (bsc#929960)
- cib: Enable cib legacy mode for plugin-based clusters (bsc#929960)
- Build: CRM_STATE_DIR is created dynamically when needed
- Tools: Repair expected output for ACLs
- Build: Prevent rpm packaging conflicts
- pengine: cl#5130 - Choose nodes capable of running all the colocated utilization resources (FATE#313105)
  * Drop obsolete pacemaker-colocated-utilization.patch
- Upstream version cs: 0b79da3e73fe2ced8b9602aa59d55873d857b3e7
* Mon May 11 2015 ygao@suse.com
- crmd/pengine: implement on-fail=ignore without allow-fail (bsc#981731)
- pengine: Prevent use-after-free in sort_rsc_process_order() (bsc#930368)
- crmd: Prevent the old version of DC from being fenced when it shuts down for rolling-upgrade (bsc#929955)
- xml: Fix upgrade-1.3.xsl to correctly transform ACL rules with "attribute" (bsc#929681)
- crmd/pengine: handle on-fail=ignore properly (bsc#981731)
- crmd: respect start-failure-is-fatal even for artifically injected events (bsc#981731)
- crmd: don't update fail count twice for same failure (bsc#950450, bsc#981731)
- crmd: report operation rc as advertised instead of status (bsc#981731)
- xml: add RelaxNG schema for crm_mon XML output
- Upstream version cs: c9ad9cd503f071391efe17d3c45d578d6f152acd
* Wed May  6 2015 ygao@suse.com
- pengine: process rsc parameters during unpack (bsc#929842)
- pengine: handle setting container attribute in the correct location (bsc#929842)
- lrmd: move isolation wrappers to hidden directory (bsc#929842)
- mainloop: resolves race condition mainloop poll involving modification of ipc connections (bsc#929835)
- Upstream version cs: f47ea56b4ec23c7d8e0c129535a9b49cdbd80482
* Thu Apr 30 2015 ygao@suse.com
- fencing: Correctly make args for fencing agents (bsc#925751)
- fence_legacy: Avoid passing 'port' to cluster-glue agents (bsc#925751)
- corosync: Bug cl#5232 - Somewhat gracefully handle nodes with invalid UUIDs
- HealthSMART: OCF_RESKEY_drives could contain multiple values
- pengine: restart master instances on instance attribute changes
- spec: move report.common and report.collector to cli package
- pengine: only kill process group on timeout when on-fail does not equal block.
- lrmd: Hint to child processes that using sd_notify is not required (bsc#956626)
- Agents: Fix the HealthSMART metadata
- make targetted reprobe for remote node work, crm_resource -C -N <remote node>
- crmd: include remote nodes when forcing cluster wide resource reprobe
- crm_mon: Support of the start from systemd of crm_mon
- Upstream version cs: 195559d47b0e9186b5d131981f6f7fee96ecad76
* Mon Apr 13 2015 ygao@suse.com
- Rebase:
  * pacemaker-NodeUtilization-RA.patch
- docker-wrapper: per resource logging of lrmd and remote client tool
- pengine: Avoid trailing whitespaces when printing resource state
- pengine: cl#5207 - Display "UNCLEAN" for resources running on unclean offline nodes
- docker-wrapper: add reuse option for presistent containers
- docker-wrapper: only override exit reason if docker daemon is inactive
- pengine: handle isolated resource scenario, cloned group of isolated resources
- pengine: handle cloned isolated resources in a sane way
- crm_report: More patterns for finding logs on non-DC nodes
- lrmd: Use original timestamps when reporting multi-step systemd operations
- lrmd: report original timeout when systemd operation completes
- systemd: improve unit files
- PE: Turn off legacy unpacking of resource options into the meta hashtable
- acl: Do not delay evaluation of added nodes in some situations (bsc#927828: CVE-2015-1867)
- docker-wrapper: add demote, promote, and notify actions for multistate rsc
- docker-wrapper: properly forward key value pairs during isolation
- attrd: fixes double free in attrd legacy
- lrmd: do not let isolation wrappers inherit the wrapper attribute, or it makes a loop
- pengine: pass node name of pcmk host into isolated resources
- lrmd: isolation wrappers are moved from containers to isolation OCF namepace
- pengine: Fix colocation with unmanaged resources
- stonith-ng: Correctly track node state
- stonith-ng: No reply is needed for CRM_OP_RM_NODE_CACHE
- crm_resource: Fix output format of the warning from --force-start
- crm_resource: Display the locations of all anonymous clone children when supplying the children's common ID (bsc#870339)
- cib: Correctly track node state
- Upstream version cs: 7a2e3ae6b736621933b24f4cdc9ea260021d878d
* Fri Mar 27 2015 ygao@suse.com
- Rebase:
  * bug-806256_pacemaker-log-level-notice.patch
  * pacemaker-NodeUtilization-RA.patch
  * pacemaker-colocated-utilization.patch
- crmd: All peers need to track node shutdown requests (bsc#917625)
- crmd: Cached copies of transient attributes cease to be valid once a node leaves the membership (bsc#917625)
- crmd: Wait for all pending operations to complete before poking the policy engine
- lrmd: preserve exit reason string when isolation wrappers are in use
- docker-wrapper: properly separate docker and resource specific attributes
- docker-wrapper: set authkey file permissions and properly set container 'node name' during start
- systemd: Trick systemd into not stopping our services before us during shutdown (bsc#913251)
- mcp: Allow a configurable delay when debugging shutdown issues
- systemd: Kindly ask dbus NOT to kill the process if the dbus connection fails (bsc#931271)
- systemd: Tell systemd not to take DBus down from underneath us (bsc#913251)
- cib: Correctly set up signal handlers
- PE: Do not record duplicate copies of the failed actions
- lrmd: enable ipc proxy for docker-wrapper privileged mode
- lrmd: properly handle poke requests in lrmd client when using ipc
- spec: add docker-wrapper directory to spec file
- pengine: disable migrations for resources with isolation containers
- pengine: disable reloading of resources within isolated container wrappers
- pengine: ability to launch resources in isolated containers
- extra: docker container tech wrapper script for pcmk remote
- tools: crm_mon prints Stopped clones only if --inactive was specified
- tools: display node names more consistently in crm_mon output
- tools: Improve crm_mon output with certain option combinations
- tools: make crm_mon last updated header consistent across formats
- remote: pcmk remote client tool for use with container wrapper script
- crmd: Reset stonith failcount to recover transitioner when the node rejoins (bsc#921102)
- systemd: fix crash caused when canceling in-flight operation
- Upstream version cs: 3e93bc1dd6c1c3f2ee101f754567aa007b24bb5e
* Fri Mar 13 2015 ygao@suse.com
- PE: Support non-actionable degraded mode for OCF
- lrmd, services: interpret LSB status codes properly
- tools: add crm_resource --wait option
- tools: attrd_updater supports --query and --all options
- attrd: attrd supports queries
- pengine: remove unnecessary whitespace from notify environment variables
- tools: free allocated memory correctly in crm_resource
- attrd: properly write attributes for peers once uuid is discovered
- cib: assignment where comparison intended
- attrd: only send ack for recognized operations
- attrd: make each client operation handler its own function
- tools: attrd_updater supports private attributes
- attrd supports private attributes (not written to CIB)
- pengine: Reschedule specific monitors when resource definitions have changed (bsc#914761)
- pengine: Resolve memory leaks (bsc#914761)
- Upstream version cs: e32080b460f81486b85d08ec958582b3e72d858c
* Fri Feb 27 2015 ygao@suse.com
- properly record stop args after reload
- pengine: Do not reschedule monitors that are no longer needed while resource definitions have changed (bsc#914761)
- Build: Fix building when heartbeat support is disabled
- fencing: cl#5134 - Support random fencing delay to avoid double fencing (FATE#317136, FATE#318381, bsc#970733)
- extra: Use crm_simulate for the showscores script
- attrd: refresh should force an immediate write-out of all attributes
- service: Leave synchronous calls to be free'd by the caller
- service: Additional pointer safety
- crmd: Add "on_node" attribute for *_last_failure_0 lrm resource operations (bsc#918839)
- crm_mon: Fill CRM_notify_node in traps with node's uname rather than node's id if possible (bsc#918839)
- pengine: ensure if B is colocated with A, B can never run without A
- cib: automatically update .sig files in file backends when clients update live CIB
- cib: file-based backends now detect whether file is live CIB
- lrmd: add back support for class heartbeat agents
- lrmd: provide fake meta data for ra class heartbeat
- crm_resource: Use-after-free when restarting a resource
- cli: Ensure subsequent unknown long options are correctly detected
- crmd: Bug rhbz#1181824 - Ensure the DC can be reliably fenced
- attrd_updater: Allow attributes to be set for other nodes
- native_print: report target-role as well
- membership: fix crm_update_peer_proc to NOT ignore flags if partially set
- crmd: don't trigger a stonith_reconnect if no longer required
- Upstream version cs: fa1311a0159588385f24cd8c3530233f4b90f3a9
* Tue Feb 24 2015 rguenther@suse.com
- Add pacemaker-Wno-format-signedness.patch to disable
  - Wformat-signedness added by GCC 5 and enabled by -Wformat=2
* Fri Jan 30 2015 ygao@suse.com
- pengine: Handle ordering between stateful and migratable resources (bsc#881160)
- crmd: Check "watchdog" daemon option before setting "have-watchdog" property
- crmd: Correctly add the local option that validates against schema for pengine to calculate
- Upstream version cs: 3021d731fdeba29e1136c117a62f3201785be6ea
* Fri Jan 16 2015 ygao@suse.com
- crm_standby: update accepted options to match documentation
- cts: Fix bashisms in LSBDummy script
- pengine: fixes pengine crash with orphaned remote node connection resource
- PE: Do not aggregate children in a pending state into the started/stopped/etc lists
- acl: Correctly implement the 'reference' acl directive
- Upstream version cs: 03ec61210c82471161f6cf3366e8afc30d737d67
* Mon Jan 12 2015 ygao@suse.com
- pengine: imply stop in container node resources when host node is fenced
- Build: Fix building if ncurses doesn't provide pkg-config files
- xml: Do not change the ordering of properties when applying v1 cib diffs
- xml: Do not prune leaves from v1 cib diffs that are being created with digests
- Upstream version cs: 4109f1539a625bfa3e884d19ab2fc42d7a4daec4
* Fri Jan  9 2015 ygao@suse.com
- xml: add 'require-all' to xml schema for constraints
- pengine: require-all feature for ordered clones
- xml: Ensure ACLs are reapplied before calculating what a replace operation changed
- cib: Ensure file-based backends treat '-o section' consistently with the native backend
- crmd: resolves memory leak in crmd.
- pacemakerd: resolves memory leak of xml structure in pacemakerd
- ipc: use server enforced buffer during ipc client send
- pengine: do not recording pending migrate_to ops for pacemaker remote
- crmd: never stop recurring monitor ops for pcmk remote during incomplete migration
- pengine: prefer migration target for remote node connections
- pengine: properly handle ordering during remote connection partial migration
- crmd: Ensure remote connection resources timeout properly during 'migrate_from' action
- crmd: gracefully handle remote node disconnects during op execution
- pengine: Fence baremetal remote when recurring monitor op fails
- crmd: Handle remote connection failures while executing ops on remote connection
- remote: Treat recv msg timeout as a disconnect
- pengine: properly recover remote-nodes when cluster-node proxy goes offline
- systemd: Correctly handle long running stop actions (bsc#948989)
- crm_resource: Include group members when calculating the next timeout
- crm_resource: Ensure --restart sets/clears meta attributes
- crm_resource: Clean up memory in --restart error paths
- Build: Use a wrapper for realloc() which calls abort when we run out of memory
- services: Prevent potential use-of-NULL
- crm_resource: Memory leak in error paths
- crmd: Mistake of the set of the variable.
- Upstream version cs: d0139e9a00c32b9bc1d7d206d6210126045b49be
* Fri Nov 21 2014 ygao@suse.com
- crm_node: Correctly remove nodes from the CIB by nodeid
- fencing: Allow nodes to be purged from the member cache
- xml: cl#5231 - Unset the deleted attributes in the resulting diffs (bsc#905641, bsc#967254)
- fencing: stonith -l option for custom log
- cib: Avoid nodeid conflicts we don't care about
- Membership: Detect and resolve nodes that change their ID
- attrd: Simplify how node deletions happen
- attrd: Clean out the node cache when requested by the admin
- crm_resource: Allow resource restart operations to be node specific
- crm_resource: Implement --timeout for resource restart operations
- crm_resource: Calculate how long to wait for a restart based on the resource timeouts
- crm_resource: Implement an intelligent restart capability
- crm_failcount: Better error reporting when no resource is specified
- cib: tls sock cleanup for remote cib connections
- Upstream version cs: 7dd90226e10035340d6707d9fd2b04f2e0141194
* Fri Nov 14 2014 ygao@suse.com
- pengine: make resource-discovery work with location rules
- services: Conditionally clean up services actions
- Upstream version cs: 5093c095c5f517ab58375b2b69ecfc5516c86b5b
* Fri Nov 14 2014 dimstar@opensuse.org
- Drop conditional BuildRequires of system-devel: it was required
  one line lower unconditionally.
- Replace remaining systemd-devel BuildRequires with
  pkgconfig(systemd).
* Mon Nov 10 2014 ygao@suse.com
- pengine: exclusive discovery implies rsc is only allowed on exclusive subset of nodes
- dbus: handle dispatch queue when multiple replies need to be processed
- dbus ref count leaks
- dbus: Ensure both the read and write queues get dispatched
- systemd: Ensure failed monitor operations always return
- Perform systemd reloads asynchronously
- Upstream version cs: cd7c9abbcfc620aa84194ee07aade142240db15a
* Tue Oct 28 2014 ygao@suse.com
- watchdog: Allow startup without sbd
- service: Prevent potential use-of-NULL in metadata lookups
- dbus: Fail gracefully if malloc fails
- crmd: Prevent use-of-NULL during reprobe
- crmd: Correctly obtain SBD_WATCHDOG_TIMEOUT from the environment
- pengine: add #kind=remote for baremetal remote-nodes
- Officially support the resource-discovery attribute for location constraints
- xml: fix xml.c memleak in "missing upgrade XSLT" case
- Prefer to inherit the  watchdog timeout from SBD
- stonith-ng: Correctly observe the watchdog completion timeout
- sbd: Attempt to locate sbd via its pid file
- Fencing: If configured, wait stonith-watchdog-timer seconds for self-fencing to complete
- Resolve some potential issues spotted by clang and coverity
- PE: Watchdog integration is sufficient for fencing
- Fencing: Correctly wait for self-fencing to occur when the watchdog is in use
- Fencing: Ensure the hostlist parameter is set for watchdog agents
- crm_resource: Allow -M location to be reinforced with -f even if rsc is already on node
- mcp: Turn on sbd integration if pacemakerd finds it running
- pengine: Fix the behaviors of multi-state resources with asymmetrical ordering (bsc#899403)
- lrmd: Prevent glib assert triggered by timers being removed from mainloop more than once
- cib: Improved tracing of callbacks
- Upstream version cs: a9c81774b89f21f990be255f9862446d1a38afee
* Fri Oct 17 2014 ygao@suse.com
- remote: advertise default port correctly, further adjust default timeout periods
- remote: report timestamps for remote connection resource operations
- pengine: allow remote-nodes to be placed in maintenance mode
- xml: Prevent assert errors in crm_element_value() on applying a patch without version information (bsc#900296)
- pengine: prevent disabling rsc discovery per node in certain situations
- crm_resource: avoid deletion of lrm cache on node with resource discovery disabled.
- pengine: per-node control over resource discovery
- mainloop: fix potential segfault for fd = 0
- ping: Correct metadata for attempts parameter (bsc#899324)
- ping: Pass extra options to fping (bsc#899324)
- ping: Remove incorrectly advertised migrate_to|migrate_from (bsc#899324)
- ping: Add use_fping parameter (bsc#899324)
- ping: Correctly advertise multiplier default (bsc#899324)
- pengine: resource discovery mode for location constraints
- cib: Ensure upgrade operations from a non-DC get an acknowledgement
- lrmd: cancel pending async connection during disconnect
- systemd: Ensure we don't call dbus_message_unref() with NULL
- systemd: Perform monitor operations without blocking
- dbus: Notice when dbus connections get disabled
- pengine: allow baremetal remote-nodes to recover without requiring fencing when cluster-node fails
- crmd: do not remove connection resources during re-probe
- pengine: only fence baremetal remote when connection can fails or can not be recovered
- ipc: properly allocate server enforced buffer size on client
- remote: advertise more reasonable timeout periods for remote-nodes connections
- crmd: properly update job limit for baremetal remote-nodes
- crmd: Remote-node throttle jobs count towards cluster-node hosting conneciton rsc
- crmd: Ensure throttle_mode() does something on Linux
- systemd: Perform actions asynchronously (bsc#956500)
- crm_attribute: Correctly update config options when -o crm_config is specified
- crmd: Fixes crash when remote connection migration fails
- pengine: fixes segfault caused by malformed log warning
- Allow fail-counts to be removed en-mass when the new attrd is in operation
- fencing: Use the correct define for origin
- fencing: Reject actions for devices that haven't been explicitly registered yet
- cts : change default cluster stack from openais to corosync (bsc#894871)
- crm_resource: Ensure fail-counts are purged when we redetect the state of all resources
- corosync: Avoid unnecessary repeated CMAP API calls (bsc#870771)
- cib: Do not update on disk backups if we're just querying them
- mcp: Allow orphan children to initiate node panic via SIGQUIT
- Support machine panics for some kinds of errors (via sbd if available)
- Fencing: Allow the cluster to recover resources if the watchdog is in use
- crmd: If configured, trigger the watchdog immediately if we loose quorum and no-quorum-policy=suicide
- crmd: Ensure a watchdog device is in use if stonith-watchdog-timeout is configured
- Fencing: Advertise the watchdog device for fencing operations
- PE: Allow natural ordering of colocation sets
- stonith-ng: Reset mainloop source IDs after removing them
- Fencing: Force 'stonith-ng' as the system name
- crm_mon: Repair notification delivery when the v2 patch format is in use (bsc#909286)
- mcp: Teach pacemakerd to ignore SIGHUP
- Rebase bug-806256_pacemaker-log-level-notice.patch
- Upstream version cs: 28aee948cebd51305a2cdc3ec4f94252ce975655
* Fri Sep  5 2014 ygao@suse.com
- cluster: Invoke crm_remove_conflicting_peer() only when the new node's uname is being assigned in the node cache (bnc#870771)
- mcp: set environment variable which the cluster-glue module needs
- services: Refector services os execute function
- Upstream version cs: 266d5c2484716111616bcd0f32d9b94bc49baa77
* Wed Aug 27 2014 ygao@suse.com
- logging: correctly initialized default log file (bnc#883567)
- Upstream version cs: 362f181a387e0a0a9f04e0da84d6c5906d71dd20
* Mon Aug 18 2014 ygao@suse.com
- crm_resource: Print a clear message if the attribute is not found for the resource (bnc#890400)
- lrmd: fix rescheduling of systemd monitor op during start
- services: restore SIGPIPE default behavior for child processes
- lrmd: prevent \n from being printed in exit reason output
- lrmd: pass exit reason prefix to ocf scripts as env variable
- Upstream version cs: dad4cebccdb5a4bcdb8fb94e676f6df006ac0846
* Thu Aug  7 2014 ygao@suse.com
- crm_diff: Support generating a difference without versions details if --no-version/-u is supplied (bnc#888726)
- crmd: When container's host is fenced, cancel in-flight operations
- crm_mon: add exit reason to resource failure output
- lrmd: store failed operation exit reason in cib
- Upstream version cs: 1040002ecc1a0dfec9f0561f79936cbe64d716db
* Mon Jul 28 2014 ygao@suse.com
- Bug rhbz#1067544 - Tools: Correctly handle --ban, --move and --locate for master/slave groups
- lrmd: Log with the correct personality
- mainloop: implement gio_poll_dispatch_mod
- Upstream version cs: 483f48a1921241f1f5976a100a171785dc327192
* Tue Jul 22 2014 ygao@suse.com
- Update to version 1.1.12
- Log: Turn off the default log file if a real one is specified
- Log: Do not unconditionally send crm_perror output to stderr
- Log: allows the user to specify a log level that is output to syslog
- Upstream version cs: 561c4cfda1b09b31b60fd5f73644ee05348f41fb (1.1.12)
* Thu Jul 17 2014 ygao@suse.com
- logrotate: maxsize is not supported by older versions (bnc#883567)
- Tools: Non-daemons shouldn't abort just because xml parsing failed
- Log: Default to emitting CRIT messages only until logging is fully configured
- Logging: Bootstrap daemon logging before processing arguments but configure it afterwards (bnc#883567)
- dbus: Return 'null' if we cannot connect via dbus
- Upstream version cs: 026944ebfad7c4b2da5a6864a9d763bf37e0e088
* Thu Jul 10 2014 ygao@suse.com
- systemd: Ensure the retry logic is also exercised for the 'service' class
- crm_simulate: Remove resource states and transient attributes when a node is marked as down
- crm_verify: Perform a full set of calculations whenever the status section is present (bnc#886479)
- PE: Correctly warn when resources require fencing but fencing is disabled (bnc#886479)
- PE: Always use pe_fence_node to mark nodes as unclean
- lrmd: Handle systemd reporting 'done' before a resource is actually stopped
- Upstream version cs: c468fa06483152c29529f81aa0b5ccf37da8b2af
* Thu Jul  3 2014 ygao@suse.com
- attrd: Remove offline nodes from node cache for "peer-remove" requests (bnc#870771)
- membership: Prevent use-after-free in reap_crm_member() (bnc#870771)
- cluster: Remove unknown offline nodes with conflicting unames from node cache (bnc#870771)
- crmd: Remove state of unknown nodes with conflicting unames from CIB (bnc#870771)
- Upstream version cs: 440da7f59ac4bed16a0289e33f04d2635b335c70
* Tue Jul  1 2014 ygao@suse.com
- extra: Add logrotate configuration file for /var/log/pacemaker.log (bnc#883567)
- PE: Correctly detect empty tags
- xml: Ensure realloc didn't fail
- crmd: Only write fence_averride if open() returns a positive file descriptor
- tools: Non-recurring memory leak
- PE: Potential use-of-NULL
- ipc: Buffer size cannot be negative
- xml: Prevent possible array underflow
- mcp: Let daemons know when they have been respawned by the mcp
- cts: fix RemoteBaremetal step2 move resource action failed issue
- PE: Correctly observe requires=nothing
- crmd: Remove unknown nodes with conflicting unames from CIB (bnc#883240)
- controld: Return OCF_ERR_INSTALLED instead of OCF_NOT_INSTALLED (bnc#883729)
- lrmd: Prevent OCF agents from logging to random files due to "value" of setenv() being NULL (bnc#883524)
- cts: fix shutdown pattern not found issue
- Fix: ignore SIGPIPE with gnutls is in use
- crmd: avoid double free caused by nested hash table removal
- crm_report: Correctly detect large files
- cib: cl#5222 - Prevent assert in xml_calculate_changes() on performing cib operations (bnc#881575)
- Upstream version cs: c3f1a7f8912f3d6d17497dd8af0b69fe0708b2b1
* Fri Jun 13 2014 ygao@suse.com
- Bug cl#5219 - PE: Allow unrelated resources with a common colocation target to remain promoted (bnc#899175)
- Bug cl#5222 - Enable legacy mode whenever a broadcast update is detected (bnc#881575)
- xml: Prevent incorrect xml diffs from corrupting the cib (bnc#878362)
- mainloop: implement gio_poll_dispatch_mod
- cluster: Prevent search of unames from attempting to create node entries for unknown nodes (bnc#881884)
- Upstream version cs: 97629ded958f76652350569a54303b3cd25d1d7e
* Wed Jun 11 2014 ygao@suse.com
- crm_report: Gracefully handle rediculously large logfiles
- Bug cl#5222 - cib: Repair rolling update capability (bnc#881575)
- cib: Use a better option name for enabling the legacy cib diff code (cl#5222, bnc#881575)
- remote: clear remote-node status correctly
- pengine: properly handle fencing of container remote-nodes when the container is orphaned
- remote: Handle request/response ipc proxy correctly
- cib: Prevent assert on sending cib sync requests (cl#5222, bnc#881575)
- crm_simulate: Clean up temporary shadow files on exit (bnc#879934)
- pengine: cl#5200 - Before migrating utilization-using resources to a node, take off the load that will no longer run there if it's not introducing transition loop
  (Rework cl#5044, lf#2599, bnc#695440)
- Fencing: Cache metadata lookups to avoid repeated blocking during device registration
- pengine: properly place resource within a container when container is a remote-node.
- mainloop: Better handle the killing of processes in the act of exiting
- services: Remove cancelled recurring ops from internal lists as early as possible (bnc#888586)
- services: Remove file descriptors from mainloop as soon as we have drained them (bnc#888586)
- pengine: Don't report a resource as restarting when it is a moving multistate resource
- pengine: avoid assert by searching for stop action on correct node during LogActions
- Upstream version cs: 734e6b538b0a037f9e7d0709f450bd664f26c332
* Mon Jun  2 2014 ygao@suse.com
- cib: Drop the message serverity now that the cause is well understood
- crmd: Avoid spamming the cib by triggering a transition only once per non-status change
- Upstream version cs: 559f733e8818a96085134cd2a34efc280c512a2a
* Thu May 29 2014 ygao@suse.com
- pengine: Prevent possible segfault (bnc#880258)
- attrd: Ensure attribute dampening is always observed
- Bug cl#5213 - Limit the scope of the previous commit to the masters role
- membership: Avoid duplicate peer entries in the peer cache
- Bug cl#5184 - Ensure pending probes that ultimately fail are correctly updated (bnc#804763, bnc#879034)
- Upstream version cs: 9776707a6232f25812009145fafa8a64c5b53910
* Tue May 27 2014 ygao@suse.com
- Rebase:
  * pacemaker-colocated-utilization.patch
- Bug cl#5213 - Ensure role colocation with -INFINITY is enforced
- pengine: Mark unrunnable stop actions as "blocked" and show the correct current locations (bnc#878662)
- pengine: Block restart of resources if any dependent resource in a group is unmanaged (bnc#878662)
- systemd: Try to handle dbus actions that complete prior to configuring a callback
- mainloop: Canceling in-flight operations should not fail if child process has already exited.
- Bug rhbz#1097457 - Limit the scope of the previous fix and include a helpful comment
- Bug cl#5212 - Do not promote instances when quorum is lots and no-quorum-policy=freeze
- Bug rhbz#1097457 - Prevent invalid transition when resource are ordered to start after the container they're started in
- Fix: fix small memory leaks
- Upstream version cs: 25ebca2b83df9263aedb944ea4eeb53468e90e83
* Fri May 23 2014 jsegitz@novell.com
- added necessary macros for systemd files
* Mon May 12 2014 ygao@suse.com
- pengine: Use "#site-name" in rules for setting site-specific instance attributes
- pengine: Use "#cluster-name" in rules for setting cluster-specific instance attributes (FATE#316118)
- crmd: Set "cluster-name" property to corosync's "cluster_name" by default for corosync-2 (FATE#316118)
- pengine: Fixed so that it could change while a setup of "startup-fencing" starts.
- crmd: Use correctly signed inputs to sscanf()
- PE: Correctly handle origin offsets in the future
- iso8601: Different logic is needed when logging and calculating durations
- xml: Do not prune meaningful leaves from v1 patchsets
- Upstream version cs: da5aaab97ca5b7858f2aac98107a1a7ffc3e4252
* Thu May  8 2014 ro@suse.de
- use _rundir macro
* Mon May  5 2014 ygao@suse.com
- Rebase:
  * pacemaker-NodeUtilization-RA.patch
  * pacemaker-colocated-utilization.patch
- xml: Clean up schema list at exit
- pengine: Support site-specific instance attributes based on rules for stretch cluster
- pengine: Support cluster-specific instance attributes based on rules (FATE#316118)
- crmd: Ensure crm_config options are re-read on updates
- Resolve all clang analyser defects
- xml: Check all available schemas when doing upgrades
- Changes to the ACL schema to support nodes and unix groups
- tools: Allow crm_shadow to create older configuration versions
- xml: Prevent use-after-free when comparing two xml documents
- cib: Resolve memory leaks in query paths
- xml: Correctly subtract xml with v1 patchsets
- fencing: Advertise support for reboot/on/off in the metadata for legacy agents
- fencing: default to 'off' when agent does not advertise 'reboot' in metadata
- fencing: Execute all required fencing devices regardless of what topology level they are at
- fencing: Fence using all required devices
- fencing: fixed so that change of <resources> could be handled correctly.
- Upstream version cs: 42ae0e3cb50bb9e19dba7d1ad1ea69255bef5370
* Wed Apr 16 2014 ygao@suse.com
- pengine: Fix memory leak in expand_tags_in_sets()
- PE: Memory leak
- PE: Do not initiate fencing for unclean nodes when fencing is disabled
- crm_node: Only remove the named resource from the cib
- pengine: Support site-specific instance attributes based on rules (FATE#316118)
- pengine: Ignore failure-timeout only if the failed operation has on-fail="block" (bnc#871175)
- Upstream version cs: f7859e2e06c8cf320482c3e4b447ddbe0a96fe83
* Mon Apr 14 2014 ygao@suse.com
- pengine: Support cib object tags (FATE#315101)
- crmd: Correctly detect changes of ticket state (bnc#872794)
- Upstream version cs: 3f7ec44b51825898e3e30784ca4df09e3f45bf40
* Fri Apr 11 2014 ygao@suse.com
- Rebase:
  * bug-812269_pacemaker-fencing-device-register-messages.patch
- Build: Update versions in configure.ac and sample spec file
- fencing: Do not unregister/register all stonith devices on every resource agent change
- PE: Unfencing is based on device probes, there is no need to unfence when normal resources are found active
- pengine: handles edge case where container order constraints are not honored during migration
- pengine: Allow container nodes to migrate with connection resource
- xml: Resolve memory leak when logging xml blobs
- PE: Do not unfence nodes that are offline, unclean or shutting down
- PE: Ensure unfencing only happens once, even if the transition is interrupted
- crmd: Actions can only be executed if their pre-requisits completed successfully
- crmd: Do not erase the status section for unfenced nodes
- Fencing: Correctly record which peer performed the fencing operation
- lrmd: Expose logging variables expected by OCF agents
- logging: Simplify processing of logging directives
- logging: daemons always get a log file, unless explicitly set to configured 'none'
- PE: Ensure unfencing occurs before fencing devices are (re-)probed
- fencing: Filter self-fencing at the peers to allow unfencing to work correctly
- fencing: Automatically switch from 'list' to 'status' to 'static-list' if those actions are not advertised in the metadata
- lrmd: Provide stderr output from agents if available, otherwise fall back to stdout
- fencing: properly detect new fencing devices for v2 cib updates
- acl: Prevent use-of-NULL
- cts: automatically determine whether to run RemoteBaremetal (bnc#856353)
- pengine: Correctly search failcount (bnc#880520)
- Upstream version cs: ff74a591e670dbdb86f7cddeec989167de521216
* Wed Apr  9 2014 ygao@suse.com
- pengine: Support id-ref in nvpair with optional "name" (FATE#316118)
  Drop the patches that have been merged upstream:
  * pacemaker-pengine-nvpair-id-ref.patch
  * pacemaker-pengine-nvpair-id-ref-test.patch
- Upstream version cs: 6442c5a67cdd4cbaeedb2c532e0dc0667a79c202
* Tue Apr  8 2014 ygao@suse.com
- xml: INFINITY could overflow for 16-bit ints - explicitly cast it
- xml: Correctly determine the lowest allowed schema version
- xml: Construct the table of supported schemas
- cib: All schema upgrade requests must go via the DC
- cib: Determine the best value of validate-with if one is not supplied
- acl: Ensure known users are not able to read the cib by default
- xml: Add missing schema file
- Upstream version cs: d9fbba56804a7a7bcceaa5d4b7e29e3f15fc0e59
* Fri Apr  4 2014 ygao@suse.com
- crmd: Correctly react to successful unfencing operations
- PE: Delay unfencing until after we know the state of all resources that require unfencing
- PE: Fencing devices default to only requiring quorum in order to start
- PE: Automatically re-unfence a node if the fencing device definition changes
- pengine: Only report 'migrate' in transition summary if migration is actually taking place
- crm_node: Set correct subsystem in node rm cache msg
- crm_node: Prevent use-after-free in tools_remove_node_cache()
- crmd: make resource ID case sensitive
- fencing: Correction of the registration from a difference.
- crm_report: Add support for ISO8601 time format in logs (bnc#870886)
- PE: Potential memory leak
- xml: Support resources that require unfencing
- crmd: make node_state erase correctly
- xml: Add the ability to have lightweight schema revisions
- xml: Split up the RelaxNG schema files so they're easier to version individually
- crm_get_msec: prevent integer overflow
- corosync: Reduce log severity for a redundant message (bnc#870624)
- attrd: Reduce log severity for normal messages (bnc#870624)
- cib: When data was old, it fixed so that the newest cib might not be acquired.
- crm_attribute: Default --lifetime to forever when using --node (bnc#870696)
- Upstream version cs: 76579e813b5aaa1972d400055233519f58bbc0c6
* Mon Mar 31 2014 ygao@suse.com
- pengine: Do not fence remote-node entries left over in the node section that have no connection rsc
- pengine: properly handle remote-node without connection resource.
- xml: Update xml validation to allow '<node type=remote />'
- cib: allow setting permanent remote-node attributes
- Upstream version cs: d63eaf41fa8173de3e29873d0461bfb888b83b37
* Fri Mar 28 2014 ygao@suse.com
- xml: Allow first-acl-match-wins semantics to be supported if desired
- crm_report: extract additional DLM lockspace data
- xml: If validate-with is missing, we find the most recent schema that accepts it and go from there
- tools: fix "crm_shadow --reset <name>"
- controld: Remove '-q 0' from default dlm_controld arguments
- acl: Authenticate pacemaker-remote requests with the node name as the client
- controld: Verify killall is available on resource start
- Prevent use-of-NULL spotted by coverity
- crmd: Correctly detect changes to the configuration root
- crmd: Fenced nodes that return prior to an election do not need to have their status section reset
- xml: Do not log deleted attributes
- xml: Correctly mark the parent's of deleted attributes as dirty
- crm_diff: Allow the generation of xml patchsets without digests
- crmd: Prevent memory leak when accepting a new DC
- xml: Find the minimal set of changes when part of a document is replaced
- xml: Create the correct diff when only part of a document is changed
- Upstream version cs: 61e95e4864be0301be528874eed65266f4e62cf0
* Fri Mar 21 2014 ygao@suse.com
- pengine: fixes invalid transition caused by clones with more than 10 instances
- services_action_cancel: Interpret return code from mainloop_child_kill() correctly
- fencing: make hashtable mapping hostname->alias case insensitive for hostname
- attrd: Make hostname hashtable case insensitive
- membership: make caching peers by uname case insensitive
- crmd: make lrm_state hash table not case sensitive
- lrmd: clean up the agent's entire process group
- xml: Enable resource sets in location constraints for 1.2 schema (bnc#867880)
- Upstream version cs: 8bee850bb95ee01dcba03038ddfd65d22e195cf6
* Thu Mar 13 2014 ygao@suse.com
- Drop obsolete bug-792124_pacemaker-stonith-monitor-log.patch
* Thu Mar 13 2014 ygao@suse.com
- mainloop: Fixes use after free in process monitor code
- lrmd: Cancel recurring operations before stop action is executed
- lrmd: Merge duplicate recurring monitor operations
- services: Do not allow duplicate recurring op entries
- crmd: Ack pending operations that were cancelled due to rsc deletion (bsc#1035822)
- crm_mon: Add failures to --as-xml output
- cib: Check if on-disk cib is corrupt in the separate on_disk_cib_corrupt() rather than in validate_on_disk_cib() (bnc#866618)
- crmd: Do not start timers for already completed operations
- acl: Read access must be explicitly granted
- xml: Better move detection logic for xml nodes
- cib: Do not disable cib disk writes if on-disk cib is corrupt (bnc#866618)
- xml: Correctly calculate the adjusted offset of xml elements
- crm_diff: Mirror how the cib operates for better testing
- cib: Ingore patch failures if we already have their contents
- cib: Prevent use-after-free when cleaning up after query operations
- xml: Mark the parents of a partial replace as dirty
- xml: Correctly enforce ACLs after a replace operation
- cib: Do not try to use an empty value for CIB_shadow
- crm_resource: Gracefully handle -EACCESS when querying the cib
- xml: Correctly observe ACLs when creating filtered copies of xml documents
- xml: Only test write permissions for attributes that are being changed
- xml: Always allow new scaffolding - node with no attributes or only an id field
- cib: Memory leaks caused by ACLs returning filtered copies
- xml: Set flags to indicate when updates were rejected by an ACL
- cib: Respect the CIB_user environment variable for ACLs
- xml: Unpack and apply ACLs when tracking changes
- cib: Implement CIB_file-mode ACLs for testing
- remote: Enable migration support for baremetal connection resources by default
- cibadmin: Allow priviliged clients to perform tasks as unpriviliged users
- cibadmin: Remove dangerous commands that exposed unnecessary implementation internal details
- cibadmin: Purge legacy command options deprecated since 2008 to make the short-forms available for new options
- cib: Include a request with file-mode cib actions for the acl code to interrogate
- cib: Switch over completely to the new ACL code
- xml: Allow new objects to be created provided they subseqently match a configured ACL
- cib: Use the new acl filtering functionality
- xml: Support the creation of filtered copies based on ACLs
- xml: Convert all ACLs to xpaths during unpack
- xml: Add ACL flags for xpath selectors when tracking is enabled
- cib: ACL improvements
- cib: Simplify ACL handling for read-only cib queries
- cib: Check ACLs prior to making the update instead of parsing the diff afterwards
- cib: Default ACL support to on
- Upstream version cs: 38c5972cd284ea6627b3309b619dad4d27442ab0
* Mon Mar  3 2014 ygao@suse.com
- Add symlinks rcpacemaker and rcpacemaker_remote to /usr/bin/service (bnc#866057)
* Mon Mar  3 2014 ygao@suse.com
- Rebase bug-812269_pacemaker-fencing-device-register-messages.patch
* Mon Mar  3 2014 ygao@suse.com
- xml: Memory leak when free'ing xml documents
- systemd: Prevent use-of-NULL when determining if an agent exists
- xml: Fix segfault in TRACKING_CHANGES() (bnc#865345)
- PE: Memory leak when updating cancel operations
- xml: Prevent memory leak in xml _private field
- pengine: Performance increase, stack allocated score2char
- crm_report: Only gather dlm data if dlm_controld is running
- Fix: memory leak found by valgrind was corrected.
- Fencing: Add the ability to call stonith_api_time() from stonith_admin
- Fencing: Pass the correct options when looking up the history by node name
- cib: Ensure 'cibadmin -R/--replace' commands get replies
- xml: Correctly initialize and find v1-style patch version numbers
- crm_mon: Add -R switch to show clone details
- Build: Install compatibility.h
- fencing: Teach stonith-ng about finding device and topology changes in the v2 patch format
- crm_report: Additional dlm detail
- crm_report: Allow ssh alternatives to be used
- crmd: Correctly recognise operation cancellations we initiated
- crmd: Improved logging of transition cancellations
- crmd: Correctly detect lrm refreshes
- crmd: Ignore 'move' operations to the cib, we only care about content changes
- PE: Ensure instance numbers are preserved for cloned templates
- Bug cl#5196 - PE: Check values after expanding templates
- crm_mon: Ensure resource attributes have been unpacked before displaying connectivity data
- Upstream version cs: ca8234daf2bbb2d0fd2fb47cdbb6667f892081bb
* Mon Mar  3 2014 ygao@suse.com
- pengine: Support id-ref in nvpair with optional "name" (FATE#316118)
  * pacemaker-pengine-nvpair-id-ref.patch
  * pacemaker-pengine-nvpair-id-ref-test.patch
* Fri Feb 21 2014 ygao@suse.com
- controld: Do not consider the dlm up until the address list is present
- pengine: Support per-resource maintenance mode (bnc#863071)
- pengine: cl#5187 - Prevent resources in an anti-colocation from even temporarily running on a same node (bnc#856135, bnc#862319)
- controld: handling startup fencing within the controld agent, not the dlm
- Upstream version cs: 0b7d85a159cc92e00ebded65c9a33edce7ba1c22
* Fri Feb 21 2014 ygao@suse.com
- cib: Erasing the cib is an admin action, bump the admin_epoch instead
- mcp: Tell systemd not to respawn us if we exit with rc=100
- crm_mon: Allow the file created by --as-html to be world readable
- crmd: Do not overwrite existing node state when fencing completes
- PE: Default sequential to TRUE for resource sets for consistency with colocation sets
- Bug rhbz#1036631 - Stop members of cloned groups when dependancies are stopped
- PE: Ensure stop actions are viable when reporting what will happen to a resource
- xml: Consolidate patchset logging and apply functionality
- cib: Validate that everyone still sees the same configuration once all updates have completed
- cib: Validate clients are correctly applying v2-style diffs at most once a minute
- xml: Allow both patch formats to include and validate an xml digest
- election: If an error occurrs in crm_uptime(), compare as {0,0}
- xml: Correctly compare the current feature set when determining which patch format to use
- crmd: Support failcount processing with the new patch format
- crmd: Handle patchset directives that change the configuration top-level
- cib: Make patchset validation a run-time switch
- cib: Implement zero-copy status update
- cib: Enable the more efficient xml patchset format
- crmd: Add support for parsing resource operations in the v2 patch format
- xml: New function for calculating patchset version details
- cib: Auto-detect which patchset format to use
- xml: Allow the source of xml library errors to be traced
- cib: Send all r/w operations via the cluster connection and have all nodes process them
- xml: Use an optimized xpath search function for applying patch sets
- xml: Use the new patch application code path
- xml: Detect changes in global replace operations
- xml: allow either patch format to be created and applied automatically
- xml: Create a more robust diff format
- xml: Track changes to xml trees as they happen
- Upstream version cs: 0d3f74a5caa7e0f7d1f5ccc97e0d2d018ed8bdfc
* Thu Feb 20 2014 ygao@suse.com
- Update to version 1.1.11
- Drop the patches that have been merged upstream:
  * pacemaker-display-pending-ops.patch
  * pacemaker-crm_mon-brief.patch
- pengine: Prevent memory leak on handling pending state
- crmd: Prevent message relay from attempting to create node entries for unknown nodes (bnc#862383)
- attrd: Support "--refresh" command of attrd_updater
- crmd: Prevent manual fencing confirmations from attempting to create node entries for unknown nodes (bnc#860169)
- Upstream version cs: 3ca8c3bf87057339c9f2a55cd137db8c9c9922f0
* Sat Feb  8 2014 ygao@suse.com
- ipc: Convince clang that our casting is intended (bnc#845525)
  * Drop pacemaker-Wno-cast-align.patch which has been merged upstream
- cib: Use the correctly typed enum value during initialization
- Build: Add dbus as an rpm dependancy
- Fix: Bug rhbz#1057697 - Use native DBus library for systemd async support to avoid problematic use of threads
- remote: Fail remote-node connection rsc monitor ops early on unexpected disconnect
- tools: Return error when attempting to delete an unspecified attribute
- remote: Allow baremetal remote-node connection resources to migrate
- lrmd: Send event alerting estabilished clients that a new client connection is created.
- Fix: Bug rhbz#1057697 - Use native DBus library for systemd support to avoid problematic use of threads
- xml: Fix segfault in find_entity()
- Upstream version cs: 6290953f2b035a92a8f093973b94c5cf38b79cd9
* Tue Jan 28 2014 ygao@suse.com
- pengine: Free memory allocated by find_actions()
- cib: Fix remote cib based on TLS
- Upstream version cs: f3eeaf49d1fb7bca713ecbbc819aef51650d26ef
* Tue Jan 28 2014 ygao@suse.com
- stonith: Drop the severity of log for recoverable condition (bnc#857779)
  * Update bug-812269_pacemaker-fencing-device-register-messages.patch
* Sat Jan 25 2014 ygao@suse.com
- Build: Suppress -Wcast-align warnings/errors on arm and ppc64le (bnc#845525)
  * Update pacemaker-Wno-cast-align.patch
* Sat Jan 25 2014 ygao@suse.com
- services: Do not block synced service executions
- Upstream version cs: 96cd1941308be48fdf1e827b88ebd9410cf2010a
* Fri Jan 24 2014 ygao@suse.com
- crm_mon: Display brief output if "-b/--brief" is supplied or 'b' is toggled (FATE#314757)
  * Add pacemaker-crm_mon-brief.patch
- tools: Display pending state in crm_mon/crm_resource/crm_simulate if --pending/-j is supplied (cl#5178) (FATE#315159)
  * Add pacemaker-display-pending-ops.patch
* Mon Jan 20 2014 ygao@suse.com
- Drop the obsolete patch (bnc#857779):
  * bug-812269_pacemaker-fencing-update-cib.patch
* Mon Jan 20 2014 ygao@suse.com
- crm_report: Force grep to interpret logs as text
- pengine: Force record pending for migrate_to actions
- pengine: cl#5186 - Avoid running rsc on two nodes when node is fenced during migration
- cluster: Fix segfault on removing a node (bnc#858745)
- services: Reset the scheduling policy and priority for lrmd's children without replying on SCHED_RESET_ON_FORK (bnc#858857)
- fencing: Update stonith device list only if stonith is enabled (bnc#857779)
- services: Correctly reset the nice value for lrmd's children (bnc#858857)
- pengine: Correctly perform partial migrations when node's uname is not equal to the id.
- fencing: Immediately fail remote fencing operation on peer timeout
- cl#5055: Improved migration support.
- stonith_admin: Ensure pointers passed to sscanf() are properly initialized
- Fix: Prevent potential use-of-NULL
- crmd: Prevent memory leak in error paths
- services: Fixes segfault associated with cancelling in-flight recurring operations. (bnc#859923)
- pengine: cl#5174 - Allow resource sets and templates for location constraints (FATE#315158)
- Upstream version cs: a3cda7619e71399d54f209296aebf3ba713a0bf4
* Sat Jan 11 2014 ygao@suse.com
- crmd: Change the default value of node-action-limit
- crm_ticket: Support multiple modifications for a ticket in an atomic operation (bnc#855099)
- Upstream version cs: 3e8930190b8b53565ef4ca3fa00006c41511be9f
* Thu Jan  9 2014 ygao@suse.com
- ipc: fix memory leak for failed ipc client connections. (bnc#857779)
- pacemakerd: Fixed a problem that only pacemakerd did not inherit the logfacility of corosync.conf.
- pengine: Fixes memory leak in regex pattern matching code for constraints.
- crm_attribute: Do not swallow hostname lookup failures
- crmd: Avoid deleting the 'shutdown' attribute
- Upstream version cs: ad10acb1c4d668befd7ea1d39312356223d86615
* Wed Dec 11 2013 ygao@suse.com
- cts: Install cib_xml.py (bnc#854926)
- report: Add support for xz compressed logs (bnc#854060)
- attrd: Memory leak
- crm_mon: Fix overflow on SMTP subject line
- Upstream version cs: 65bb87eadcf6dfd9b5cd6030ec318579fd4fe7c8
* Thu Dec  5 2013 ygao@suse.com
- Fix: Removes unnecessary newlines in crm_resource -O output (bnc#853651)
- Upstream version cs: 93a37bf6ea4dcaea8fe7462442ee01019ec167c5
* Thu Nov 28 2013 ygao@suse.com
- crmd: Memory leak
- Upstream version cs: ce5d77c6038a0a0294d4cae238169c458ba03b72
* Mon Nov 25 2013 ygao@suse.com
- pengine: Recover unexpectedly running container nodes.
- pengine: Disable container node probes due to constraint conflicts
- ipc: Have the ipc server enforce a minimum buffer size all clients must use.
- Bug cl#5181 - corosync: Ensure node IDs are written to the CIB as unsigned integers
- Upstream version cs: f57ad6c17624c0cbfc58c46f0bad7e28453506bb
* Tue Nov 19 2013 ygao@suse.com
- Update pacemaker-colocated-utilization.patch
  * pengine: Do not check the allocation of resources during a colocation preview (bnc#849595)
* Tue Nov 19 2013 ygao@suse.com
- election: Correctly hook up the timeout callback
- crmd: Improve throttling response on clusters of single core machines (bnc#838358)
- fencing: Wait until all possible replies are recieved before continuing with unverified devices
- Bug cl#5179 - Corosync: Attempt to retrieve a peer's node name if it is not already known
- Core: Allow blackbox logging to be disabled with SIGUSR2
- PE: Correctly handle demotion of grouped masters that are partially demoted
- crmd: When the DC gracefully shuts down, record the new expected state into the cib
- crmd: When a peer expectedly shuts down, record the new join and expected states into the cib
- attrd: Memory leak
- attrd: Do something sane when older non-atomic versions send us messages
- crmd: Correctly observe the configured batch-limit (bnc#838358)
- attrd: Improve compatibility with older attrd versions
- controld: Use the correct variant of dlm_controld for corosync-2 clusters
- lrmd: Correctly calculate metadata for the 'service' class
- crmd: Prevent over-polling of throttle inputs (bnc#838358)
- crmd: Enable cluster-wide throttling when the cib heavily exceeds its target load (bnc#838358)
- Upstream version cs: 5a69be5ff56ec7fa66bcf9c2069af6211e4ebc98
* Thu Nov 14 2013 ygao@suse.com
- crmd: Send the first throttle update (bnc#838358)
- Upstream version cs: 2383f6c469bfb31da9efa8e4dd626de049e808c6
* Sun Nov 10 2013 ygao@suse.com
- Rebase:
  * bug-806256_pacemaker-log-level-notice.patch
- Drop the obsolete patch:
  * bug-800323_pacemaker-crm_mon-save-cib.patch
- Probe for baremetal remote-node connection resources.
- remote: Add support for ipv6 into pacemaker_remote daemon
- election/fencing: Fix the casts that would result in incorrect values for big-endian systems (bnc#842915)
- Fencing: Apply correct score to the resource of group
- crm_resource: Wait for the correct number of replies when cleaning up resources (bnc#842204)
- cpg: Only process one message at a time to allow other priority jobs to be performed
- remote: Handle endian changes between client and server and improve forward compatibility
- crmd: A more reliable method of looking up migration options (bnc#838358)
- crmd: Allow non-CIB based throttling to be disabled (bnc#838358)
- crmd: Honor load thresholds lower than the cib maximum (bnc#838358)
- crmd: Tell the DC our job limit instead of the number of cores (bnc#838358)
- crmd: Track the CIB's CPU usage (bnc#838358)
- crmd: Fold the enforcement of migration-limit into the throttling code (bnc#838358)
- crmd: Don't start throttling until we're over the target threshold (bnc#838358)
- crmd: Do not send throttle updates to versions that don't support them (bnc#838358)
- ipc: Use the higher of the configured buffer size or the default
- crmd: Tweak the throttling threshold multipliers (bnc#838358)
- crmd: Simplify option processing for throttling options (bnc#838358)
- crmd: Simplify the logic for calculating the number of available cores (bnc#838358)
- crmd: Make the per-node action limit directly configurable in the CIB (bnc#838358)
- crmd: Tweak the throttling code based on migration-limit and/or LRMD_MAX_CHILDREN (bnc#838358)
- crmd: Slow down recovery on nodes with IO load (bnc#838358)
- crmd: Make the utilization limit configurable (bnc#838358)
- crmd: Use the load on our peers to know how many jobs to send them (bnc#838358)
- crmd: Notify peers of our relative load (bnc#838358)
- remote: Properly version the remote connection protocol
- crmd: Track CPU usage on cluster nodes (bnc#838358)
- ipc: Consolidate client/server flags and add version field to header
- ipc: Suppress asserts for proxied connections
- crmd: Do not block on proxied calls from pacemaker_remoted
- lrmd: Do not interrogate NULL replies from the server
- crm_mon: Reduce flickering in interactive mode
- fencing: Ignore changes to non-fencing resources
- cli: Do not enabled blackbox for cli tools
- crm_resource: Wait for all replies when cleaning up resources (bnc#842204)
- crm_mon: Correctly show the queued and exec times for an action
- crmd: Correctly update expected state when the previous DC shuts down
- crm_resource: Observe --master modifier for --move
- PE: Location constraints with role=Started should prevent masters from running at all
- Upstream version cs: 907f52608e97b4f280690618342e1377f184b554
* Tue Oct 22 2013 schwab@suse.de
- Disable -Wcast-align on problematic files (bnc#845525)
* Tue Oct 22 2013 ygao@suse.com
- iso8601: Prevent dates from jumping backwards a day in some timezones
- crm_master: Avoid sending redundant "--node" options to crm_attribute (bnc#846360)
- ipc: Client buffer size must never fall below our max read size
- ipc: Ensure buffer environment variable is read before setting max buffer len
- fencing: Deep copy current topology level list on remote op
- Upstream version cs: afdce1faecf82c778ed81eb5eb9b7518d36a1160
* Thu Oct 17 2013 ygao@suse.com
- crm_resource: Wait for a reply for each request to crmd (bnc#842204)
- Upstream version cs: 7afb87c8caa96d3c1ed9a353ae6061023a729fd4
* Wed Oct 16 2013 ygao@suse.com
- Cluster: On cluster signoff, make sure that the g_source gets disconnected.
- crmd: Using PCMK_ipc_buffer variable for remote-node proxy
- plugin: Reset the scheduling policy of daemons to SCHED_OTHER with nice value -10 (bnc#843647)
- ipc: Compress msgs based on client's actual max send size
- pengine: Do not probe for connection resources
- Upstream version cs: 490e695539630cfc158c5967a99237659fac5f30
* Thu Oct  3 2013 ygao@suse.com
- fencing: Allow fencing for node after topology entries are deleted
- fencing: Do not broadcast suicide if the on action is being executed
- remote: Option to enable/disable probes on container resource remote-nodes
- lrmd: Correctly cancel monitor actions for lsb/systemd/service resources on cleaning up (bnc#842471)
- services: Fix the executing of synchronous actions
- Upstream version cs: 728ec77851540f9ce64ee1b1269d967841571b25
* Sun Sep 29 2013 ygao@suse.com
- PE: Add a special attribute for distinguishing between real nodes and containers in constraint rules
- PE: Allow location constraints to take a regex pattern to match against resource IDs
- Bug rhbz#1011618 - Consistently use 'Slave' as the role for unpromoted master/slave resources
- cibadmin: Report errors during sign-off
- Fencing: Observe pcmk_host_list during automatic unfencing
- services: Prevent use-of-NULL when executing service actions
- crm_resource: Provide a meaningful error if --master is used for primitives and groups
- ipc: Raise the default buffer size to 128k (bnc#838358)
- Upstream version cs: ecd44e642db3b65ee83aceed0e93376894a58c47
* Wed Sep 25 2013 lmb@suse.com
- plugin: stonith-ng needs membership updates (bnc#841010)
- controld: allow the stonith-enabled check to be overridden
  (bnc#842186, fate#315195)
- attrd: Avoid infinite write loop for unknown peers
- tools: Detect orphaned remote-nodes when setting attributes
- controld: don't start dlm if stonith-enabled is false (bnc#842186, fate#315195)
- pengine: Probe container nodes
- crmd: Tell attrd when remote-node is disconnected
- attrd: Give remote-nodes ability to set attributes with attrd
- Upstream version cs: c68919f46bbaa96ec4ff2c770f82588280277fe6
* Wed Sep 25 2013 lmb@suse.com
- crmd: Expose "expected-quorum-votes" option in the metadata only for plugin-based clusters
- decode_transition_key: Older systems do not support '%%ms' in
  sscanf
- cib: Guard against overly long user specified strings
- crm_shadow: Simplify prompt generation and impose a sane limit on
  length
- fencing: Skip empty notifications from the cib
- election: Do not update state when ACKs arrive
- cib: Additional logging for invalid diff updates
- cib: Correctly check for archived configuration files
- crmd: Reliably detect and act on reprobe operations from the policy
  engine
- crm_mon: Do not display duplicates of failed actions
- crm_node: Display partition output in sorted order
- cib: Allow values to be added/updated and removed in a single update
- attrd: Use the truely atomic version where CPG is used for cluster communication
- attrd: Untested reimplementation of a truely atomic attrd
- election: Track the election state and allow it to be queried
- crm_resource: Handle --ban for master/slave resources as advertised
  (rhbz#902407)
- xml: Location constraints are allowed to specify a role
- Review and refresh all patches to apply without fuzz.
- Upstream version cs: 144c2fc4b2f50623cbc87bf20788717e0b058a38
* Tue Sep 24 2013 ygao@suse.com
- Rebase:
  * bug-728579_pacemaker-stonith-dev-id.patch
  * bug-806256_pacemaker-log-level-notice.patch
  * bug-812269_pacemaker-fencing-device-register-messages.patch
- Drop the patches that have been merged upstream:
  * pacemaker-node-maintenance.patch
  * pacemaker-node-maintenance-tests.patch
  * pacemaker-crmd-pending-delete.patch
  * pacemaker-resource.patch
- Drop the obsolete patches:
  * pacemaker-cts-startcmd.patch
  * pacemaker-disable-listing-fence-agents.patch
  * pacemaker-daemon-symlinks.patch
  * pacemaker-ptest-build.patch
  * pacemaker-lrmd-remote-disabled.patch
  * bug-815447_pacemaker-cib-strip-text-nodes.patch
  * bug-809635_pacemaker-xml-digest.patch
- Drop the obsolete source:
  * heartbeat-doc-1.0.tar.gz
* Tue Sep 17 2013 ygao@suse.com
- spec: Recommends fence-agents and sbd
* Tue Sep 10 2013 ygao@suse.com
- pengine: Properly handle orphaned multistate resources living on remote-nodes
- pengine: Map orphaned container fillers to container resource during shutdown to preserve ordering
- pengine: Do not attempt to probe resources on remote-nodes that are shutting down
- cib: Prevent potential double free in get_remote_uuid
- pengine: Properly shutdown orphaned remote connection resources
- crmd: Populate remote peer cache when building new cib
- crmd: Clear remote-node status AFTER start completes, not before.
- pengine: Probe resources on baremetal remote-nodes
- crmd: Remote-node fencing glue
- pengine: Allow fencing of baremetal remote nodes
- crmd: Cache baremetal remote-nodes
- tools: Fixes formatting of remote-nodes in crm_mon and crm_simulate
- Upstream version cs: d9bb7632492b1f91a300fb43e9ad8a262a8f2928
* Wed Sep  4 2013 ygao@suse.com
- cib: Support XML comments in diffs (bnc#836965)
- Upstream version cs: 5d0a2239543bd5003444af4a16780ac47fd37079
* Mon Sep  2 2013 ygao@suse.com
- crm_mon: add --hide-headers option to hide all headers
- pengine: Order demote/promote of resources on remote nodes to happen only once the connection is up
- tools: clear ncurses screen when crm_mon cannot connect
- crmd: Invalid formatting of log message causes crash
- remote: Properly handle expected late replies when TLS transport is in use.
- cluster: Allow remote-nodes to be cached
- Upstream version cs: a4eb44fd075e8cb8608f5e45522cade45658ff98
* Wed Aug 21 2013 ygao@suse.com
- Fencing: Support agents that need the host to be unfenced at startup
- cpg: Correctly set the group name length
- pengine: Distinguish between the agent being missing and something the agent needs being missing (bnc#833374)
- crmd: Prevent PCMK_LRM_OP_NOT_INSTALLED for being mapped to PCMK_LRM_OP_ERROR
- Bug cl#5171 - PE: Don't prevent clones from running due to dependant resources
- services: Correctly invoke callbacks for aborted operations
- services: Preserve errno when handling exec failres least it be reset as a side-effect of other calls
- services: Prevent use-of-NULL in g_error_free
- services: Detect missing agents and permission errors before forking
- lrmd: Do not overwrite any existing operation status error
- crmd: Correcty update the history cache when recurring ops change their return code
- PE: Correctly account for the location preferences of things colocated with a group
- crmd: Gracefully handle actions that cannot be initiated
- crm_simulate: Do not complain about CRM_OP_REPROBE actions
- PE: Gracefully handle bad values for XML_ATTR_TRANSITION_MAGIC
- crm_mon: Correctly extract alternate name for pingd attributes
- Fix: Prevent use-of-NULL when ping resources do not define a host list
- Fix: Gracefully handle -ECHILD from waitpid() in crm_abort()
- Fix: Command-line tools should stop after an assertion failure
- systemd: Prevent glib assertion - only call g_error_free() with non-NULL arguments
- Upstream version cs: 4f672bc85eefd33e2fb09b601bb8ec1510645468
* Mon Aug  5 2013 ygao@suse.com
- crmd: Don't add node_state to cib, if we have not seen or fenced this node yet
- PE: Do not allow colocation with blocked clone instances
- PE: Do not re-allocate clone instances that are blocked in the Stopped state
- fence_legacy: stonithd now handles killing the process group for us
- Fencing: On timeout, clean up the agent's entire process group
- fencing: Put all fencing agent processes into their own process group
- crmd: Prevent crash by passing log arguments in the correct order
- PE: Do not restart resources that depend on unmanaged resources
- crmd: Prevent recurring monitors being cancelled due to notify operations
- mcp: Fix so that only pacemakerd restarts, at the time of pacemakerd failure
- mcp: Support PCMK_fail_fast to reboot a machine at the time of process (subsystem) failure
- cpg: Ensure the CPG group is always null-terminated
- Upstream version cs: ac7aa1c94f317fc1d4024fbc09b012bc9f1b229e
* Fri Jul 26 2013 ygao@suse.com
- Update to version 1.1.10
- crm_resource: Allow options to be set recursively
- cib: Correctly read back archived configurations if the primary is corrupted
- mainloop: Hand the channel off to g_io_watch and forget it.
- mainloop: Force removal of ipc fd in dispatch_del callback
- crmd: Clean up handling of pending operations at shutdown and improve logging
- Bug cl#5161 - crmd: Prevent memory leak in operation cache
- cib: Ensure we set up hacluster's groups in stand-alone mode
- Upstream version cs: 368c72641139785ec5981813f311fae8cd1410f3 (1.1.10)
* Mon Jul 22 2013 ygao@suse.com
- cpg: Correctly free sent messages (bnc#853675, bnc#856018)
- crm_resource: Present an error if an admin tries to --force-start an already active resource
- cluster: Correctly construct the header for compressed messages (bnc#851951, bnc#856018)
- PE: Re-allow ordering constraints with fencing devices now that it is safe to do so
- cl#5170 - Correctly support on-fail=block for clones
- PE: Do the right thing when admins specify the internal resource instead of the clone
- fencing: Correctly detect existing device entries when registering a new one
- crm_node: Return 0 if --remove passed
- remove the mainloop_trigger that are no longer needed.
- corosync: Ensure removed peers are erased from all caches
- cluster: Detect and warn about node names with capitals
- Upstream version cs: 9abe6876d50ff2879f17b08dfa1500817a7fbeba
* Thu Jul 11 2013 ygao@suse.com
- crmd: Prevent messages for remote crmd clients from being relayed to wrong daemons
* Wed Jul 10 2013 ygao@suse.com
- lrmd: Prevent use-of-NULL in client library
- Upstream version cs: 9d656180294770e39deced79a134d4cf531b8159
* Wed Jul 10 2013 ygao@suse.com
- Bug cl#5168 - Prevent clones from being bounced around the cluster due to location constraints
- Upstream version cs: 90b8afe77ab8a3ff2fd30826187fd7726aab4f04
* Tue Jul  9 2013 ygao@suse.com
- crm_mon: Bug cl#5167 - Only print "stopped" node list for incomplete clone sets
- Upstream version cs: d16f4c56b120c5ae761680cfb4d98922a185c6c2
* Thu Jul  4 2013 ygao@suse.com
- Fix: memory leak when used score2char()
- Fencing: Avoid hashtable lookups in NULL
- Fencing: Force use of the calculated command for support ops
- Bug cl#5157 - Allow migration in the absence of some colocation constraints
- PE: Detect constraints with inappropriate actions (ie. promote for a clone)
- PE: Do the right thing when admins specify the internal resource instead of the clone
- Fencing: User-defined arguments always trump calculated ones
- cluster: Correctly remove duplicate peer entries
- Upstream version cs: 0dc3203917438057ab476a0f0aac4a1c8e27f97a
* Wed Jul  3 2013 ygao@suse.com
- plugin: Fix memory leaks
- Upstream version cs: 5053ba656a854bdf4eacaf7d43b0dce1b7e58b9d
* Tue Jul  2 2013 ygao@suse.com
- plugin: Handle messages in the common way in the plugin dispatch function by default
- Upstream version cs: 704f45e36594018358b0ea9d578291af1d52196e
* Sat Jun 29 2013 lmb@suse.com
- plugin: Fix small memory leak
* Wed Jun 26 2013 ygao@suse.com
- plugin: Change the function declaration in the plugin header
- crm_mon --neg-location drbd-fence-by-handler
- crm_mon -A: print_attr_msg needs to lookup paramters, not meta
- crm_mon -A: fix memleak, add g_free_list(attr_list)
- crmd: CID#1036761 Dereference null return value
- Corosync: CIB#1036763 Dereference before null check
- Tools: CID#1036764 Unused pointer value, CID#1036762 Resource leak
- Tools: CID#1036760 Truncated stdio return value
- PE: Delete the old resource state on every node whenever the resource type is changed (bnc#822233)
- Upstream version cs: 61e4b8f62b109ca5b910efd38c7e79ef403030fd
* Fri Jun 21 2013 ygao@suse.com
- crmd: Ensure operations for cleaned up resources don't block recovery (bnc#825536)
- logging: If SIGTRAP is sent before tracing is turned on, turn it on
- membership: Correctly merge partial entries in the peer cache
- attrd: Fixes deleted attributes during dc election
- crmd: Stop trying to fence when no devices exist capable of fencing a node
- PE: Allow active nodes in our current membership to be fenced without quorum
- PE: If fencing is unavailable or disabled, block further recovery for resources that fail to stop
- crm_resource: Avoid whitespace in transition keys when cleaning up and failing resources (bnc#851308)
- crmd: Everyone who gets a fencing notification should mark the node as down (bnc#842915)
- crmd: Initiate node shutdown if another node claims to have successfully fenced us (bnc#842915)
- crm_resource: Correctly implement --master
- crm_resource: Support OCF tracing when using --force-(check|start|stop)
- lrmd: Make lrmd and pacemaker_remoted in charge of setting up rsc state folder
- Allow uuid retrieval for nodes with no known name
- crmd: Update the status section with details of nodes for which we only know the nodeid
- crm_error: Add the ability to list and print error symbols
- crmd: Further improve clean shutdowns
- Core: Ensure the blackbox is saved on abnormal program termination
- crm_mon: Implement the ability to change the display options during operation.
- Upstream version cs: 6ea4b7ef34ce6e17f53f69d87a404d334db5d837
* Wed Jun 19 2013 ygao@suse.com
- xml: Purge diff markers even if there's no digest (bnc#824097)
* Wed Jun 19 2013 ygao@suse.com
- crmd: Prevent use-of-NULL during emergency shutdown
- crmd: Ensure all membership operations can complete while trying to cancel a transition
- Repair handling of attrd_update_delegate() return codes
- attrd: Correctly detect successful invocation of attrd_update()
- Convert all exit codes to positive errno values
- crm_attribute: Send details on duplicate values to stdout
- crm_attribute: Return the actual error code rather than the negative of it
- crm_resource: Implement the --master option for the --move,--ban,--clear commands
- crm_resource: Make --move without --host a true alias for --ban without --host
- crm_resource: Implement --ban for moving resources away from nodes and --clear (replaces --unmove)
- cib: Allow multiple children to be removed from the object root (eg. constraints)
- crmd: Prevent use-after-free now that mainloop terminates naturally
- mainloop: Saner ordering of reference counting events in mainloop_destroy_trigger()
- Correctly calculate crm_system_name
- Core: Tolerate NULL in mainloop_destroy_trigger()
- crmd: Allow mainloop to terminate naturally on graceful shutdown
- crmd: Use standard error codes on exit
- Ensure anything we free at shutdown is set to NULL too
- Ensure crm_system_name is cleaned up at exit for valgrind
- crmd: Ensure timers are stopped at exit
- Fencing: Ensure API object is consistently free'd
- Clean up internal mainloop structures at exit
- Core: Correctly unreference GSource inputs
- crmd: Clean up more memory before exit
- crmd: Do not get stuck in S_POLICY_ENGINE if a node we couldn't fence returns
- Upstream version cs: 47ed85ac6f4a9ac353945ae8bc4d7cea98b7cb7a
* Tue May 28 2013 ygao@suse.com
- PE: Mark unrunnable stop actions as "blocked" (bnc#816511)
- crm_resource: Do not crash when calling --force-start on an invalid resource
- ping: Ensure OCF_RESKEY_failure_score has a value (bnc#831327)
- PE: Unlink pengine output files before writing.
- Fencing: Restore the ability to manually confirm that fencing completed (bnc#843699)
- Fix: Resolve several memory leaks and improper dereferencing of pointers
- PE: cl#5155 - Block the stop of resources if any depending resource is unmanaged (bnc#816511)
- crmd: Insert async failures so that they appear in the correct order
- cl#5151 - Ensure node names are consistently compared without case
- crmd: Block after 10 failed fencing regardless of crmd-transition-delay
- PE: Re-initiate _active_ recurring monitors that previously failed but have timed out
- cl#5133 - PE: Correctly observe on-fail=block for failed demote operation
- PE: Suppress meaningless IDs when displaying anonymous clone status
- PE: Display a list of nodes on which stopped anonymous clones are not active instead of meaningless clone IDs
- PE: Correctly handle resources that recover before we operate on them
- Core: Detect child processes that terminate before our SIGCHLD handler is installed
- Upstream version cs: 674e69854a0ce4636ee54e123e45b1612c8f1fd5
* Thu May  9 2013 ygao@suse.com
- crmd: Do not record pending delete operations in the CIB
* Sat May  4 2013 ygao@suse.com
- cib: Strip text nodes on writing CIB to disk (bnc#815447, bnc#809635)
- xml: Use xmlNodeDump() from libxml2 when calculating digest (bnc#809635)
* Fri May  3 2013 ygao@suse.com
- PE: Ensure per-node resource parameters are used during probes
- cl#5154 - Do not expire failures when on-fail=block is present
- Upstream version cs: 2db99f16fe9b19a6320db62755f0f28ced8efe00
* Thu May  2 2013 ygao@suse.com
- cl#5153 - Correctly display clone failcounts in crm_mon
- crmd: Simplify the logic for resetting node status in the CIB after fencing events (bnc#812913)
- crmd: cl#5152 - Correctly clean up fenced nodes during membership changes (bnc#812913)
- ipc: Reference the correct type when inspecting IPC messages
- Core: Ensure the last field in transition keys is 36 characters
- crm_mon: Check if a process can be daemonized before forking so the parent can report an error
- crm_mon: Ensure stale pid files are updated when a new process is started
- extra: add failure_score parameter into ping RA
- crm_resource: Allow --cleanup without a resource name
- Upstream version cs: 3297085490c2fe0af25fc805d2b53123da877f7a
* Thu Apr 18 2013 ygao@suse.com
- fencing: Drop the severity of the messages on registering a stonith device (bnc#812269)
* Thu Apr 18 2013 ygao@suse.com
- crmd: Ensure we return to a stable state if there have been too many fencing failures
- fencing: Prevent empty call-id during notification processing
- crm_resource: Make --refresh and --reprobe an alias for --cleanup [--resource name]
- crmd: Indicate completion of refresh to callers
- crmd: Indicate completion of re-probe to callers
- crm_resource: Allow individual resources to be reprobed
- ipc: Allow unpriviliged clients to clean up after server failures
- crmd: Only performa dry run for deletions if built with ACL support
- Upstream version cs: a92f3a0e327da2af171856c979fb8eaa00122534
* Wed Apr 17 2013 ygao@suse.com
- crmd: Fixes hash table assert when resetting stonith failures
- crmd: Fixes memleak in failure cleanup
- crmd: Do not update fail-count and last-failure for old failures (bnc#804003)
- tools: cibadmin - Do not log for query commands by default (bnc#813045)
- services: Fix signal FD leak
- Upstream version cs: d63c13cbcde7663cfae9bb412583ad11914b6acc
* Thu Apr  4 2013 ygao@suse.com
- tools: crm_mon - Prevent segfault on reconnecting cib (bnc#813131)
* Mon Apr  1 2013 ygao@suse.com
- Fix: tools: crm_mon - Print a timing field only if its value is non-zero (bnc#809313)
* Mon Apr  1 2013 ygao@suse.com
- tools: crm_mon - Save relevant cib XML into /tmp/cmon.* files if refreshing fails (bnc#800323)
* Fri Mar 29 2013 ygao@suse.com
- fencing: Directly query the full cib on updating the cib cache (bnc#812269)
* Fri Mar 29 2013 ygao@suse.com
- cib: Use unique error codes for write_cib_contents()
- Fix: Ensure custom error codes are less than 256
- corosync: cl#5148 - Correctly remove a node that used to have a different nodeid (bnc#805278)
- Upstream version cs: e8caee88c9e078fccf98a9da05543b73d4696f04
* Thu Mar 28 2013 ygao@suse.com
- services: Improve the performance of synchronous actions (bnc#803969)
* Wed Mar 27 2013 ygao@suse.com
- lrmd: Change the default directory for nagios plugins (bnc#812005)
* Wed Mar 27 2013 ygao@suse.com
- xml: Prevent lockups by setting a more reliable buffer allocation strategy
- fencing: Fix memory leaks and invalid read
- fencing: Correctly unpack device parameters before using them
- lrmd: Avoid memory leak in resources_action_create()
- Skip WNOHANG when waiting after sending SIGKILL to child processes
- fencing: Fail the operation once all peers have been exhausted
- Fix several use-after-free and use-of-NULL
- fencing: Correctly filter devices when no nodes are configured yet
- ipc: Restore the ability for members of the haclient group to connect to the cluster
- Fencing: Re-use the policy engine libraries for filtering devices
- Upstream version cs: c7910371a5ada346fe7d1e1872ec9a40570018e6
* Mon Mar 25 2013 ygao@suse.com
- corosync: Support "crm_node --remove" with a node name for corosync plugin (bnc#805278)
- Fix memory leaks in stonithd, crmd and lrmd
- services: Close the reading pipes when a synchronous action is finished
- Doc: Pacemaker Explained: Add nagios resource class
- Upstream version cs: cb7b3f48dea9eb1b6825242da2ef507887b409cc
* Tue Mar 12 2013 ygao@suse.com
- Log: Change some messages to notice level (bnc#806256)
* Mon Mar 11 2013 ygao@suse.com
- xml: Support nagios resource class in the 1.2 schema
- xml: Support resource container in the 1.2 schema
* Fri Mar  8 2013 ygao@suse.com
- Update to version 1.1.9
- fencing: Only initiate topology based fencing if all topology queries have arrived
  AND we are still in the query phase
- fencing: Don't delay execution if all topology queries have arrived
- crmd: Bug cl#5144 - Do not updated the expected status of failed nodes (bnc#807824)
- Core: Support PCMK_logpriority to set syslog priority
- Upstream version cs: 2a917ddb9d1a01f47db84b17468413522d63ddfa
* Fri Mar  1 2013 coolo@suse.com
- update license to new format
* Sat Jul 28 2012 aj@suse.de
- Include sys/resource.h for getrlimit etc.
* Wed Jun  6 2012 ygao@suse.com
- Core: Revert to the original process flags for the support of
  rolling-upgrade
- PE: Bug cl#5059 - Use the correct action's status when calculating
  required actions for interleaved clones
- Upstream version cs: 61a079313275f3e9d0e85671f62c721d32ce3563
* Mon May 21 2012 badshah400@gmail.com
- Use BuildRequires: libgnutls-devel instead of gnutls-devel for
  Factory in keeping with gnutls package naming changes.
* Fri Apr 20 2012 ygao@suse.com
- corosync: Determine node state for plugin based cluster types
- tools: crm_node - Test stack membership only when displaying
  partition members
- Overhaul the way peers are determined to be sufficiently active
- PE: Observe the promotion score of probed resources
- crmd: Detect when peers have an incorrectly set process list
- corosync: Detect when the first corosync has not yet formed and
  handle it gracefully
- Corosync: Move deprecated corosync variants to their own file
- Upstream version cs: 4c8b599e6d79499f28f8178988d65fd33e0d9b24
* Thu Apr 19 2012 ygao@suse.com
- Update to version 1.1.7
- crmd: cl#5057 - Restart sub-systems correctly (bnc#755671)
- corosync: Fix compilation when libqb is not available
- pengine: cl#5058 - Fixes issue with on-fail option on operation
  being ignored.
- tools: rhbz#754216 - Make crm_mon --as-xml option default to
  - -one-shot mode
- cts: cl#5047 - Suppress cts badnews output related to fencing
  when fencing is expected.
- crmd: cl#5053 - Fixes fail-count not being updated properly.
- crmd: cl#5051 - Fixes file leak in pe ipc connection initialization.
- Tools: crm_simulate - Correctly detect status sections with
  duplicate node_state entries
- crmd: Detect when the quorum API isn't configured for corosync 2.0
- RA: controld - use the correct dlm_controld when membership comes
  from corosync directly
- Core: Fix the logging of XML and conditional corefile creation
  by asserts
- pengine: cl#5045 - Better handling of interrupted migrations.
- Build: rhbz#805147 - Use default value for HB_DAEMON_DIR define
  when clusterglue does not provide one.
- cib: Even with no peers, we still need to wait for connected
  clients to disconnect
- corosync: Fix complation warning when corosync doesn't use libqb
- cib: Determine when there are no peers to respond to our shutdown
  request and exit
- cib: Correctly shutdown in the presence of peers without relying
  on timers
- Corosync: Correctly disconnect from corosync variants
- cib: Ensure no additional messages are processed after we begin
  terminating
- Corosync: Reset connection variables after disconnect
- Core: Correctly track the length of a string without reading from
  uninitialzied memory (valgrind)
- PE: Fix memory leak in order_rsc_sets (valgrind)
- Tools: Fix memory leak in crm_simulate (valgrind)
- PE: Correctly locate crm_simulate for automated regression tests
- Core: Use the default schema location when PCMK_schema_directory
  is defined but empty
- PE: Correctly migrate a resource that has just migrated
- pengine: cl#5025 - Automatically clear failures when resource
  configuration changes.
- Fix a number of potential problems reported by coverity
- crmd: Also purge fencing results when we enter S_NOT_DC
- crmd: Correctly determine when a node can suicide with fencing
- PE: Bug rhbz#799070 - Report resources as active in crm_mon if
  they are located on an unclean node
- Upstream version cs: 023d3b183e77cfdb3699080b26d98ca4bc534c57
* Wed Apr 18 2012 ygao@suse.com
- PE: Support of referencing resource templates in resource sets (bnc#729634)
- stonith: A "start" operation of a stonith resource does a "monitor" on the
  device beyond registering it
- PE: More validations on configurations related to resource templates
- Core: Bug cl#5027 - Fix compilation when libqb is not available
- PE: cl#5002 - increment_clone() does not terminate on invalid input
- PE: Indicate the difference between resources that are restarting
  and reloading
- crmd: Leave it up to the PE to decide which ops can/cannot be reload
- PE: Detect reloads of previously migrated resources
- Core: Bug cl#5016 - Prevent failures in recurring ops from being lost
- crmd: Bug cl#5015 - Remove the failed operation as well as the
  resulting fail-count and last-failure attributes
- Fencing: Supress errors when listing all registered devices
- PE: Reload of a resource no longer causes a restart of dependant resources
- Fencing: Implement support for advanced fencing topologies:
  eg. kdump || (network && disk) || power
- Fencing: Add support for fencing levels to the admin tool
- Fencing: Prevent duplicate free and uninitialized pointers
- Fencing: Correctly remove the fencing levels when requested
- Fencing: Not all devices might be running locally when creating a
  fencing level
- cib: Don't halt disk writes if the previous digest is missing
- Cluster: Hook up the callbacks to the corosync quorum notifications
- Corosync: Correctly extract the node id from membership udpates
- Core: Ensure signals are handled eventually in the absense of timer
  sources or IPC messages
- Corosync: Default to using the nodeid as the node's uuid (instead of uname)
- corosync: Consistently set the correct uuid with get_node_uuid()
- Fencing: Standardize on /one/ method for clients to request members
  be fenced
- Core: Strip text nodes from on disk xml files (bnc#769910)
- Tools: Implement crm_node functionality for native corosync
- corosync: Hook up CPG membership
- fencing: More gracefully handle failed 'list' operations for devices
  that only support a single connection
- corosync: Unset the process list when nodes dissappear on us
- corosync: Correctly infer lost members from the quorum API
- crmd: Election - perform the age comparison only once
- crmd: Remove rusage differences of less than a second from election
  calculations
- PE: Ensure post-migration stop actions occur before node shutdown
- fencing: Correctly remove a single fencing level for a target
- fencing: Add the fencing topology section to the 1.1 configuration schema
- corosync: Ensure we catch nodes that leave the membership, even
  if the ringid doesn't change
- corosync: Treat CS_ERR_QUEUE_FULL the same as CS_ERR_TRY_AGAIN
- crmd: Fast-track shutdown if we couldn't request it via attrd
- tools: Bug rhbz#754216 - Add XML as an output option to crm_mon
- Core: Correctly determine when an XML file should be decompressed
- corosync: Remove deprecated member of the CFG API
- fencing: Provide enough data to construct an entry in the node's
  fencing history
- pengine: cl#5014, Prevent asymmetrical order constraints from causing
  resource stops
- pengine: cl#5007, Fixes use of colocation constraints with multi-state
  resources
- PE: Bug cl#5038 - Prevent restart of anonymous clones when clone-max
  decreases
- PE: Bug rhbz#789397 - Failcount and related info should be reset
  or removed when the resource is deleted
- fencing: fence_legacy - Drop spurilous host argument from status query (bnc#750512)
- pengine: Bug cl#5000 - Implements ability to create rsc_order
  constraint sets such that A can start after (B || C) has started.
- Fencing: fence_legacy - Ensure port is available as an environment
  variable when calling monitor (bnc#750512)
- PE: Bug cl#5028 - Unmanaged services should block shutdown unless
  in maintainence mode (bnc#738882)
- Fix coverity defects in pengine, cib, stonith-ng and crm_resource
- Fix use-after-free in crmd, stonith-ng and crm_simulate
- Fix use-of-NULL in libcrmcluster and stonith-ng
- Fix segfaults in stonith-ng and xml.c
- Upstream version cs: 1e8a96ae55d6022f7036434b537938a1fa75a700
* Thu Mar 29 2012 lmb@novell.com
- Add provides to identify support level for tickets (bnc#752241)
* Mon Mar 26 2012 ygao@suse.com
- Resolve coverity RESOURCE_LEAK, REVERSE_INULL and UNREACHABLE defects
* Sun Mar 25 2012 ygao@suse.com
- Tools: crm_simulate - Support to grant/revoke/standby/activate
  tickets from the new ticket state section (bnc#752241)
* Sun Mar 25 2012 ygao@suse.com
- Tools: Add crm_ticket to be profiled by valgrind
- Tools: crm_ticket - Display the tickets that are referenced in
  rsc_ticket constraints but have never been granted yet (bnc#752241)
- Tools: crm_mon - Support to display tickets (bnc#752242)
* Sat Mar 24 2012 ygao@suse.com
- PE: Move the ticket state section to
  "/cib/status/tickets/ticket_state" (bnc#752241)
- PE: Support to make tickets standby for relinquishing tickets
  gracefully (bnc#752241)
- Tools: Implement a new crm_ticket (bnc#752241)
- Tools: Update CLI regression tests for the new crm_ticket
- Tools: Add CLI regression tests for ticket standby state
- PE: Update regression tests for the new ticket state section
- PE: Support to make tickets standby for relinquishing tickets
  gracefully (regression tests)
* Tue Mar 20 2012 ygao@suse.com
- Tools: crm_ticket - Granting/revoking tickets need user to confirm
  unless "--force" option is used (bnc#752269)
* Tue Mar 13 2012 ygao@suse.com
- Tools: Implement the support of granting/revoking tickets for
  crm_simulate (bnc#752241)
* Tue Jan 17 2012 ygao@suse.com
- Core: Move several new fields since v1.1.6 to the end of the data
  types for ABI compliance
- stonith: Default to 20s timeout for start and monitor operations of
  stonith resources which is same as "default-action-timeout" (bnc#733337)
- Tools: ptest - Fix "-X, --xml-text" option to handle a XML string as its
  argument (bnc#736212)
- cib: Fix segfault caused by destroying an already freed hash table (cl#5023)
- stonith: Expose IDs of stonith resources to stonith agents through
  "$CRM_meta_st_device_id" environment variable (bnc#728579)
* Mon Jan  9 2012 tserong@suse.com
- Only include glib.h in plugin.h (don't directly use glib/ghash.h)
* Fri Dec 16 2011 tserong@suse.com
- RA: add NodeUtilization
- stonith-ng: export stonith resource name to stonith agents
- crmd: Send out all of the meta parameters to lrmd for stop actions
  (bnc#715501)
- RA: Fix the metadata of HealthSMART and SysInfo RAs
- stonith: Longer default timeout/interval of operations for stonith
  resources
- Doc: many proof-reading improvements
- stonith: Fix the stonith timeout issue (cl#5009, bnc#727498)
- update the license information in pacemaker.spec (bnc#726795)
- xml: Add rsc_ticket support into "pacemaker-1.2" schema
- xml: Add resource template support into "pacemaker-1.2" schema
- tools: Avoid problems caused by differences between node name and
  uname -n
- PE: Resolve memory leak when retrieving failure counts
- Stonith: Implement a manual override for when nodes are known to be
  safely off
- PE: Implement limit number of concurrent live migrations (FATE#310118)
- PE: Implement referencing templates in constraints
- PE: Move master based on failure of colocated group
- Fencing: Support admin configurable timeouts for API operations
- Fencing: Support checking in-progress operations for all nodes
- don't package crm shell code
- add Requires: crmsh
- Build man pages and html versions (bnc#723680)
- Shell: template support
- Upstream version cs: b988976485d15cb702c9307df55512d323831a5e
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Tue Sep 20 2011 tserong@suse.com
- Upgrade to 1.1.6.
- PE: Demote from Master does not clear previous errors
- crmd: Prevent secondary DC fencing resulting from CIB updates
  that are lost due to elections
- crmd: Log duplicate DC detection as a WARNING not ERROR
- crmd: Bug lf#2632 - Correctly handle nodes that return faster
  than stonith (bnc#710314)
- Core: Treat GNUTLS_E_UNEXPECTED_PACKET_LENGTH as normal
  termination of a TLS session
- cib: Call gnutls_bye() and shutdown() when disconnecting from
  remote TLS connections
- cib: Remove disconnected remote connections from mainloop
- cib: Attempt a graceful sign-off for remote TLS connections
- Core: Ensure there is sufficient space for EOS when building
  short-form option strings (prevents segfault)
- Core: Fix variable expansion in pkg-config files
- PE: Resolve memory leak reported by valgrind
- PE: Fix memory leak for re-allocated resources reported by
  valgrind
- PE: Improve the merging with template's operations
- crmd: Allow nodes to fence themselves if they're the last one
  standing (lf#2584)
- stonith: Add an API call for listing installed agents
- stonith: Allow the fencing history to be queried
- stonith: Ensure completed operations are recorded as such in
  the history
- stonith: Support --quiet to display just the seconds since
  epoch at which a node was last shot
- stonith: Serialize actions for a given device
- stonith: Add missing entries to stonith_error2string() (missing
  error messages)
- Shell: geo-cluster support commands
- Shell: support for rsc_ticket
- Shell: let the pager decide how to handle output smaller than
  terminal
- Shell: look for log segments with more care and don't throw
  exception on seek (bnc#713939)
- Shell: several history improvements
- tools: crm_attribute - Update tickets directly to cib instead
  of through attrd
- Shell: support for LRM secrets in resource level
- Shell: enable removal of unmanaged resources (bnc#696506)
- Shell: add crm execute directory to the PATH if not already present (bnc#712605)
- Shell: update log patterns for history
- Shell: relax transition acceptance in history
- tools: crm_simulate - Send logging to stdout when additional detail is
  requested so that grep works as intended
- PE: Prevent services being active if dependancies on clones are not
  satisfied (bnc#707150)
- PE: Prevent resource shuffling when the 'utilization' placement
  strategy is used
- PE: Implement resource template
- fencing: Add support for --reboot to stonith_admin
- Fencing: Downgrade an error message for a valid scenario
- crmd: Ensure we do not attempt to perform action on failed nodes
  (bnc#703236, lf#2612)
- Fencing: admin - Disable stderr logging by default
- Fencing: Fix use-of-NULL by g_hash_table_lookup
- Tools: Correctly log corosync node IDs (lf#2621)
- pacemaker:ping: Incorporate fping functionality from Dan Urist
- crmd: Recurring actions shouldn't cause the last non-recurring action
  to be forgotten
- crmd: Do not wait for actions that were pending on dead nodes
- crmd: Cancel timers for actions that were pending on dead nodes
- PE: Correctly recognise which recurring operations are currently
  active
- PE: Ensure role is preserved for unmanaged resources
- PE: Ensure unmanaged resources have the correct role set so the
  correct monitor operation is chosen
- PE: Implement cluster ticket and deadman
- Build: Add crm_ticket into spec file
- Tools: crm_attribute - No need to determine the node for tickets
  management
- Tools: crm_mon crm_resource - Display the "operation_key" instead of
  the operation "id" if available (bnc#707201)
- CTS improvements.
- Shell: reimplement the history latest command (bnc#710958)
- Shell: Don't limit to last hour when examining hb_reports
- Shell: improve capture log slices for transitions (bnc#710907)
- Shell: allow specifying PE files as relative paths in order to
  disambiguate between PE inputs with the same number (bnc#710655)
- Shell: remove peinputs "get" and "list" subcommands, just use 'v' for the
  long listing (bnc#711060)
- Shell: remove transition "show" subcommand, if there is no subcommand
  it is assumed that the user wants to do "show" (bnc#711060)
- Shell: detect (and ignore) empty transitions
- Shell: review transition interface (bnc#710655)
- Fencing: Improved pcmk_host_map parsing
- Fencing: Consolidate pcmk_host_map into run_stonith_agent so that it
  is applied consistently
- Shell: Update regression tests for new stonith metadata
- pengine: Correctly determine the state of multi-state resources with a
  partial operation history
- Core: Cancelled and pending operations do not count as failed
- PE: Ensure restarts due to definition changes cause the start action
  to be re-issued not probes
- Fencing: Prevent use-of-NULL by g_hash_table_lookup
- Shell: Install support for pssh
- PE: Support of monitor op with role="Stopped"
- Shell: improve logic for when to use the pager
- Shell: don't print error on Broken pipe
- cib: Record and display the originator details of CIB changes for
  schema "pacemaker-1.2"
- crmd: Display the name and vlaue of the transient attribute(s) that
  caused a new transition
- stonith: Correctly handle synchronous calls
- PE: A demote operation is implied by the stonith operation (lf#2606)
- PE: Group migration after failures and non-default utilization
  policies (lf#2613, lf#2619)
- Shell: Include log file querying tools and "history" extension.
- Significant number of fixes for issues reported by Coverity.
- ais: Handle IPC error before checking for NULL data (bnc#702907)
- PE: save PE inputs again (bnc#703723)
- PE: Before migrating an utilization-using resource to a node, take off
  the load which will no longer run there (lf#2599, bnc#695440)
- cib: Record and display the originator details of CIB changes
- cib: Update "cib-last-written" for live CIB on a config change
- cib: Filter out unnecessary "update-*" fields on digest calculating
- doc: man page for crm
- cib: Check the validation version before adding the originator details
  of a CIB change
- PE: Don't log resource states unless debug is on
- Shell: implement -w,--wait option to wait for the transition to finish
- crmd: Store only the last and last failed operation in the CIB
- Core: Use pre-glib2-2.28 version of g_str_hash to ensure consistent
  score calculation for clone instances
- Shell: repair template list command
- PE: Optimize the placement strategy and handle stickiness for
  utilization-based placement correctly (bnc#669686)
- Shell: print error instead of warning and exit with 1 if a resource
  cannot be deleted (bnc#680401)
- Tools: attrd - Do not initiate updates for deleted attributes
- Tools: Make progress when attrd_updater is called repeatedly within
  the dampen interval but with the same value (lf#2528)
- tools: Do not pass bash specific switches to other SHELLs (lf#2556)
- crmd: Watch for config option changes from the CIB even if we're not
  the DC (lf#2509)
- PE: Prevent shuffling by choosing the correct clone instance to stop
  (lf#2574)
- PE: Avoid group restart when clone (re)starts on an unrelated node
  (lf#2581, bnc#681595)
- PE: Set reasonable default limits for the number of input files saved
- tools: Do not recursively look for resource meta attributes (lf#2563)
- PE: Do not write out duplicated input files (lf#2582)
- cib: Use SIGPIPE for re-enabling disk writes after an error (lf#2229)
- crmd: Fail actions that were scheduled for a failed/fenced node
  (lf#2559)
- Fencing: Clean up the metadata creation
- Stonith: Allow the fencing agent operations to be overridden on a
  per-device basis (lf#2557)
- Tools: crm_resource - Indicate master/slave state when querying the
  parent resource (lf#2477)
- Tools: crm_mon - Display the true number of configured resources
  (lf#2549)
- RA: Fix handling of 'devices' in the HealthSMART agent
- Shell: print warning if start or stop interval is not zero
- Shell: Check for violations of uniqueness for instance parameters
  during commit
- PE: Indicate resource failures even if on-fail="ignore"
- ais: Ensure we drain the corosync queue of messages when glib tells us
  there is input
- crmd: Catch fence operations that claim to succeed but did not really
- Core: Use pre-glib2-2.28 version of g_str_hash to ensure consistent
  score calculation for clone instances
- Shell: repair template list command
- Shell: node clearstate must flush LRM state too (bnc#653795)
- Upstream version cs: 9971ebba4494 (release 1.1.6)
* Fri Aug  5 2011 tserong@novell.com
- Fix rpmlint non-ghost-in-var-run check (bnc#710272)
* Wed Feb  9 2011 tserong@novell.com
- PE: Consolidate logging for resources active on multiple nodes
- PE: More accurate logging of restarts and recovery for master/slave
  resources
- PE: target-role alone is not sufficient to promote resources (lf#2544)
- ais: Ensure that process death is communicated to peer nodes (lf#2550)
- PE: Certain stop operations require STONITH, could overload the
  batch-limit otherwise (lf#2551, bnc#669229)
- PE: Suppress unnecssary assertion failure message (lf#2558,
  bnc#670983)
- Shell: Do not print XML for permission denied errors
- ACL: Support access control on "cleanup"
- crmd: Cancel recurring operations while we're still connected to the
  lrmd
- crmd: Suppress an ERROR by teaching fsa_action2string() about complex
  actions
- crmd: ACL: Prohibit non-privileged users to "fail" resources
- Core: Do not store last-run for recurring operations, since it is
  misleading
- Shell: fix logic for not printing the default monitor depth
- Doc: Add ACL documentation
- Upstream version cs: ecb6baaf7fc0
* Tue Feb  8 2011 tserong@novell.com
- Upgrade from 1.1.2.1 to 1.1.5.  Note that the following changelog
  entries cover changes made in versions 1.1.3 and 1.1.4 as well.
- crmd: Cancel recurring operations while we're still connected to the
  lrmd
- crmd: Suppress an ERROR by teaching fsa_action2string() about complex
  actions
- PE: Consolidate logging for resources active on multiple nodes
- PE: More accurate logging of restarts and recovery for master/slave
  resources
- PE: target-role alone is not sufficient to promote resources (lf#2544)
- ais: Ensure that process death is communicated to peer nodes (lf#2550)
- PE: Certain stop operations require STONITH, could overload the
  batch-limit otherwise (lf#2551, bnc#669229)
- Shell: Do not print XML for permission denied errors
- Doc: Add ACL documentation
- Core: Do not store last-run for recurring operations, since it is
  misleading
- crmd: Purge status for resourcs that no longer live in the LRMd
  (lf#2536)
- Stonith: Teach stonith_admin to automagically obtain the current node
  attributes for the target from the CIB
- tools: Prevent use-of-NULL in crm_simulate (lf#2527)
- ACL: Convert uid directly with strtol() for avoiding unnecessary error
  logs
- Tools: Make unmanaged resources stand out in crm_simulate graphs
- PE: Correctly reconstruct the status of anonymous cloned groups
  (lf#2508)
- Core: Correctly parse the resource name from notificiation action IDs
  (lf#2511)
- crmd: Indicate the interval for the timer that just expired
- crmd: Reschedule the PE_START action if its not already running when
  we try to use it
- crmd: Ensure notify variables are accurate for stop operations
  (lf#2545)
- crmd: Implement reprobe natively in the crmd to avoid transition loops
  (lf#2533)
- crmd: Cancel recurring monitor ops at shutdown (lf#2309)
- PE: Don't imply colocation requirements when applying ordering
  constraints with clones (lf#2493)
- PE: Protect against constraints that require stonith devices to stop
  before 'normal' ones (lf#2529)
- PE: Prevent unstable clone placement by factoring in the current
  node's score before all others (lf#2544)
- Tools: Suport cibadmin --empty for creating a minimal CIB
- PE: Do not override configured clone stickiness values (lf#2445)
- PE: Avoid relying on stickness for stable clone placement (lf#2445)
- Shell: work around lrmd/lrmadmin blocking when not run as root or
  hacluster
- Shell: more lazy help system initialization
- Access control list support for pacemaker's shell and CIB.
- PE: Prevent segfault by validating the contents of ordering sets
  (lf#2495)
- PE: Prevent use-after-free resulting from unintended recursion when
  chosing a node to promote master/slave resources
- PE: Avoid flooding the logs with errors for orphan resources
  (lf#2518)
- cib: Add "enable-acl" property
- Shell: don't create empty optional sections (bnc#665131)
- xml: Add ACL support into pacemaker-1.2 and 1.1 schemata.
- RA: HealthSMART: Several fixes.
- RA: SysInfo: Allow a list of filesystems/devices to be queried for
  free space
- RA: ClusterMon: htmlfile is not mandatory (lf#2512)
- Shell: merge properties and rsc/op_defaults on load update (lf#2454)
- stonith: use ST_DEVICEID for short description
- Shell: combine crmd and PE meta-data (lf#2373,2419)
- PE: Only update the node's promotion score if the resource is active
  there
- PE: Only use the promotion score from the current clone instance
- Shell: ask for confirmation for node fence and clearstate (bnc#642268)
- Shell: insert sleep between stop and start in resource restart
- stonith: remove unnecessary logging
- Shell: fix exception when HOME is not set
- Shell: Allow creation of an empty shadow CIB ("cib new ... empty")
- Shell: Allow cibstatus to create new node status entries.
- Shell: fix rsc/op_defaults edit
- Shell: repair management of cloned groups
- Shell: wait for the stop transition to finish before invoking start in
  the resource restart command (lf#2516)
- PE: Correct target_rc for probes of inactive resources
- Tools: Prevent crm_resource commands from being lost due to the use of
  cib_scope_local
- PE: Prevent use-of-NULL resulting from variable shadowing spotted by
  Coverity
- Shell: allow adding node attributes in configure when the attributes
  set doesn't already exist
- Core: Repair reference to child-of-child after removal of
  xml_child_iter_filter from get_message_xml()
- Core: Remove extra calls to xmlCleanupParser resulting in use-after-free
- Core: Reinstate the logic that skips past non-XML_ELEMENT_NODE children
- Core: Update the default validation type to pacemaker-1.0
- Core: Prevent recently introduced use-after-free in replace_xml_child()
- crmd: Update failcount for failed promote and demote operations
- PE: Prevent use-of-NULL when there is status for an undefined node
- Shell: warn on non-existing nodes in location constraints (lf#2486)
- Shell: put completion bits into a separate module
- Shell: repair ability to display multiple property sets
- Build: Script for determining test coverage
- Remove usage of the xml_child_iter macro to obtain better information
  from tracing tools.
- Shell: Let crm_resource handle node & resource iteration during
  resource cleanup (skips down nodes: bnc#647378)
- PE: Avoid needless string compares
- cib: Fix a log message
- Core: Provide arguments to do_crm_log_alias() in the correct order
  when logging xml
- Add gcov support to spec file (disabled by default)
- crmd: Determin the target rc for an action once
- crmd: Prevent use of NULL by making copies of the operation's hash
  table
- Core: Turn off unneeded checks when applying a diff
- crmd: Allow operations in the PE state
- crmd: Ensure the CIB is always writable on the DC by removing a timing
  hole
- cib: Deprecate the set_slave_all() API call
- PE: Ensure fencing of the DC preceeds the STONITH_DONE operation
- PE: Complete all fencing before attempting atomic migrations
- stonith-ng: fix two memory leaks.
- Core: Preserve ordering when removing subtrees with a diff
- Tools: Calculate the digest after applying a diff
- Core: Correctly extract the version details from a diff
- cib: Drop the severity of a log message
- crmd: Don't abort transitions when probes are completed on a node
- PE: Try to ensure atomic migration ops occur within a single
  transition
- Core: Correctly compare against crm_log_level in the logging macros
- cib: Revert part of a recent commit that purged still valid
  connections
- PE: reduce logging severity for single rsc sets
- Core: Prevent use-after-free when creating a CIB update for a timed
  out action
- Shell: update shadow file directory processing
- Tools: crm_resource - Improved output when listing constraints
  relevant to a given resource
- Tools: crm_resource - Fix -x, the short form of --xml-file
- Tools: crm_resource - Include location constraints in -A|-a output
- Tools: crm_shadow - Avoid replacing the entire configuration
  (including status)
- PE: Prevent clones from being stopped because resources colocated with
  them cannot be active
- crmd: Include the correct transition details for timed out operations
- Core: Drop the compression limit (lf#2506)
- cib: Don't remove client's when notifications fail, they might just be
  too big (lf#2506)
- cib: Do not calculate changes for status updates that wont be
  broadcast
- cib: Speed up the establishment of remote connections
- crmd: All pending operations should be recorded, even recurring ones
  with high start delays
- stonith-ng: reduce logging.
- Core: Provide significant performance improvements by implementing
  versioned diffs and digests
- cib: Reject updates with a feature set greater than our own
- Core: Some performance enhancements when comparing xml objects
- crmd: Use the supplied timeout for stop actions
- Core: Ensure ordering is preserved when applying diffs
- crmd: There's no need to check the cib version from the 'added' part
  of diff updates
- crmd: Additional logging for the cause of new transitions
- cib: Drop invalid/failed connections from the client hashtable
- PE: Use the original digest algorithm for parameter lists
- cib: Ensure all diffs sent to peers have sufficient ordering
  information
- cib: Reduce unnecessary copying when comparing xml objects
- Core: Purge diff markers before calculating and comparing digests
- Core: Minor speedup when comparing xml objects
- cib: The feature set version check is only valid if the current value
  is non-NULL
- Tools: crm_resource - Ensure xml-related memory is cleaned up at exit
- Tools: crm_simulate - Ensure xml-related memory is cleaned up at exit
- PE: lf#2478 - Implement improved handling and recovery of atomic
  resource migrations
- PE: Fix memory leak when processing completed migration actions
- Large number of performance improvements to the Policy Engine and
  CIB.
- Core: Cache Relax-NG schemas - profiling indicates many cycles are
  wasted needlessly re-parsing them
- Core: Don't compress large payload elements unless we're approaching
  message limits
- Tools: crm_node - Fix the return code for operations on corosync
  clusters
- Stonith: Fix two memory leaks
- crmd: Record completed migrate ops in CIB status section as
  migrate_to/migrate_from, not as stop/start (lf#2481)
- PE: Fix typo leading to use-of-NULL in the new ordering code
  (bnc#653635)
- crmd: on version print everything to stdout
- stonith: cleanup children on timeout in fence_legacy
- Shell: use uname instead of id in nodes when building other ids
- Shell: add "clearstate" command for nodes
- crmd: Don't hide stop events that time out - allowing faster recovery
  in the presence of overloaded hosts
- PE: Use hashtables instead of linked lists for performance sensitive
  datastructures
- PE: Skip probe_resources() completely if probing is disabled
- PE: Obtain massive speedup by prepending to the list of ordering
  constraints (which can grow quite large)
- PE: Detect start/stop actions with intervals
- PE: Optimize the logic for deciding which non-grouped anonymous clone
  instances to probe for
- stonith: Use the timeout specified by the user
- stonith: Add the timeout at the top level where the
  daemon is looking for it (lf#2473)
- stonith: Ensure timeouts are included for fencing
  operations (lf#2473)
- Logging tuning
- crmd: Use an operation's interval when an invalid timeout was
  specified
- crmd: Use the correct define/size for lrm resource IDs
- Tools: Ensure the line we're grabbling the time from contains a time
- Tools: crm_simulate - Fix use-after-free in when terminating
- Stonith: Ensure stonith operations complete within the timeout and are
  terminated if they run too long (lf#2473)
- crmd: Prevent assertion failure for stop actions
- PE: Prevent segfault by ensuring the arguments to do_calculations()
  are initialized
- PE: Correct use-after-free
- Tools: crm_simulate - Resolve memory leak reported by valgrind
- PE: Ignore failed actions on nodes that have been shutdown
- crmd: Better logging of failed stonith operations (lf#2473)
- stonith: Gracefully handle remote operations that arrive late (after
  we've done notifications) (lf#2473)
- Tools: crm_simulate - Resolve memory leak reported by valgrind
- PE: Repair on-fail=block for groups and primitive
  resources (lf$2476)
- crmd: Ensure stop actions always have the relevant resource attributes
  (lf#2458)
- Tools: Fix assertion failure in crm_resource (lf#2456)
- PE: Do not demote resources because something that requires it can't
  run
- PE: Display managed/unmanaged state for resources when grouped by node
  in crm_mon (lf#2479)
- cib: Clean up disconnected remote connections (lf#2469)
- Tools: crm_mon - Only display attributes of online nodes (and sort
  them)
- RA: ping - Indicate that host_list is a required parameter in the
  metadata
- stonith: Prevent segfault by not looking up operations if the
  hashtable hasn't been initialized yet (lf#2461)
- Tools: Have crm_resource --locate indicate which instances are
  promoted (lf#2477)
- PE: Ensure resource op timeout takes precedence over op_defaults
  (lf#2474)
- Upstream version cs: bdd89e69ba54
* Wed Nov 17 2010 meissner@suse.de
- SUSE_ASNEEDED also during %%install, if by chance we rebuild
  things in there.
* Mon Aug 16 2010 lmb@novell.com
- cib: Allow backup files to proceed after wrap-around (bnc#630322)
- Upstream version cs: dfc6b2561373
* Mon Aug  9 2010 lmb@novell.com
- stonith-ng: record exit code and log output for failed port list query
  (bnc#625594)
- Upstream version cs: 0db65fda4b15
* Fri Aug  6 2010 lmb@novell.com
- Shell: print error if a resource is not found in stop/start/manage
  (bnc#627757)
- PE: Fix memory leak when unpacking recurring operations
- PE: Fix potential use-of-NULL when calculating the set of required
  actions
- Shell: set shadow directory properly (bnc#626638)
- Core: Enable coredumps properly for MCP and AIS plugin (lf#2463)
- Upstream version cs: 61360150595d
* Thu Aug  5 2010 tserong@novell.com
- Explicitly require libglue2 to avoid potential conflict with
  libheartbeat2 (bnc#628243)
* Wed Jul 28 2010 lmb@novell.com
- crmd: Prevent everyone from losing DC elections by correctly
  initializing all relevant variables
- crmd: Ensure we activate the DC timer if we detect an alternate DC
- PE: Wait until stonith is available, don't fall back to shutdown for
  nodes requesting termination
- Upstream version cs: e0d731c2b1be
* Wed Jul 21 2010 lmb@novell.com
- PE: Correctly order clone startup after group/clone start
- stonith-ng: pass the configuration to the stonith program via
  environment variables; requires cluster-glue >= 1.0.6 (bnc#620781,
  CVE-2010-2496)
- Logging improvements.
- Upstream version cs: f9fbf97b0ce8
* Wed Jul 14 2010 lmb@novell.com
- Shell: allow adding force parameter to resource migrate
- Shell: add the actions option to configure ptest (lf#2360)
- Shell: test early for duplicate elements in edit (bnc#620460)
- Shell: Use crm_attribute directly instead of the deprecated
  crm_standby and crm_failcount wrappers
- PE: Correctly detect when there is a real failcount that expired and
  needs to be cleared
- PE: Avoid creating invalid ordering constraints for probes that aren't
  needed
- PE: Include the prefix for clone children when printing the clone
- PE: Bug lf#2453 - Enforce clone ordering in the absense of colocation
  constraints (lf#2453, bnc#619581)
- crmd: Only log the failcount op if something is wrong
- crmd: Base DC election on process relative uptime
- crmd: Make sure we always poke the FSA after a transition to clear any
  TE_HALT actions
- crmd:  Make sure the membership cache is accurate after a sucessful
  fencing operation
- crmd: All nodes should see status updates, not just the DC
- stonith-ng: Advertise stonith-ng options in the metadata
- Core: Correctly unpack HA_Messages containing multiple entries with
  the same name
- ais: Sign everyone up for peer process updates, not just the crmd
- ais: Move the code for finding uid before the fork so that the child
  does no logging
- Upstream version cs: e9b2f255a20e
* Tue Jul  6 2010 lmb@novell.com
- PE: Fail unmanaged resources should not prevent other services from shutting down (lf#1959)
- crmd: Handle asynchronous notification of resource deletion events (lf#2439)
- Shell: add support for classes to the providers command
- crmd: Pass in the correct result when processing synchronous resource deletion operations
- ais: Fix unterminated recursion in init_ais_connection()
- Tools: Make sure crm_resource waits for the completion of crmd operations it sent
- stonith: Support the poweron/poweroff actions (bnc#618798)
- stonith: Map poweron/poweroff back to on/off expected by the stonith
  tool from cluster-glue (bnc#618798)
- PE: Correctly handle pseudo action creation
- Tools: crm_node - Enable the -A parameter, the short form of --openais
- CLI: report bad ISO8601 duration specifiers (bnc#618808)
- crmd: Fix assertion failure when performing async resource failures
- crmd: Include the action for crm graph operations
- crmd: Allow non-DC nodes to clear failcounts too and tidy up logging
- Fix some valgrind reported leaks.
- Upstream version cs: ea6cdd9d9613
* Mon Jun 14 2010 lmb@novell.com
- Shell: templates: clvm,ocfs2: add the fs/vg resource to the base
  group, add timeouts (bnc#605580)
- Shell: skip resource checks for property-like elements (lf#2420)
- Shell: on no id match the first of property-like elements (lf#2420)
- Shell: set proper ids for rsc/op_defaults (lf#2420)
- Shell: add exit codes for non-interactive use
- PE: No services should be stopped until probes finish (lf#2433)
- PE: Support clones in resource sets (bnc#586613, lf#2404, lf#2409)
- Tools: Allow ptest and crm_simulate to work with configs that lack a
  status section
- Core: Reduce logging for failed xpath searches
- PE: Support colocation sets with negative scores (lf#2435)
- PE: Ensure deallocated resources are stopped
- PE: Ordering dependencies on partially active groups not observed
  properly (lf#2422, bnc#607125)
- PE: If there are no compatible peers when interleaving clones, ensure
  the instance is stopped
- PE: Fix colocation for interleaved clones
- PE: Fix colocation with partially active groups
- PE: Don't overwrite existing meta attributes (like timeout) for notify
  operations (lf#2424)
- PE: stop-all-resources shouldn't apply to stonith resources (lf#2426)
- Fencing: Reduce stonith-ng logging (lf#2431)
- ais: Improved processing when the peer crmd processes join/leave
  (lf#2401)
- Tools: crm_resource - Report crmd connection errors
- Tools: Depreciate the 'pingd' daemon and resource agent in favor of
  ocf:pacemaker:ping
- cib: Fix the application of unversioned diffs
- Several valgrind + coverity issues fixed.
- Upstream version cs: 8b9ec9ccc506
* Tue Jun  8 2010 tserong@novell.com
- Install crm shell and cts in $(pyexecdir) instead of $(pythondir)
  to ensure installation in /usr/lib64 on x86_64
* Tue May 18 2010 tserong@novell.com
- Fix crm membership check (bnc#603685, reverts changesets
  6e6980376f01 and 2e096a41a5f9)
- Upstream version cs: e8717a29601a (1.1.2.1)
* Fri May 14 2010 lmb@novell.com
- ais: fix list of active processes sent to clients (bnc#603685)
- Upstream version cs: 2e096a41a5f9
* Wed May 12 2010 lmb@novell.com
- crmd: Prevent use-after-free of the stonith-ng connection (lf#2414)
- Core: Prevent use-after-free reported by valgrind when
  doing xpath based deletions (lf#2414)
- PE: Fix memory leaks reported by valgrind
- Core: Fix memory leak in replace_xml_child() reported by valgrind
- PE: Remove developemnt logging which mistakenly logged at "ERROR"
  level.
- Upstream version cs: b59c27dc114a (1.1.2)
* Mon May 10 2010 lmb@novell.com
- crmd: Prevent use-after-free of the PE connection after it dies
  (lf#2414)
- Shell: support for clone instances in constraints (lf#2169)
- Upstream version cs: 42a5aa3413f4
* Mon May 10 2010 lmb@novell.com
- Shell: new command default-timeouts to set default operation timeouts
  (bnc#479052)
- crmd: ais: Use the threadsafe version of getpwnam
- PE: Enforce mandatory promotion (colocation) constraints (lf#2403)
- PE: Don't complain about missing agents during probes of a-symetric
  clusters (lf#2410)
- Shell: don't error on missing resource agent with asymmetrical
  clusters (lf#2410)
- ais: Ensure the list of active processes sent to clients is always
  up-to-date
- PE: Allow constraints to apply to specific instances of clones
  (lf#2169)
- PE: Allow ordering constraints to apply to specific instances of
  clones
- PE: Clean up failcount after it expires (lf#2066)
- PE: Before starting utilization-using resources on a node, take off
  the load which will no longer run there (bnc#594782)
- PE: Don't be so quick to pull the trigger on nodes that are coming up
- crmd: Use global fencing notifications to prevent secondary fencing
  operations of the DC
- cib: Changes to group order are not detected or broadcast to peers
  (lf#2352)
- Core: Only use the named schema if the validation passes
- Shell: don't verify empty configurations (bnc#602711)
- crmd: Send erase_status_tag() calls to the local CIB when the DC is
  fenced, since there is no DC to accept them
- crmd: Include operation interval in logged action
- crmd: Arrange for only one node to clean up after a fenced DC node
- crmd: create the final directory too for resource agents (bnc#603190)
- Tools: crm_mon: refresh screen on terminal resize (bnc#589811)
- PE: Correctly locate clone instances by their prefix (lf#2412)
- ais: Make a better attempt at determining an accurate born-on value
  from corosync
- tools: crm_mon - Enable 'connectivity' mode for 'ping' resources too
- Upstream version cs: e8624c181a3f
* Tue Apr 27 2010 lmb@novell.com
- Fix small error so that regression test suite passes.
* Tue Apr 27 2010 ygao@novell.com
- PE: Before starting utilization-using resources on a node, take off
  the load which will no longer run there (bnc#594782)
* Mon Apr 26 2010 lmb@novell.com
- PE: Don't create scaffolding for ordering sets with a single resources
  (bnc#586613)
- PE: Ignore colocation weights from clone instances
- PE: Print allocation scores as +/-INFINITY when appropriate
- Upstream version cs: fa1c810f1d1d
* Fri Apr 23 2010 lmb@novell.com
- Fix regression test for build environment.
- Upstream version cs: c11e18619efd
* Wed Apr 21 2010 lmb@novell.com
- Fix several memory leaks exposed by valgrind.
- Improve regression tests.
- Low: Fencing: Delay system initialization until after we handle
  possible metadata queries
- Tools: Do not print help on executing "crm_node -i"
- crm_simulate: Allow bringing new node online (bnc#591162)
- crmd: Improved detection of partially active peers (lf#2401)
- PE: Fix intra-set colocation and ordering (lf#2384)
- PE: Combine failcounts for all instances of an anonymous clone on a
  host (lf#2383)
- crmd: Add missing fields to the metadata for use by the shell
  (lf#2387)
- PE: Check for use-of-NULL in dump_node_scores()
- PE: Rewrite native_merge_weights() to avoid Fix use-after-free
- Upstream version cs: 2a90abe96048
* Mon Apr 12 2010 lmb@novell.com
- Automated test case improvements.
- Upstream version cs: 536bf0b9d3ba
* Fri Apr  9 2010 lmb@novell.com
- Shell: always reload status if working with the cluster (bnc#590035)
- Shell: add new regression tests
- Shell: don't allow empty attributes for properties/*_defaults
  (lf#2395)
- Shell: add another attribute not present in the crmd metadata
- Tools: crm_mon - Enable specification of community for SNMP traps
- PE: Ensure important options (notify, unique, etc) are always exposed
  during resource operations (lf#2391)
- Tools:  Support short form of crm_simulate --quorum (bnc#591168)
- ais: Convert endian for all of the integer fields in messages
  (bnc#472014)
- Upstream version cs: 80e0bb600e6c
* Wed Mar 31 2010 lmb@novell.com
- Shell: Default to using the status section from the live CIB
  (bnc#592762)
- Upstream version cs: 739282ba9e2e
* Wed Mar 31 2010 lmb@novell.com
- crmd: fix non-fatal assert in lrmd.c when resources are manually
  failed (bnc#590924)
- Upstream version cs: f77530201221
* Tue Mar 30 2010 lmb@novell.com
- tools: crm_simulate - fix small xpath memory leak in inject_node_state
- Shell: templates: new sbd template
- Shell: templates: update apache documentation
- crmd: Do not ignore action timeouts based on FSA state (could cause
  transitions that never terminate)
- Upstream version cs: 322ff3419bc8
* Mon Mar 29 2010 lmb@novell.com
- Shell: add two attributes not present in the crmd metadata, which
  broke "configure verify"
- Upstream version cs: 24ee74882b42
* Mon Mar 29 2010 lmb@novell.com
- Shell: fix bad cib passed to crm_verify
- Upstream version cs: c02327f742a0
* Mon Mar 29 2010 lmb@novell.com
- Shell: verify only changed elements on commit (bnc#590033)
- Shell: observe op_defaults when verifying primitives (bnc#590033)
- Shell: update meta attributes list
- Shell: verify meta attributes and properties (bnc#589867)
- Shell: fix wrong exit code setting logic in resource cleanup
- Shell/PE: Show utilization/capacity information (bnc#589873)
- Shell: implement new cibstatus interface and commands (bnc#580492)
- crmd: Do not allow the target_rc to be misused by resource agents
- Shell: check python version at start (lf#2369)
- extra/showscores.sh: Correctly display stickiness if unset
- RA: SystemHealth: exit properly when the required software is not
  installed (bnc#587940)
- ais: Look for the correct conf variable for turning on file logging
- crmd: Ensure the cluster terminates when the PE isn't available
  (lf#2379)
- crmd: Ensure we dont get stuck in S_PENDING if we loose an election to
  someone that never talks to us again
- Upstream version cs: 3fea355803af
* Fri Mar 19 2010 lmb@novell.com
- crmd: Remove race condition that could lead to multiple instances of a
  clone being active on a machine
- PE: Consolidate and unify logging of fencing causes
- hb2openais: add support for corosync as target
- Shell: templates: add cmirror to ocfs2 and clvm (bnc#587493)
- Shell: support for resource/node utilization
- Shell: switch to single cibadmin for commit
- Shell: enable comments (lf#2221)
- Upstream version cs: 83f654529b5c
* Mon Mar 15 2010 lmb@novell.com
- Shell: don't touch resources within a group when managing
  groups/clones
- Shell: repair node show (bnc#587883)
- Upstream version cs: 3002fabf85d4
* Wed Mar 10 2010 lmb@novell.com
- PE: Make sure migration ops use the correct meta options (bnc#586710)
- Upstream version cs: aaf4d36b8494
* Tue Mar  9 2010 dmuhamedagic@novell.com
- Shell: fix commit for new clones of new groups (bnc#585471)
- Shell: edit multiple meta_attributes sets in resource management (lf#2315)
- Shell: don't cache node and resource ids (lf#2368)
- Shell: new cibstatus import command (bnc#585471)
- Shell: check timeouts also against the default-action-timeout property
* Tue Mar  9 2010 lmb@novell.com
- PE: Avoid needless restart of primitive depending on a clone (lf#2317,
  bnc#586613)
- PE: Only log orphans when they are found to be active (lf#2364)
- PE: Ensure clones observe mandatory ordering constraints if the LHS is
  unrunnable (lf#2361)
- Tools: Add utilization support for crm_attribute and crm_resource
- Upstream version vs: c23bbc5262b2
* Fri Mar  5 2010 lmb@novell.com
- ais: Do not count votes from offline nodes and calculate current
  votes before sending quorum data.
- PE: Repair handling of unordered groups in RHS ordering constraints.
- Shell: update regression tests.
- CTS: Make it work for openais.
- Upstream version cs: a9f5a06a8f9e
* Thu Mar  4 2010 lmb@novell.com
- Conflict with ocfs2-tools-o2cb prevented said package from being
  installed at all due to dependencies (bnc#582697).
* Wed Mar  3 2010 lmb@novell.com
- Shell: implement lifetime for rsc migrate and node standby (lf#2353)
- Shell: node attributes update in configure (bnc#582767)
- Tools/PE: Do not warn if the configuration is fully
  forward-compatible.
- Upstream version cs: 745c756006da
* Mon Mar  1 2010 lmb@novell.com
- Shell: update previous node lookup procedure to include the id where
  necessary
- Shell: improve batch mode.
- Shell: add support for xml in cli.
- Shell: repare clone/ms cleanup (bnc#583288)
- Shell: load update should update existing elements.
- crmd: expected-quorum-votes not correctly updated after membership
  change (lf#2359)
- PE: Fix master-master anti-colocation (lf#2358)
- Upstream version cs: 059e4095d2ca
* Wed Feb 24 2010 lmb@novell.com
- Work around non-thread-safe setenv() calls that could cause a crash
  (bnc#582598)
- Upstream version cs: ae0170640c3e
* Tue Feb 23 2010 lmb@novell.com
- Shell: update supported CIB RE to include pacemaker 1.1 and 1.2
- ais: Fix the child shutdown escalation logic
- Core: Give signal handlers higher priority
- PE: Correctly implement optional colocation between primitives and
  clone resources
- crmd: Don't send operation updates for deleted resources (bnc#578644)
- Upstream version cs: 530add2a3721
* Mon Feb 22 2010 lmb@novell.com
- Shell: add tab completion for nodes (bnc#577003)
- Shell: fix wrong var reference
- Shell: improve configure commit (lf#2336)
- Shell: add tab completion for op/rsc_defaults (bnc#552541)
- Shell: add option to control sorting of cib elements (lf#2290)
- Shell: add tab completion for nodes (bnc#577003)
- RA: ping(d) - Fix metadata.
- xml schema: support differentiation between stable and experimental
  feature sets.
- Upstream version cs: 0591630c8bd3
* Thu Feb 18 2010 lmb@novell.com
- Conflict with ocfs2-tools-o2cb; a system needs to be configured
  either for Pacemaker or O2CB/Oracle RAC, but never both.
* Thu Feb 18 2010 lmb@novell.com
- stonith-ng: Fix meta-data not always being retrieved properly.
- Tools: crm: fix CIB upgrade command (bnc#578637)
- PE: Improved graphs when probing partially up nodes
- crmd: Improve handling of cancelled operations caused by resource
  cleanup (bnc#578644)
- PE: Significant performance bugs for larger clusters with many
  nodes/resources/constraints removed.
- Upstream version cs: 4bc7a38e2b10
* Tue Feb  9 2010 lmb@novell.com
- Add dependencies on python and python-xml so the shell works
  immediately (bnc#578006).
* Mon Feb  8 2010 lmb@novell.com
- Incorporate code for hard resource limits (FATE#303384) in shell and
  pacemaker policy engine.
- External stonith agents were not properly handled (bnc#577007).
- Upstream version cs: 46679a8feec7
* Fri Jan 22 2010 lmb@novell.com
- crmd: Ensure we have the latest status after a transition abort
- crm: optimize shell start-up time (lf#2303).
- crm: simplify template for ocfs2
- crm: don't remove sets which contain id-ref attribute (lf#2304)
- crm: add update method to template apply (lf#2289)
- crm: make template new more robust, add documentation
- crm: fix check for invalid constraints
- crm: rename status to cibstatus (lf#2236)
- crm: save options if run from the command line (lf#2310)
- crm: add notify to the list of valid operations
- crm: fix node delete (lf#2305)
- crm_node: accept -f as the short form of --force
- crm_node: rovide a way to determin the nodeid of past cluster members
  (lf#2307)
- Upstream version cs: 6a6aa02deea9
* Mon Jan 11 2010 lmb@novell.com
- PE: Don't log uninstalled resource agents as errors (lf#2251)
- fix refresh time for html interface of crm_mon
- Tools: crm: don't consider warnings as errors (lf#2274)
- Tools: crm: direct RA interface for ocf class resource agents
  (lf#2270)
- cib: Check also whether an user's primary group is matched
- PE: Bug lf#2153 - non-clones shouldn't restart when clones stop/start
  on other nodes
- PE: Bug lf#2153 - Update regression tests
- PE: Correctly anti-colocate with a group
- Tools: crm: define missing index in validate_template (lf#2287)
- Tools: crm: stay in crm if user specified level only (lf#2286)
- Tools: crm: fix exit code on single shot commands
- Tools: Bug lf#2286 - Allow the shell to accept template parameters on
  the command line
- Tools: crm: allow entering level and input file (-f)
- Tools: crm: relax check for RA existence (lf#2270)
- Tools: crm: fix OCF_ROOT processing
- Tools: crm: catch EOFError exception in raw_input (lf#2289)
- Tools: crm: implement -F (--force) option
- Tools: crm: rename some misnamed functions
- PE: Prevent non-multistate resources from being promoted through
  target-role
- Tools: crm: direct RA interface for stonith class resource agents
  (lf#2270)
- fencing: stonithd: ignore case when comparing host names (lf#2292)
- Tools: crm: direct RA interface for lsb class resource agents
  (lf#2270)
- PE: Bug lf#2153 - non-clones shouldn't restart when clones stop/start
  on other nodes - improved
- TE: Fix batch-limit processing.
- Tools: crm: exclude locations when testing for pathological
  constraints (lf#2300)
- PE: Only complain about target-role=master for non m/s resources
- Tools: crm: load help from crm_cli.txt
- pengine/crmd: move crm_log_init after version and metadata calls
  (lf#2272)
- crmd: Ensure batch-limit is correctly enforced
- PE: Don't overwrite the value of batch-limit
- cts: Add the 'cmd' to the output of external commands
- pengine: crmd: Ensure help text includes correct binary name
- Tools: crm: don't fall apart if there's no help text file
- Tools: crm: cache help tables (lf#2303)
- Upstream version cs: 443ff5d69319
* Thu Dec 10 2009 "lmb@novell.com"
- PE: Correctly unpack ordering constraints for resource sets to avoid
  graph loops
- Two new system health RAs.
- PE: Don't log uninstalled resource agents as errors (lf#2251)
- Upstream version cs: cd2aaf7e35cf
* Tue Dec  8 2009 "lmb@novell.com"
- Tools: crm: fix parentheses parsing in resource sets
- Tools: crm: support for description attribute in resources/operations
  (bnc#548690)
- Tools: hb2openais: add EVMS2 CSM processing (and other changes)
  (bnc#548093)
- Tools: crm: don't add score which doesn't exist
- Tools: crm: copy score from/to resource_set
- Tools: crm: update tab completion for constraints (support resource
  sets)
- Tools: crm: handle resource_set resource references in delete and
  rename
- PE: Provide a default action for resource-set ordering
- Tools: crm: drop empty attributes elements
- xml: Add stopped as a supported role for operations
- Tools: hb2openais: don't allow empty rules, clones, or groups
  (lf#2215)
- Tools: hb2openais: refuse to convert pure EVMS volumes
- Tools: hb2openais: add inf score to order constraints
- crm: Enhance "colocation" help to explain how it works.
- crm_mon: Mail subject needs space for \0 byte.
- fencing: stonithd: add metadata for stonithd instance attributes (and
  support in the shell)
- Tools: crm: drop short description from the metadata if it equals long
  description
- Tools: crm: relax checks for advertised monitor operations (lf#2222)
- Tools: crm: support for comments (lf#2221)
- Tools: crm: test operation name against a list of possible ops
- tools: Dont waste vertical space in crm_mon output
- xml: Treat node unames as text fields not IDs (bnc#552713)
- PE: rsc_order constraints always use score at the top level (lf#2206)
- xml: Create an always-true expression for empty rules when upgrading
  from 0.6 (lf#2215)
- PE: Clone ordering should be able to prevent startup of dependant
  clones (lf#2209)
- PE: Add regression test (lf#2209)
- PE: Correctly identify the state of anonymous clones when deciding
  when to probe (lf#2216)
- PE: Operations that require fencing should wait for 'stonith_complete'
  not 'all_stopped'. (lf#2225)
- PE: Prevent clone peers from stopping while another is instance is
  (potentially) being fenced (lf#2225)
- crmd: C_TIMER_POPPED is now quite normal thanks to the recheck timer,
  downgrade log message
- PE: Silently fix requires=fencing for stonith resources so that it can
  be set in op_defaults
- xml: Preserve the old stonith-enabled=false symantics from 0.6 during
  an upgrade (lf#2230)
- xml: Allow the auto-id base to be specified, because generate-id()
  isn't always unique
- PE: Ensure groups process location constraints so that clone-node-max
  works for cloned groups (lf#2213)
- Tools: crm: relax check for RA actions
- Upstream version cs: 9f61f272598a
* Tue Nov  3 2009 "lmb@novell.com"
- PE: Provide better defaults for lt(e) and gt(e) comparisons
  (bnc#515172)
- Upstream version cs: 405fe9a92d82
* Tue Sep 29 2009 "lmb@novell.com"
- Revert conflicts with ocfs2-tools-o2cb to ease automatic upgrades. The
  two should still not be installed in parallel; please see release
  notes!
- High: ais: Gracefully handle changes to the AIS nodeid
- Low: PE: Fix the metadata to advertise the correct type for
  stonith-timeout
- High: cib: Repair the ability to connect to the cluster from
  non-cluster machines
- Medium: Tools: Use -q as the short form for --quiet (for consistency)
- Medium (bnc#520707): Tools: crm: new templates ocfs2 and clvm
- Medium (LF 2185): Tools: crm: add resource promote/demote commands
- Low (LF 2175): Tools: crm: add help for node status
- High: xml: Mask the "symmetrical" attribute on rsc_colocation
  constraints (bnc#540672)
- Upstream version cs: 05c8b63cbca7
* Thu Aug 27 2009 "lmb@novell.com"
- Upstream version cs: 595cca870aff
- Dev: Tools: crm: do not allow empty attribute names
- Low: Tools: crm: make check for operations id attribute stricter
- Dev: Tools: crm: implement binary op types properly (thanks to Alain
  St-Denis)
- Dev: Tools: crm: allow id-refs to stand by themselves (update for fix
  37077ed56af5)
- High: crmd: Terminate if we are ever evicted from the membership
- High: crmd: Unset any existing DC value before querying for a new one
- High: PE: Bug bnc#515172 - Fix the boolean-op attribute of rules
- High: PE: Bug bnc#515172 - Correctly process location constraint rules
  which contain multiple expressions
- High (bnc#507255): Tools: crm: implement date expressions
- Low: Tools: crm: let the user know that curses is needed for colors
- High: Tools: crm: new display type (uppercase keywords)
- Medium: Extra: Add tools, an RA and tests for the System Health
  feature
- Medium: Tools: crm_resource - Prevent use-of-NULL by requiring a
  resource name for the -A and -a options
- Medium: PE: Prevent use-of-NULL in find_first_action()
- High: PE: Only prevent migration if the clone dependancy is
  stopping/starting on the target node
- Low: crmd: Include cib version of the updates which caused a
  transition abort
- High: PE: Bug lf#2160 - Dont shuffle clones due to colocation
- Low: PE: Fix find_first_action() when no node filter is specified
- Low: PE: ptest - Suppress deleted ordering constraints from the .dot
  graph
- High: PE: New implementation of the resource migration (not
  stop/start) logic
- Medium: crmd: Note that dc-deadtime can be used to mask the brokeness
  of some switches
- High: Tools: crm_resource - Advertise --move instead of --migrate
- Medium: Extra: New node connectivity RA that uses system ping and
  attrd_updater
- High: crmd: Bug bnc#527530 - Wait for the transition to complete
  before leaving S_TRANSITION_ENGINE
- High: ais: Avoid excessive load by checking for dead children every 1s
  (instead of 100ms)
- Medium: PE: Stop ptest from logging to syslog
- Medium: PE: Correctly log resources that would like to start but can't
- High: PE: Bug lf#2171 - Prevent groups from starting if they depend on
  a complex resource which can't
- Low: PE: Add regression test for lf#2171
- High: PE: Bug lf#2170 - stop-all-resources option had no effect
- High: PE: Disable resource management if stonith-enabled=true and no
  stonith resources are defined
- High: Core: Bug lf#2169 - Allow dtd/schema validation to be disabled
- Medium: PE: Bug lf#2180 - Include node information for all failed ops
- Medium: PE: Bug lf#2178 - Indicate unmanaged clones
- Medium: ais: Include version details in plugin name
- High: PE: Bug lf#2106 - Not all anonymous clone children are restarted
  after configuration change
- Medium: ais: Attempt to enable core file generation if it was disabled
- Medium: crmd: Requery the resource metadata after every start
  operation
- High: Tools: crm: add semantic checks depending on the meta-data from
  resource agents
* Thu Aug 13 2009 abeekhof@suse.de
- Update source tarball to revision: b05d5a2b9c52
  + High (bnc#507255): Tools: crm: implement date expressions
  + High: Build: Fix compilation when snmp and esmtp are not available
  + High: PE: Bug 2160 - Dont shuffle clones due to colocation
  + High: PE: Bug bnc#515172 - Correctly process location constraint rules which contain multiple expressions
  + High: PE: Bug bnc#515172 - Fix the boolean-op attribute of rules
  + High: PE: New implementation of the resource migration (not stop/start) logic
  + High: PE: Only prevent migration if the clone dependancy is stopping/starting on the target node
  + High: Tools: crm: new display type (uppercase keywords)
  + High: Tools: crm_resource - Advertise --move instead of --migrate
  + High: ais: Fix cluster connection when using corosync 1.0
  + High: ais: Ubuntu needs a leading zero for directory modes
  + High: crmd: Terminate if we are ever evicted from the membership
  + High: crmd: Unset any existing DC value before querying for a new one
  + Medium: Extra: Add tools, an RA and tests for the System Health feature written by Mark Hamzy
  + Medium: Extra: New node connectivity RA that uses system ping and attrd_updater
  + Medium: PE: Prevent use-of-NULL in find_first_action()
  + Medium: Tools: crm_resource - Prevent use-of-NULL by requiring a resource name for the -A and -a options
  + Medium: crmd: Note that dc-deadtime can be used to mask the brokeness of some switches
* Thu Aug 13 2009 lmb@novell.com
- Remove references to heartbeat packages.
* Mon Aug  3 2009 lmb@novell.com
- Require python-curses for CLI color support.
* Tue Jul 21 2009 lmb@novell.com
- Update to 0123af21a705.
* Mon Jul 13 2009 lmb@novell.com
- Prevent pacemaker from being installed along with ocfs2-tools-o2cb to
  reduce likelihood of misconfiguration (bnc#520721).
* Wed Jul  8 2009 lmb@suse.de
- Build: properly install crm_standby, crm_failcount, crm_master.
* Wed Jul  8 2009 lmb@suse.de
- Update source tarball to revision: b05d5a2b9c52
  + High: Core: Show help text and exit with rc 1 if option processing failed
  + High: PE: Fix reload for master/slave resources
  + High: Tools: Differentiate between --help and an unknown option
  + High: Tools: crm: support for color output
  + High: lrm: Look in the correct location for stonith agents
  + Low: Core: Reduce logging noise
  + Low: Tools: Ensure crm_resource -q prints a trailing newline
  + Low: Tools: ptest no longer supports --xml-pipe
  + Low: Tools: remove spurios newline output to stderr
  + Low: ais: Better handling of to_file: and to_syslog: options
  + Low: ais: set HA_LOGFACILITY too
  + Low: extra: Add a dummy parameter to 'Dummy' so we can test reload
  + Medium: Tools: crm: fix the verify exit code properly
  + Medium: cib: Supply an empty status section for replace operations
  + Dev: Tools: crm: recreate constraints on grouping resources
* Wed Jun 10 2009 abeekhof@suse.de
- Update source tarball to revision: Pacemaker-1.0.4
  + High: ais: bnc#488291 - don't rely on byte endianness on ptr cast
  + High: Tools: bnc#507255 - crm: import properly rsc/op_defaults
  + High: Tools: lf#2114 - crm: add support for operation instance attributes
  + High: ais: Bug lf#2126 - Messages replies cannot be routed to transient clients
  + High: attrd: Support the value++ and value+=... syntax required for failcounts
  + High: cib: Fix huge memory leak affecting heartbeat-based clusters
  + High: Core: Generate the help text directly from a tool options struct
  + High: crmd: Bug lf#2120 - All transient node attribute updates need to go via attrd
  + High: crmd: Fix another large memory leak affecting Heartbeat based clusters
  + High: PE: Bug bnc#495687 - Filesystem is not notified of successful STONITH under some conditions
  + High: PE: Make running a cluster with STONITH enabled but no STONITH resources an error and provide details on resolutions
  + High: PE: Prevent use-of-NULL when using resource ordering sets
  + High: Tools: attrd - Prevent race condition resulting in the cluster forgetting node's wish to shut down
  + High: Tools: crm_mon - Fix smtp notifications
  + High: Tools: crm_resource - Repair the ability to query meta attributes
  + Medium: Core: Include supported stacks in version information
  + Medium: Tools: Include current stack in crm_mon output
  + Medium: PE: Correctly log the actions for resources that are being recovered
  + Medium: PE: Correctly log the occurance of promotion events
* Fri Apr  3 2009 abeekhof@suse.de
- Add a man page for crm_shadow
- Update source tarball to revision: 9196be9830c2
  + High: crmd: Bug bnc#480977 - Prevent extra, partial, shutdown when a node restarts too quickly (verified)
  + Medium: crmd: Bug bnc#490426 - Escalated shutdowns stall when there are pending resource operations
  + Medium: PE: Bug bnc#491441 - crm_mon does not display operations returning 'uninstalled' correctly
* Tue Mar 31 2009 abeekhof@suse.de
- Update for SLE11 HAE RC9
- Update source tarball to revision: 61da7b5260df
  + High: PE: Bug bnc#490418 - Correctly determine node state for nodes wishing to be terminated
  + High: RA: Bug bnc#490641 - Shut down dlm_controld with -TERM instead of -KILL
* Mon Mar 30 2009 abeekhof@suse.de
- Update source tarball to revision: f090699a99c5
  + High: PE: Bug bnc#488721 - Fix id-ref expansion for clones, the doc-root for clone children is not the cib root
  + High: PE: Bug lf#2094 - Fix probe ordering for cloned groups
  + High: crmd: Bug bnc#489063 - Ensure the DC is always unset after we 'loose' an election
* Fri Mar 20 2009 abeekhof@suse.de
- Update for SLE11 HAE RC8
- Update to upstream version number
- Update source tarball to revision: be123e8615a5
  + High: PE: Bug lf#2089 - Meta attributes are not inherited by clone children
  + High: PE: Bug lf#2091 - Correctly restart modified resources that were found active by a probe
  + High: PE: Correctly handle terminate node attributes that are set to the output from time()
  + High: ais plugin: Fix quorum calculation (bnc#487003)
  + High: ais: Bug bnc#486858 - Fix update_member() to prevent spamming clients with membership events containing no changes
  + High: fencing: stonithd: is_heartbeat_cluster is a no-no if there is no heartbeat support
* Mon Mar 16 2009 lmb@suse.de
- Update for SLE11 HAE RC7
- Update source tarball to revision: 7e44933b0e46
  - Tools: crm: print short help if there is no long help; replace "desc" with "help"
  - Tools: crm: issue warnings on all unrecognized elements of the cib configuration
  - Tools: crm: the new configure monitor command
  - Tools: crm: return exit code from configure commands
  - Tools: crm: check shadow name for sanity in the cib use command
  - Tools: crm: more shadow name sanity checks
* Mon Mar 16 2009 abeekhof@suse.de
- Update source tarball to revision: ec6b0bbee1f3
  + High: PE: The ordered option for clones no longer causes extra start/stop operations
  + High: RA: pingd: Set default ping interval to 1 instead of 0 seconds
  + High: Tools: crm: the new configure node command
  + High: Tools: crm_mon - Prevent use-of-NULL when summarizing an orphan
  + High: ais: Bug bnc#482847, bnc#482905 - Force a clean exit of OpenAIS once Pacemaker has finished unloading
* Tue Mar 10 2009 abeekhof@suse.de
- Update for SLE11 HAE RC6.1
- Update source tarball to revision: 37e5ae18279e
  + High: Fix compilation on x64 - We dont need longclock_t intervals/precision for debug timers
  + High: cib: Bug bnc#482885 - Simplify CIB disk-writes to prevent data loss
  + High: Tools: The default re-ping interval for pingd should be 1s not 1ms
* Mon Mar  9 2009 abeekhof@suse.de
- Update for SLE11 HAE RC6
- Remove heartbeat-specific binary from the distribution
- Update source tarball to revision: 3028846cc3f5
  + High: PE: Bug bnc#478687 - Don't crash when clone-max is 0
  + High: PE: Bug LF#2087 - Correctly parse the state of anonymous clones that have multiple instances on a given node
  + High: PE: Bug LF:2075 - Fix large pingd memory leaks
  + High: PE: Bug bnc#466788 - Make colocation based on node attributes work
  + High: PE: Correctly attach orphaned clone children to their parent
  + High: PE: Fix memory leak in LogActions
  + High: PE: Fix the determination of whether a group is active
  + High: PE: Look up the correct promotion preference for anonymous masters
  + High: PE: Simplify handling of start failures by changing the default migration-threshold to INFINITY
  + High: Tools: Bug bnc#483365 - Ensure the command from cluster_test includes a value for --log-facility
  + High: Tools: crm: add support for command aliases and some common commands (i.e. cd,exit)
  + High: Tools: crm: create top configuration nodes if they are missing
  + High: Tools: crm: fix parsing attributes for rules (broken by the previous changeset)
  + High: Tools: crm: new ra set of commands
  + High: Tools: crm: resource agents information management
  + High: Tools: crm: support for no value attribute in nvpairs
  + High: Tools: hb2openais: fix ocfs2 processing
  + High: Tools: pingd - prevent double free of getaddrinfo() output in error path
  + High: ais: Correctly handle a return value of zero from openais_dispatch_recv()
  + High: ais: Fix memory leak in error path
  + High: ais: IPC messages are only in scope until a response is sent
  + High: cib: Bug bnc#482885 - Simplify CIB disk-writes to prevent data loss.  Required a change to the backup filename format
  + High: crm: Avoid infinite loop during crm configure edit (bnc#480327)
  + High: crmd: Avoid a race condition by waiting for the attrd update to trigger a transition automatically
  + High: crmd: Bug bnc#479543 - Correctly find the migration source for timed out migrate_from actions
  + High: crmd: Fix memory leaks found by valgrind
* Thu Mar  5 2009 abeekhof@suse.de
- heartbeat-common _must_ be a PreReq: instead of a Requires: so that
  the script which creates hacluster/haclient has completed before
  Pacemaker is installed.  Otherwise the file permissions are all wrong.
* Tue Mar  3 2009 abeekhof@suse.de
- Add man page for the crm shell
* Fri Feb 27 2009 lmb@suse.de
- Update source tarball to revision: e0f361e9bd17
- High: Tools: cli: fix and improve delete command
- High: Tools: crm: support rsc/op_defaults
* Wed Feb 25 2009 abeekhof@suse.de
- Add extra soft dependancies: graphviz, libdlm, heartbeat-resources
* Mon Feb 23 2009 abeekhof@suse.de
- Update for SLE11 HAE RC5
- Update source tarball to revision: 33e92390b2ed
  + High: Core: Prevent unterminated strings after decompression
  + High: PE: Clones now default to globally-unique=false
  + High: PE: Prevent use-of-NULL for failed migrate actions in process_rsc_state()
  + High: PE: Start the correct monitor operation for unmanaged masters
  + High: Tools: Cause the correct clone instance to be failed with crm_resource -F
  + High: ais: Centralize all quorum calculations in the ais plugin and allow expected votes to be configured int he cib
  + High: crmd: Ensure updates for lost migrate operations indicate which node it tried to migrating to
  + High: crmd: Fix memory leak in cib notication processing code
  + High: crmd: Fix memory leak in transition graph processing
  + Medium: Core: Bug BNC#474727 - Set a maximum time to wait for IPC messages
  + Medium: PE: Ensure clones always have a value for globally-unique
  + Medium: crmd: Add new expected-quorum-votes option
  + Medium: crmd: Automatically detect and use new values for crm_config options
  + Medium: crmd: Bug BNC#472473 - Don't wait excessive amounts of time for lost actions
  + Medium: crmd: Bug BNC#472473 - Reduce the transition timeout to action_timeout+network_delay
* Fri Feb  6 2009 abeekhof@suse.de
- Update source tarball to revision: 09be44da9b32
  + High: PE: Remove an optimization for the terminate node attribute that caused the cluster to block indefinitly
  + High: Tools: Bug BNC#468066 - Don't use the result of uname() when its no longer in scope
  + High: Tools: Bug LF:2036 - crm_resource cannot set/get parameters for cloned resources
  + High: ais: Add optional support for the new AIS IPC layer
  + High: ais: Always set header.error to the correct default: SA_AIS_OK
  + High: ais: Ensure crm_peer_seq is updated after a membership update
  + High: ais: Make sure all IPC header fields are set to sane defaults
  + High: cib: Allow clients without mainloop to connect to the cib
  + High: cib: Fix four moderately sized memory leaks detected by Valgrind
  + High: Core: Fix more memory leaks foudn by valgrind
  + High: Tools: Bug BNC#473265 - crm_resource -L dumps core
  + High: Tools: Bug LF:2046 - Node attribute updates are lost because attrd can take too long to start
  + High: Tools: hb2openais: add constraints for clvmd to controld
  + High: Tools: hb2openais: improve media processing and set rrp_mode for multiple rings configuration
  + High: Tools: hb2openais: openais supports up to two rings
* Mon Jan 26 2009 abeekhof@suse.de
-  Update source tarball to revision: 7eef42ed409d
  + High: Tools: Bug BNC#468066 - crm_standby - Don't use the result of uname() when its no longer in scope
  + High: PE: Bug BNC#465484 - Fix the no-quorum-policy=suicide option
  + High: PE: Only shoot online nodes with no-quorum-policy=suicide
  + High: ais: Bug BNC#456208 - Prevent deadlocks by not logging in the child process before exec()
  + High: ais: Detect and handle situations where ais and the crm disagree on the node name
  + High: crmd: Bug BNC#467995 - Delay marking STONITH operations complete until STONITH tells us so
  + High: crmd: Prevent node attribute loss by detecting attrd disconnections immediately
- Enabled support for SNMP and SMTP notifications on resource state changes
* Wed Jan 21 2009 abeekhof@suse.de
- Update source tarball to revision: a2f46902d821
  + High: Core: CID:10 - Prevent indexing into an array of schemas with a negative value
  + High: Core: CID:13 - Fix memory leak in log_data_element
  + High: Core: CID:15 - Fix memory leak in crm_get_peer
  + High: Core: CID:6 - Fix use-of-NULL in copy_ha_msg_input
  + High: Core: Fix crash in the membership code preventing node shutdown
  + High: PE: CID:19 - Fix use-of-NULL in determine_online_status
  + High: Tools: Bug 2003 - pingd doesn't correctly handle node-down events on multi-NIC systems
  + High: Tools: Bug 2021 - pingd does not detect sequence wrapping correctly, incorrectly reports nodes offline
  + High: Tools: attrd - Correctly determine when an attribute has stopped changing and should be committed to the CIB
  + High: Tools: crm_master shouldn't define a set id now that attrd is used.  Defining one can break lookups
  + High: Tools: hb2openais: adjust path to the supporting script and set CONF variable
  + High: Tools: hb2openais: set no-quorum-policy to ignore for 2-node clusters
  + High: ais: Bug BNC#456243 - Ensure the membership cache always contains an entry for the local node
  + High: cib: CID:18 - Fix use-of-NULL in cib_perform_op
  + High: cib: CID:18 - Repair errors introduced in b5a18704477b - Fix use-of-NULL in cib_perform_op
  + High: crmd: Bug LF:2010 - Ensure fencing cib updates create the node_state entry if needed to preent re-fencing during cluster startup
  + High: crmd: Correctly handle reconnections to attrd
  + High: stonith: CID:3 - Fix another case of exceptionally poor error handling by the original stonith developers
  + High: stonith: CID:5 - Checking for NULL and then dereferencing it anyway is an interesting approach to error handling
  + High: stonithd: wrong checks for shmid (0 is a valid id)
* Wed Dec  3 2008 abeekhof@suse.de
- Reduce bloat - remove regession tests from source tarball
- Update source tarball to revision: 6b8d46c7ab9c
  + High: crmd: Don't fast-track the processing of LRM refreshes when there are pending actions.
  + High: PE: Bug LF:2005 - Fix startup ordering of cloned stonith groups
  + High: PE: Bug LF:2006 - Correctly reprobe cloned groups
  + High: PE: Prevent on-fail settings being ignored after a resource is successfully stopped
  + High: Tools: Bug LF:2003 - pingd doesn't correctly detect failures when the interface is down
  + High: Tools: Bug LF:2001 - Transient node attributes should be set via attrd
  + High: Tools: crm cli: Bug bnc:450815 - don't generate id for the operations tag
  + High: Tools: crm cli: drop '-rsc' from attributes for order constraint
  + High: Tools: crm cli: fix wrong order of action and resource in order constraint
  + High: Tools: crm cli: return on syntax error when parsing score
* Fri Nov 21 2008 abeekhof@suse.de
- Update source tarball to revision: 27be064e0907
  + High: ais: Repair and streamline service load now that OpenAIS startup functions correctly
- Requires and is related to sr3936: Fix Bug bnc#444376 - openais segafults in lcr_ifact_release during shutdown
* Fri Nov 21 2008 abeekhof@suse.de
- Update source tarball to revision: 61d0af5c31c0
  + High: cib: Ensure configuration updates contain the correct values of admin_epoch
    Otherwise the configuration can not be kept in sync across the cluster
  + High: crmd: Bug LF:1962 - Don't NACK peers because they're not (yet) in our membership.  Just ignore them.
  + High: crmd: Prevent node re-probe loops by ensuring manditory actions always complete
  + High: PE: Bug LF:1996 - Correctly process disabled monitor operations
  + High: PE: Correctly calculate the number of available nodes for the clone to use
  + High: Tools: crm cli: catch system errors on file operations
  + High: Tools: crm cli: exit with an appropriate exit code
  + High: Tools: crm cli: new command: configure upgrade
  + High: Tools: crm cli: prevent key errors on missing cib attributes
  + High: Tools: crm cli: sometimes, on errors, level would change on single shot use
  + Medium: crmd: do_dc_join_filter_offer - Check the 'join' message is for the current instance before deciding to NACK peers
  + Medium: Tools: crm cli: replace inf with INFINITY
  + Medium: Tools: crm cli: supply provider only for ocf class primitives
* Tue Nov 18 2008 abeekhof@suse.de
- Add man pages for Pacemaker admin tools
- Update source tarball to revision: eda05459ce58
  + High: Core: Repair the ability to have comments in the configuration
  + High: Tools: hb2openais: update logging and set logfile appropriately
  + High: ais: Hook up the openais.conf config logging options
  + High: ais: Zero out the PID of disconnecting clients
  + High: cib: Ensure global updates cause a disk write when appropriate
  + High: crmd: Ensure PE processing does not occur for all error cases in do_pe_invoke_callback
  + High: crmd: Requests to the CIB should cause any prior PE calculations to be ignored
  + Medium: PE: Prevent lsb scripts from being used in globally unique clones
  + Medium: Tools: crm_mon - display the meaning of the operation's rc code instead of the status
  + Medium: ais: Hook up the options for specifying the expected number of nodes and total quorum votes
  + Medium: crmd: Fix the handling of unexpected PE exits to ensure the current CIB is stored
* Sat Nov  8 2008 abeekhof@suse.de
- Update source tarball to revision: e21021b77657
  + High: crmd: Erase the correct node's status section when it returns
* Fri Nov  7 2008 abeekhof@suse.de
- Update source tarball to revision: 7508f211e536
  + High: PE: Bug LF:1988 - Ensure recurring operations always have the correct target-rc set
  + High: PE: Fix optional colocation
  + High: PE: Improve up the detection of 'new' nodes joining the cluster
  + High: PE: Prevent assert failures in master_color() by ensuring unmanaged masters are always reallocated to their current location
  + High: Tools: crm_shadow - Show more line number information after validation failures
  + High: ais: Ensure HA_RSCTMP exists for use by resource agents
  + High: crmd: Bug:1975 - crmd should wait indefinitely for stonith operations to complete
  + Medium: PE: Bug N:437719 - Ensure scores from colocated resources count when allocating groups
  + Medium: Tools: Bug LF:1985 - crm_mon - Correctly process failed cib queries to allow reconnection after cluster restarts
  + Medium: Tools: Bug LF:1987 - crm_verify incorrectly warns of configuration upgrades for the most recent version
  + Medium: Tools: attrd - Automatically refresh all attributes after a CIB replace operation
  + Medium: Tools: crm (bnc#441028): check for key error in attributes management
  + Medium: crmd: Detect deleted resource operations automatically
  + Medium: crmd: Erase a node's resource operations and transient attributes after a successful STONITH
  + Medium: crmd: Fix the recording of pending operations in the CIB
  + Medium: xml: Relax the restriction on the contents of rsc_locaiton.node
* Mon Oct 27 2008 abeekhof@suse.de
- Update source tarball to revision: 9082ded546ec
  + High: Tools: LF:1969 - Attrd never sets any properties in the cib
  + Medium: Core: Provide better feedback if Pacemaker is started by a stack it doesn't support
  + Medium: Ensure meta attributes are used consistantly
  + Medium: PE: Allow group and clone level resource attributes
  + Medium: PE: Make a best-effort guess at a migration threshold for people with 0.6 configs
  + Medium: Tools: crm_mon - Fix the display of timing data
  + Medium: Tools: crm_verify - check that we're being asked to validate a complete config
* Tue Oct 14 2008 abeekhof@suse.de
- Add heartbeat-common as a runtime dependancy
  This ensures the clustering user/group is installed and directories
  iare created with the right permissions
* Mon Oct 13 2008 abeekhof@suse.de
- Add openais as a hard dependancy
* Thu Oct  9 2008 abeekhof@suse.de
- Update source tarball to revision: 9a6c6d1dd871 (1.0.0)
  + High: Core: Allow the expected number of quorum votes to be configrable
  + High: Tools: Make pingd functional on Linux
  + Medium: crmd: Avoid calling GHashTable functions with NULL
  + Medium: tools: crm_resource - return with non-zero when a resource migration command is invalid
  + Medium: tools: crm_shadow - Allow the admin to start with an empty CIB (and no cluster connection)
  + Medium: PE: Use the correct attribute for action 'requires' (was prereq)
* Sun Sep 28 2008 abeekhof@suse.de
- Update source tarball to revision: 8415675fe428
  + High: Core: Only call xmlCleanupParser() if we parsed anything.  Doing so unconditionally seems to cause a segfault
  + High: hb2openais.sh: improve pingd handling; several bugs fixed
  + High: hb2openais: fix clone creation; replace EVMS strings
  + High: stonithd: fix handling of timeouts
  + High: stonithd: fix logic for stonith resource priorities
  + High: stonithd: initialize value before reading fence-timeout
  + Medium: PE: Remove new options that are better set in rsc_defaults
  + Medium: PE: Detect clients that disconnect before receiving their reply
  + Medium: PE: ptest - check the input is valid before proceeding
  + Medium: crmd: Hook up the stonith-timeout option to stonithd
  + Medium: crmd: Prevent potential use-of-NULL in global_timer_callback
  + Medium: crmd: Rationalize the logging of graph aborts
  + Medium: xml: pacemaker-0.7 should be an alias for the 1.0 schema
* Mon Sep 15 2008 abeekhof@suse.de
- Create a libpacemaker subpackage
* Thu Sep 11 2008 abeekhof@suse.de
-  Update source tarball to revision: 2087f5b1a5a0
  + High: PE: Bug LF:1950 - Ensure the current values for all notification variables are always set (even if empty)
  + High: PE: Bug LF:1955 - Ensure unmanaged masters are unconditionally repromoted to ensure they are monitored correctly.
  + High: PE: Bug LF:1955 - Fix another case of filtering causing unmanaged master failures
  + High: PE: Bug LF:1955 - Umanaged mode prevents master resources from being allocated correctly
  + High: PE: Bug N:420538 - Anit-colocation caused a positive node preference
  + High: PE: Correctly handle unmanaged resources to prevent them from being started elsewhere
  + High: PE: crm_resource - Fix the --migrate command
  + High: ais: Move the service id definition to a common location and make sure it is always used
  + High: stonithd (LF 1951): fix remote stonith operations
  + Medium: Build: Make sure crm_config.h is only ever included once
  + Medium: PE: Bug LF:1950 - Notifications do not contain all documented resource state fields
  + Medium: PE: Bug N:417585 - Don't restart group children who's individual score drops below zero
  + Medium: PE: Implement a true maintenance mode
  + Medium: ais: Use the agreed service number
  + Medium: Tools: Implement a unified CLI shell
* Mon Sep  1 2008 abeekhof@suse.de
- Update source tarball to revision: 1df197982079
- Try again to fix compilation in STABLE (this time also tested with mbuild)
- STONITH is now enabled by default and the cluster will warn if no STONITH resource is found
* Sat Aug 30 2008 abeekhof@suse.de
- Update source tarball to revision: 902885c90d96
- Fixes build ordering ssue that prevented compilation of lib/common
* Wed Aug 20 2008 abeekhof@suse.de
- Update source tarball to revision: f567855328b7 (0.7.1)
  + Added features needed to support libdlm and ocfs2-tools
  + High: admin: Fix use-after-free in crm_mon
  + High: cib: Use single quotes so that the xpath queries for nvpairs will succeed
  + High: crmd: Always connect to stonithd when the TE starts and ensure we notice if it dies
  + High: crmd: Make sure async-failures cause the failcount to be incrimented
  + High: PE: Bug LF:1941 - Handle failed clone instance probes when clone-max < #nodes
  + High: PE: Prevent use-of-NULL - order->rsc_rh will not always be non-NULL
  + High: PE: Unpack colocation sets correctly
  + High: Tools: crm_mon - Prevent use-of-NULL for orphaned resources
  + Medium: Core: Get more details regarding parser errors
  + Medium: Core: Switch to the libxml2 parser - its significantly faster
  + Medium: PE: Allow groups to be involved in optional ordering constraints
  + Medium: PE: Allow sets of operations to be reused by multiple resources
  + Medium: PE: Bug LF:1941 - Mark extra clone instances as orphans and don't show inactive ones
  + Medium: PE: Determin the correct migration-threshold during resource expansion
  + Medium: PE: Implement no-quorum-policy=suicide (FATE #303619)
  + Lots of bug fixes
* Mon Jul 21 2008 abeekhof@suse.de
- Update source tarball to revision: 7a31d0c33e22 (0.7.0)
  + High: Performance enhancements
  + High: Fix memory leaks and use-after-free
  + High: Admin: All tools now use --node (-N) for specifying node unames
  + High: Admin: All tools now use --xml-file (-x) and --xml-text (-X) for specifying where to find XML blobs
  + High: cib: Implement CIB_shadow - a facility for making and testing changes before uploading them to the cluster
  + High: cib: Make registering per-op callbacks an API call and renamed (for clarity) the API call for requesting notifications
  + High: Core: Add a facility for automatically upgrading old configurations
  + High: Core: Adopt libxml2 as the XML processing library - all external clients need to be recompiled
  + High: PE: Bug LF:1459 - Allow failures to expire
  + High: PE: Replace failure-stickiness with a simple 'migration-threshold'
  + High: PE: Bug LF:1941 - Handle failed clone instance probes when clone-max < #nodes
  + High: PE: Make OCF_ERR_ARGS a node-level error rather than a cluster-level one
  + High: PE: Properly handle clones that are not installed on all nodes
  + Medium: Admin: Bug LF:1438 - Allow the list of all/active resource operations to be queried by crm_resource
  + Medium: Admin: Bug LF:1708 - crm_resource should print a warning if an attribute is already set as a meta attribute
  + Medium: Admin: Bug LF:1883 - crm_mon should display fail-count and operation history
  + Medium: Admin: Bug N:371785 - crm_resource -C doesn't also clean up fail-count attributes
  + Medium: Admin: crm_mon - include timing data for failed actions
  + Medium: cib: Bug LF:1348 - Allow rules and attribute sets to be referenced for use in other objects
  + Medium: cib: BUG LF:1918 - By default, all cib calls now timeout after 30s
  + Medium: cib: Remove some useless parts of the API
  + Medium: cib: Implement the ability for clients to connect to remote servers
  + Medium: Core: Add support for validating xml against RelaxNG schemas
  + Medium: PE: Bug LF:1328 - Don't fencing nodes in clusters without managed resources
  + Medium: PE: Bug LF:1461 - Give transient node attributes (in <status/>) preference over persistent ones (in <nodes/>)
  + Medium: PE: Bug LF:1884, Bug LF:1885 - Implement N:M ordering and colocation constraints
  + Medium: PE: Bug LF:1886 - Create a resource and operation 'defaults' config section
  + Medium: PE: Bug LF:1892 - Allow recurring actions to be triggered at known times
  + Medium: PE: Bug LF:1926 - Probes should complete before stop actions are invoked
  + Medium: PE: Prefer the current location if it is one of a group of nodes with the same (highest) score
* Sat May  3 2008 abeekhof@suse.de
- Use a libexecdir consistent with openais
* Tue Apr 29 2008 abeekhof@suse.de
- Updated to upstream version 0.6.3-1
- Update source tarball to revision: fd8904c9bc67
- SNMP has been moved to the management/pygui project
- Many bugfixes, primarily related to master/slave resources and failcount handling
- Fix libtool version check and supply a better default for the LCRSO directory
* Sat Apr 12 2008 abeekhof@suse.de
- version 0.6.2-1
- Initial package check-in
